(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    219405,       7317]*)
(*NotebookOutlinePosition[    220456,       7351]*)
(*  CellTagsIndexPosition[    220412,       7347]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    StyleBox[\(Studying\ Continuous\ Time\ Dynamics\),
      FontFamily->"Times",
      FontSize->24], 
    StyleBox[\(of\ 2\ x2\ Normal - Form\ Games\),
      FontFamily->"Times",
      FontSize->24], 
    RowBox[{
      StyleBox["Using",
        FontFamily->"Times",
        FontSize->24], 
      StyleBox[" ",
        FontFamily->"Times",
        FontSize->24], 
      StyleBox["Mathematica",
        FontFamily->"Times",
        FontSize->24,
        FontSlant->"Italic"]}]}], "Input",
  TextAlignment->Center,
  AspectRatioFixed->True,
  FontFamily->"Helvetica",
  FontSize->20],

Cell[TextData[{
  StyleBox[
  "\tIn this notebook, I give some examples of how to use the functions \
defined in my ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["`", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["Continuous2x2Dynamics", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["`", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[" package contained in the file `",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["Cont2x2.m", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[
  "`.   I have used the 'Matching Pennies' game throughout this notebook, and \
I have evaluated the sample cells.  I have included the outputs I got when I \
ran these examples.  If you need help with the syntax of my functions, you \
can get online help for them by evaluating the expression (",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["e.g.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[") ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["?DarwinFlowOrbit", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[" ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["once you have loaded the package (",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["i.e.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[
  ",  once you have evaluated the first cell in this notebook -- see below).\n\
\tThe two dynamical models (",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["i.e.",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[
  ", replicator and darwin) seen here are taken from Brian Skyrms's book ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["The Dynamics of Rational Deliberation",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[
  ".  It should be easy enough to add new dynamical flows of your own to my \
package.  Skyrms also discusses the replicator dynamics in his more recent \
book ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["The Evolution of the Social Contract",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  "First, load in the ",
  StyleBox["`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["Continuous2x2Dynamics",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  StyleBox["`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  " package, by evaluating the following cell (here, the path should be set \
appropriately to find the package fille ",
  StyleBox["Cont2x2.m", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  ")."
}], "Text",
  FormatType->TextForm],

Cell[BoxData[
    \(<< "\<current work data:dynamics:cont2x2.m\>"; \n
    Off[Solve::"\<svars\>"]; \)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "You can use the ",
  StyleBox["?", "Input"],
  " function to obtain information about the various functions defined in the \
package."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DarwinFlowOrbit\)\)], "Input"],

Cell[BoxData[
    \("DarwinFlowOrbit[{G_, T_, A_, PrR20_, PrC20_}].  Takes the five-tuple \
<G, T, A, PrR20, PrC20> into a  graphics object of the orbit starting from \
the initial point <PrR20, PrC20> under the Darwin flow on the time interval \
[0, T]. The accuracy (i.e., step size in fourth order Runge Kutta numerical \
integration algorithm) is given by A.  G is the 2x2 Normal form  game--it is \
an eight-tuple of the form: G = {R11, C11, R12, C12, R21, C21, R22, C22}."\)],
   "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ReplicatorFlowOrbit\)\)], "Input"],

Cell[BoxData[
    \("ReplicatorFlowOrbit[{G_, T_, A_, PrR20_, PrC20_}].  Takes the \
five-tuple <G, T, A, PrR20, PrC20> into a  graphics object of the orbit \
starting from the initial point <PrR20, PrC20> under the Replicator flow on \
the time interval [0, T]. The accuracy (i.e., step size in fourth order Runge \
Kutta numerical integration algorithm) is given by A.  G is the 2x2 Normal \
form  game--it is an eight-tuple of the form: G = {R11, C11, R12, C12, R21, \
C21, R22, C22}."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(G = 
      \({R11, C11, R12, C12, R21, C21, R22, C22} = {1, 0, 0, 1, 0, 1, 1, 0}
          \); \)\), 
    \(\(Print["\<The game in question is, G = \>", 
      TableForm[Partition[G, 4]]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"The game in question is, G = \"\>", "\[InvisibleSpace]", 
        TagBox[GridBox[{
              {"1", "0", "0", "1"},
              {"0", "1", "1", "0"}
              },
            RowSpacings->1,
            ColumnSpacings->3,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          (TableForm[ #]&)]}],
      SequenceForm[ "The game in question is, G = ", 
        TableForm[ {{1, 0, 0, 1}, {0, 1, 1, 0}}]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "Here, we look at an orbit of the game ",
  StyleBox["G", "Input"],
  " above (",
  StyleBox["viz",
    FontSlant->"Italic"],
  "., \"matching pennies\") under both the darwin flow and the replicator \
flow."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sims = {{G, 30,  .1,  .9,  .9}}; \n
    DarwinPhasePlot = DarwinFlowOrbit/@Sims; \n
    ReplicatorPhasePlot = ReplicatorFlowOrbit/@Sims; \n
    Show[{DarwinPhasePlot}, Prolog \[Rule] Thickness[ .0005], 
      PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
      FrameLabel 
        \[Rule] {"\<PrR2\>", "\<PrC2\>", 
          "\<Phase plot of G under Darwin Flow\>", "\<\>"}]; \n
    \(Show[{ReplicatorPhasePlot}, Prolog \[Rule] Thickness[ .0005], 
      PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
      FrameLabel 
        \[Rule] {"\<PrR2\>", "\<PrC2\>", 
          "\<Phase plot of G under Replicator Flow\>", "\<\>"}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -14 ]
[-0.01875 .30902 -18 14 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -101 0 ]
[.5 .63053 101 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrR2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10 translate
90 rotate
-75 -10 translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrC2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -162 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
99.000000 13.000000 moveto
(plot) show
129.000000 13.000000 moveto
(of) show
147.000000 13.000000 moveto
(G) show
159.000000 13.000000 moveto
(under) show
195.000000 13.000000 moveto
(Darwin) show
237.000000 13.000000 moveto
(Flow) show
261.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0005 w
.9 .55623 m
.90814 .52885 L
.91504 .49751 L
.92076 .46422 L
.92536 .4306 L
.92892 .39771 L
.93145 .36622 L
.93299 .3365 L
.93351 .30873 L
.93294 .28296 L
.93119 .2592 L
.92807 .23736 L
.92337 .21739 L
.91675 .19918 L
.9078 .18264 L
.89603 .16767 L
.88089 .1542 L
.86186 .14213 L
.83858 .13139 L
.81093 .12193 L
.77918 .11369 L
.74396 .1066 L
.70615 .10063 L
.66677 .09572 L
.62677 .09184 L
.587 .08898 L
.54815 .08713 L
.51072 .08629 L
.47508 .08652 L
.44145 .08786 L
.40998 .0904 L
.38074 .09427 L
.35376 .09959 L
.32901 .10651 L
.30647 .11517 L
.28608 .1257 L
.2678 .13815 L
.25156 .15249 L
.2373 .1686 L
.22498 .18624 L
.21455 .20511 L
.20596 .22484 L
.19918 .24506 L
.19421 .26538 L
.19105 .2855 L
.18973 .30514 L
.19031 .32408 L
.19286 .34216 L
.1975 .35926 L
.20434 .37528 L
Mistroke
.21351 .39019 L
.22514 .40393 L
.23932 .41651 L
.25608 .42791 L
.27538 .43814 L
.29708 .44721 L
.32092 .45513 L
.34657 .46191 L
.37361 .46756 L
.4016 .4721 L
.43007 .47551 L
.45859 .4778 L
.48676 .47894 L
.51425 .47891 L
.54077 .47768 L
.56609 .47519 L
.59005 .47141 L
.6125 .46628 L
.63337 .45976 L
.65258 .45184 L
.67009 .4425 L
.68588 .43181 L
.69993 .41984 L
.71223 .40672 L
.72278 .39263 L
.73158 .37778 L
.73862 .36238 L
.74389 .34667 L
.74738 .33087 L
.74904 .31521 L
.74885 .29985 L
.74676 .28497 L
.74271 .2707 L
.73666 .25714 L
.72855 .24438 L
.71836 .2325 L
.70609 .22154 L
.69178 .21153 L
.67552 .2025 L
.65745 .19448 L
.63779 .18747 L
.61678 .18149 L
.59471 .17655 L
.57191 .17266 L
.54868 .16983 L
.52535 .16807 L
.5022 .16741 L
.47951 .16786 L
.45751 .16946 L
.43639 .17222 L
Mistroke
.41633 .17616 L
.39745 .1813 L
.37986 .18764 L
.36366 .19516 L
.34889 .20382 L
.33562 .21354 L
.32389 .22424 L
.31372 .23578 L
.30514 .24802 L
.29818 .2608 L
.29286 .27394 L
.28921 .28726 L
.28725 .3006 L
.28702 .3138 L
.28854 .3267 L
.29184 .33919 L
.29696 .35116 L
.3039 .3625 L
.31267 .37315 L
.32323 .38305 L
.33554 .39213 L
.34951 .40036 L
.365 .40771 L
.38185 .41415 L
.39986 .41965 L
.41879 .42421 L
.4384 .4278 L
.45844 .4304 L
.47865 .432 L
.49877 .43258 L
.5186 .43212 L
.53791 .43061 L
.55653 .42803 L
.5743 .42439 L
.59108 .41967 L
.60676 .41389 L
.62125 .40709 L
.63448 .39931 L
.64637 .39062 L
.65687 .3811 L
.66595 .37088 L
.67356 .36006 L
.67968 .34878 L
.68426 .3372 L
.68729 .32546 L
.68874 .3137 L
.68858 .30205 L
.68678 .29063 L
.68334 .27958 L
.67824 .26897 L
Mistroke
.67148 .2589 L
.66309 .24944 L
.65311 .24065 L
.64162 .2326 L
.62869 .22531 L
.61447 .21883 L
.59911 .21319 L
.58279 .20841 L
.56571 .20451 L
.54808 .20152 L
.53013 .19946 L
.51206 .19834 L
.49409 .19818 L
.47641 .19898 L
.45921 .20077 L
.44263 .20354 L
.42684 .20729 L
.41194 .212 L
.39804 .21766 L
.38524 .22423 L
.37361 .23164 L
.36322 .23983 L
.35411 .24872 L
.34634 .25819 L
.33995 .26814 L
.33496 .27845 L
.33142 .28898 L
.32935 .29962 L
.32877 .31024 L
.3297 .32072 L
.33216 .33095 L
.33616 .34085 L
.34167 .35031 L
.3487 .35926 L
.35719 .36764 L
.3671 .37539 L
.37833 .38245 L
.39079 .38879 L
.40434 .39437 L
.41883 .39915 L
.43409 .40312 L
.44994 .40625 L
.46619 .40852 L
.48264 .40991 L
.49911 .41041 L
.51542 .41001 L
.53138 .40869 L
.54686 .40646 L
.5617 .40332 L
.57578 .39928 L
Mistroke
.58899 .39436 L
.60124 .38861 L
.61244 .38206 L
.62253 .37477 L
.63143 .36683 L
.63911 .35831 L
.64551 .34933 L
.6506 .33997 L
.65434 .33036 L
.65671 .32061 L
.65768 .31083 L
.65723 .30112 L
.65536 .29159 L
.65205 .28234 L
.64731 .27344 L
.64117 .26498 L
.63366 .25703 L
.62484 .24964 L
.61477 .24286 L
.60354 .23675 L
.59129 .23134 L
.57812 .22665 L
.5642 .22273 L
.5497 .2196 L
.53476 .21727 L
.51958 .21576 L
.50433 .2151 L
.48917 .21528 L
.47426 .21632 L
.45975 .21822 L
.44579 .22098 L
.43248 .22457 L
.41995 .22899 L
.40828 .23419 L
.39757 .24014 L
.38788 .24678 L
.37929 .25404 L
.37183 .26185 L
.36558 .27011 L
.36055 .27874 L
.35679 .28763 L
.35433 .29668 L
.35318 .30578 L
.35338 .31485 L
.35492 .32377 L
.35781 .33246 L
.36204 .34085 L
.3676 .34885 L
.37444 .35639 L
.38252 .36342 L
Mistroke
.39177 .36989 L
.4021 .37574 L
.41341 .38094 L
.42558 .38546 L
.43848 .38926 L
.45195 .39233 L
.46584 .39463 L
.48 .39615 L
.49426 .39687 L
.50847 .39679 L
.52247 .3959 L
.53613 .3942 L
.54932 .3917 L
.56191 .38839 L
.5738 .38432 L
.58489 .37951 L
.5951 .37399 L
.60435 .36782 L
.61259 .36107 L
.61974 .35379 L
.62577 .34608 L
.63063 .33802 L
.6343 .32971 L
.63673 .32123 L
.63791 .31268 L
.63782 .30416 L
.63645 .29575 L
.6338 .28755 L
.62988 .27962 L
.62471 .27204 L
.61833 .26489 L
.61078 .2582 L
.60212 .25205 L
.59245 .24647 L
.58185 .2415 L
.57043 .23718 L
.55833 .23353 L
.54568 .23059 L
.53262 .22838 L
.51929 .2269 L
.50586 .22619 L
.49245 .22623 L
.47923 .22706 L
.46631 .22865 L
.45382 .231 L
.44189 .23411 L
.4306 .23795 L
.42006 .24249 L
.41035 .2477 L
.40154 .25351 L
Mistroke
.39369 .25989 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{94, 0}, {0, 11}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo002@Ool30004Ool400000goo00000002Ool200000goo00000002001c
Ool0095oo`03001oogoo00Aoo`03001oogoo009oo`04001oo`000003Ool00`00Oomoo`1cOol0095o
o`<000Aoo`03001oogoo009oo`<000Eoo`03001oogoo079oo`00TGoo00@007ooOol000=oo`8000=o
o`04001oogoo0005Ool00`00Oomoo`1aOol0095oo`04001oogoo0002Ool200001Goo000007oo0000
0Woo00@007ooOol0009oo`03001oogoo075oo`00T7oo100027oo100017oo0P00M7oo003oOolKOol0
0?mooa]oo`00ogoo6goo003oOolKOol005=oo`8000Aoo`8000=oo`@001eoo`8000Aoo`8000Aoo`<0
01aoo`8000Aoo`8000Aoo`8001ioo`8000Aoo`8000Aoo`80029oo`<0015oo`00DWoo00@007ooOol0
00=oo`8000Aoo`03001oogoo01aoo`04001oogoo0003Ool20005Ool00`00Oomoo`0JOol01000Oomo
o`000goo0P000goo00@007ooOol001aoo`04001oogoo0003Ool20003Ool01000Oomoo`008Woo00<0
07ooOol047oo001BOol01000Oomoo`002Woo00<007ooOol06goo00@007ooOol000Qoo`@001]oo`04
001oogoo0008Ool01000Oomoo`0077oo00@007ooOol000Qoo`04001oogoo000ROol00`00Oomoo`0@
Ool0059oo`04001oogoo000;Ool00`00Oomoo`0JOol01000Oomoo`0027oo00<007oo000077oo00@0
07ooOol000Qoo`<001eoo`04001oogoo0009Ool2000SOol00`00Oomoo`0@Ool0059oo`04001oogoo
0008Ool01000Oomoo`0077oo00@007ooOol000Qoo`03001oo`0001aoo`04001oogoo0008Ool00`00
Oomoo`0MOol01000Oomoo`0027oo00@007ooOol0029oo`03001oogoo011oo`00Dgoo0P002Woo0P00
7Woo0P002Woo0P007Goo0P002Woo0`007Goo0P002Woo0P008Woo0P004Woo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol002moomX0015oo`00;goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol03goo000_Ool00`00Oomoo`0X
Ool00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0?
Ool002moo`03001oogoo0=Ioo`03001oogoo00moo`00;goo00<007ooOol0eWoo00<007ooOol03goo
000_Ool00`00Oomoo`3FOol00`00Oomoo`0?Ool002moo`03001oogoo0=Ioo`03001oogoo00moo`00
;goo0P00egoo00<007ooOol03goo000_Ool00`00Oomoo`3FOol00`00Oomoo`0?Ool002moo`03001o
ogoo0=Ioo`03001oogoo00moo`00;goo00<007ooOol0eWoo00<007ooOol03goo000_Ool00`00Oomo
o`3FOol00`00Oomoo`0?Ool002moo`03001oogoo0=Ioo`03001oogoo00moo`00;goo00<007ooOol0
eWoo00<007ooOol03goo000_Ool2003GOol00`00Oomoo`0?Ool002moo`03001oogoo0=Ioo`03001o
ogoo00moo`00;goo00<007ooOol0eWoo00<007ooOol03goo000_Ool00`00Oomoo`3FOol00`00Oomo
o`0?Ool002moo`03001oogoo0=Ioo`03001oogoo00moo`00;goo00<007ooOol0FWoo7`00GGoo00<0
07ooOol03goo000_Ool2001DOol7000OOolB001;Ool00`00Oomoo`0?Ool002moo`03001oogoo04eo
o`H003Qoo`P004=oo`03001oogoo00moo`00;goo00<007ooOol0Agoo1P00AWoo2@00>Woo00<007oo
Ool03goo000_Ool00`00Oomoo`13Ool4001EOol6000dOol00`00Oomoo`0?Ool002moo`03001oogoo
041oo`<005moo`<0035oo`03001oogoo00moo`0077oo0P0017oo0P000goo100017oo00<007ooOol0
?Woo0P00IGoo1000;Goo00<007ooOol03goo000KOol01000Oomoo`000goo0P0017oo00<007ooOol0
17oo00<007ooOol0?Goo00<007ooOol0JGoo0`00:Woo00<007ooOol03goo000KOol01000Oomoo`00
2Woo00<007ooOol00goo0P00?Goo00<007ooOol0KGoo10009Goo0P004Goo000KOol01000Oomoo`00
2goo00<007ooOol00Woo00<007ooOol0>Woo0P00M7oo0`008goo00<007ooOol03goo000KOol01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo03Qoo`8007Uoo`80025oo`03001oogoo00moo`00
77oo0P002Woo0P001Goo00<007ooOol0=Woo0P00OGoo0`007Woo00<007ooOol03goo000_Ool00`00
Oomoo`0eOol00`00Oomoo`20Ool2000LOol00`00Oomoo`0?Ool002moo`03001oogoo03Aoo`03001o
ogoo08=oo`03001oogoo01Uoo`03001oogoo00moo`00;goo00<007ooOol0<goo00<007ooOol0QGoo
00<007ooOol067oo00<007ooOol03goo000_Ool2000dOol00`00Oomoo`26Ool2000HOol00`00Oomo
o`0?Ool002moo`03001oogoo039oo`03001oogoo08Uoo`03001oogoo01Eoo`03001oogoo00moo`00
;goo00<007ooOol0<Goo00<007ooOol0Rgoo00<007ooOol057oo00<007ooOol03goo000_Ool00`00
Oomoo`0`Ool00`00Oomoo`0[OolJ0018Ool00`00Oomoo`0COol00`00Oomoo`0?Ool002moo`03001o
ogoo031oo`03001oogoo02Moo`@001Yoo`D004=oo`03001oogoo01=oo`03001oogoo00moo`00;goo
00<007ooOol0;goo00<007ooOol08goo1@008goo1@00?goo00<007ooOol04Woo00<007ooOol03goo
000_Ool00`00Oomoo`0_Ool00`00Oomoo`0OOol4000]Ool5000kOol00`00Oomoo`0AOol00`00Oomo
o`0?Ool002moo`8002moo`03001oogoo01eoo`<003Ioo`<003Qoo`03001oogoo015oo`03001oogoo
00moo`00;goo00<007ooOol0;Woo00<007ooOol077oo00<007ooOol0>Woo0P00=goo00<007ooOol0
47oo00<007ooOol03goo000_Ool00`00Oomoo`0]Ool00`00Oomoo`0KOol2000IOol9000MOol3000d
Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool002moo`03001oogoo02aoo`03001oogoo01]oo`03001o
ogoo019oo`L000Uoo`P001Qoo`<0039oo`03001oogoo00moo`03001oogoo00moo`00;goo00<007oo
Ool0:goo00<007ooOol06Woo0P003Woo1`0067oo10005goo00<007ooOol0;goo00<007ooOol03goo
00<007ooOol03goo000_Ool00`00Oomoo`0[Ool00`00Oomoo`0IOol00`00Oomoo`0;Ool3000SOol4
000DOol2000`Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool002moo`8002aoo`03001oogoo01Moo`80
00eoo`03001oogoo00aoo`h000ioo`<001=oo`03001oogoo02eoo`03001oogoo00ioo`03001oogoo
00moo`00;goo00<007ooOol0:Woo00<007ooOol05goo00<007ooOol02goo0P002Goo1P003Woo1P00
2goo0`004Goo00<007ooOol0;Goo00<007ooOol03Goo00<007ooOol03goo000_Ool00`00Oomoo`0Z
Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool20008Ool3000:Ool70009Ool4000:Ool2000@Ool00`00
Oomoo`0/Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool002moo`03001oogoo02Yoo`03001oogoo01Io
o`03001oogoo00Uoo`03001oogoo00Eoo`<000Moo`H000Moo`P000Eoo`8000Yoo`03001oogoo00io
o`03001oogoo02]oo`03001oogoo00eoo`03001oogoo00moo`00;goo00<007ooOol0:Goo00<007oo
Ool05Woo00<007ooOol027oo0P001Woo0P001Goo1@005Goo0`0017oo0`0027oo0P003goo00<007oo
Ool0:goo00<007ooOol037oo00<007ooOol03goo000LOol20004Ool20004Ool30004Ool00`00Oomo
o`0YOol00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`02Ool3000MOol2
0005Ool30007Ool00`00Oomoo`0=Ool00`00Oomoo`0ZOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool0
01]oo`04001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`0YOol00`00Oomoo`0DOol0
0`00Oomoo`08Ool00`00Oomoo`04Ool20003Ool2000ROol30005Ool00`00Oomoo`05Ool00`00Oomo
o`0=Ool00`00Oomoo`0YOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool001]oo`04001oogoo0008Ool4
0004Ool2000YOol00`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`04Ool01000Oomoogoo0P00
9goo0P0017oo00<007ooOol01Goo00<007ooOol037oo00<007ooOol0:Goo00<007ooOol02goo0P00
4Goo000KOol01000Oomoo`0027oo00<007oo00001Goo00<007ooOol0:7oo00<007ooOol057oo00<0
07ooOol01goo00<007ooOol017oo00D007ooOomoo`0002]oo`8000=oo`8000Ioo`03001oogoo00ao
o`03001oogoo02Qoo`03001oogoo00aoo`03001oogoo00moo`005Woo0`000Woo00@007ooOol000Qo
o`03001oo`0000Eoo`03001oogoo02Qoo`03001oogoo01=oo`03001oogoo00Moo`03001oogoo00Ao
o`05001oogooOol0000^Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomo
o`0WOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool001Moo`03001oogoo009oo`8000Yoo`8000Eoo`03
001oogoo02Moo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo00=oo`05001oogooOol0000_
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0WOol00`00Oomoo`0<
Ool00`00Oomoo`0?Ool001Moo`<001Eoo`03001oogoo02Moo`03001oogoo01Aoo`03001oogoo00Io
o`03001oogoo00=oo`03001oogoo03=oo`8000=oo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo02Ioo`03001oogoo00aoo`03001oogoo00moo`005goo00@007ooOol001Aoo`03001oogoo02Mo
o`03001oogoo01=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo03Ioo`05001oogooOol0
0006Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool001Moo`04
001oogoo000DOol00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`02Ool0
0`00Oomoo`0fOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0WOol0
0`00Oomoo`0;Ool00`00Oomoo`0?Ool001Ioo`@001Eoo`8002Moo`03001oogoo01=oo`03001oogoo
00Moo`03001oogoo009oo`03001oogoo03Qoo`05001oogooOol00006Ool00`00Oomoo`0;Ool00`00
Oomoo`0VOol00`00Oomoo`0;Ool00`00Oomoo`0?Ool001Moo`@001Aoo`03001oogoo02Ioo`03001o
ogoo01=oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo03Qoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo00moo`0067oo
00<007ooOol057oo00<007ooOol09Woo00<007ooOol04goo00<007ooOol01Woo00<007ooOol00Woo
00<007ooOol0>Woo00D007ooOomoo`0000Ioo`03001oogoo00Yoo`03001oogoo02Ioo`03001oogoo
00]oo`03001oogoo00moo`0067oo00<007ooOol057oo00<007ooOol09Woo00<007ooOol04goo00<0
07ooOol01Woo00<007ooOol00Woo00<007ooOol0>Woo00D007ooOomoo`0000Ioo`03001oogoo00Yo
o`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo00moo`0067oo0P005Goo00<007ooOol09Woo
00<007ooOol04Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0>Woo00D007ooOomoo`00
00Moo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo00moo`005goo0P00
00=oo`0000004goo00<007ooOol09Woo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol0>goo00D007ooOomoo`0000Ioo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo
00]oo`03001oogoo00moo`00;goo0P009goo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol0>goo00D007ooOomoo`0000Ioo`03001oogoo00Yoo`03001oogoo02Eoo`03001o
ogoo00]oo`03001oogoo00moo`005goo100057oo00<007ooOol09Woo00<007ooOol04Woo00<007oo
Ool01Woo00<007ooOol00goo00<007ooOol0>goo00D007ooOomoo`0000Ioo`03001oogoo00Yoo`03
001oogoo02Eoo`03001oogoo00]oo`03001oogoo00moo`005Woo00<007ooOol05Woo00<007ooOol0
9Woo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0>goo00D007ooOomo
o`0000Ioo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo00moo`005Woo
00<007ooOol05Woo00<007ooOol09Woo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol0>Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol09Goo
00<007ooOol02goo00<007ooOol03goo000FOol00`00Oomoo`0FOol00`00Oomoo`0VOol00`00Oomo
o`0COol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0jOol00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`0;Ool00`00Oomoo`0?Ool001Ioo`05
001oogooOol0000DOol00`00Oomoo`0VOol00`00Oomoo`0COol00`00Oomoo`06Ool00`00Oomoo`02
Ool00`00Oomoo`0jOol01@00Oomoogoo00001Woo00<007ooOol02Woo00<007ooOol09Woo00<007oo
Ool02goo00<007ooOol03goo000GOol4000DOol00`00Oomoo`0VOol00`00Oomoo`0COol00`00Oomo
o`06Ool00`00Oomoo`03Ool00`00Oomoo`0iOol01@00Oomoogoo00001Woo00<007ooOol02Woo00<0
07ooOol09Woo00<007ooOol02goo00<007ooOol03goo000GOol4000DOol2000XOol00`00Oomoo`0B
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0gOol01@00Oomoogoo00001goo00<007oo
Ool02Woo00<007ooOol09Woo00<007ooOol02goo00<007ooOol03goo000HOol00`00Oomoo`0DOol0
0`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0gOol0
1@00Oomoogoo00001goo00<007ooOol02Woo00<007ooOol09Woo00<007ooOol02goo00<007ooOol0
3goo000IOol00`00Oomoo`0COol00`00Oomoo`0WOol00`00Oomoo`0COol00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`0eOol01@00Oomoogoo00001goo00<007ooOol02goo00<007ooOol09Woo
00<007ooOol02goo00<007ooOol03goo000JOol00`00Oomoo`0BOol00`00Oomoo`0XOol00`00Oomo
o`0BOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool001Moo`04
001oogoo000DOol00`00Oomoo`0XOol00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`02Ool2
000cOol00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomo
o`0<Ool00`00Oomoo`0?Ool001Qoo`80009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo02Qoo`03
001oogoo01Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo02ioo`8000Aoo`03001oogoo
00Eoo`03001oogoo00]oo`03001oogoo02Moo`03001oogoo00aoo`03001oogoo00moo`006goo00@0
07ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`0XOol00`00Oomoo`0EOol00`00Oomo
o`07Ool20005Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`0WOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool001]oo`04001oogoo0008Ool01000Oomo
o`0017oo0P00:Woo00<007ooOol05Goo00<007ooOol027oo00<007ooOol00goo0P00:goo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0:7oo00<007ooOol02goo0P004Goo
000KOol01000Oomoo`0027oo0`001Goo00<007ooOol0:Goo00<007ooOol05Goo00<007ooOol02Goo
0P001Goo0`009Woo0P0017oo0P0027oo00<007ooOol037oo00<007ooOol0:7oo00<007ooOol037oo
00<007ooOol03goo000KOol01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol0:Goo00<007oo
Ool05Woo00<007ooOol02Woo0P001Woo0P008Woo0P001Goo00<007ooOol01Woo0P003goo00<007oo
Ool0:7oo00<007ooOol037oo00<007ooOol03goo000LOol2000:Ool30004Ool00`00Oomoo`0ZOol0
0`00Oomoo`0FOol2000<Ool00`00Oomoo`05Ool3000MOol20006Ool00`00Oomoo`06Ool00`00Oomo
o`0>Ool00`00Oomoo`0YOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool002moo`03001oogoo02]oo`03
001oogoo01Moo`03001oogoo00Yoo`<000Moo`<001Aoo`H000Ioo`8000Qoo`03001oogoo00moo`03
001oogoo02Uoo`03001oogoo00aoo`03001oogoo00moo`00;goo00<007ooOol0;7oo00<007ooOol0
5goo0`0037oo0`001goo2@001Goo1P002Goo0`002Goo00<007ooOol03goo00<007ooOol0:Woo00<0
07ooOol037oo00<007ooOol03goo000_Ool00`00Oomoo`0]Ool00`00Oomoo`0IOol2000=Ool3000=
Ool5000<Ool3000:Ool2000BOol00`00Oomoo`0ZOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool002mo
o`8002moo`03001oogoo01Yoo`03001oogoo00eoo`<001Qoo`<000aoo`03001oogoo015oo`03001o
ogoo02]oo`03001oogoo00aoo`03001oogoo00moo`00;goo00<007ooOol0;goo00<007ooOol06Woo
0`003goo2`000Woo2`003Goo0P004goo00<007ooOol0;7oo00<007ooOol037oo00<007ooOol03goo
000_Ool00`00Oomoo`0`Ool00`00Oomoo`0LOol3000GOol2000EOol3000DOol00`00Oomoo`0]Ool0
0`00Oomoo`0<Ool00`00Oomoo`0?Ool002moo`03001oogoo035oo`8001moo`8002Yoo`8001Ioo`03
001oogoo02eoo`03001oogoo00eoo`03001oogoo00moo`00;goo00<007ooOol0<goo00<007ooOol0
7Woo0`009Goo0P005Woo0P00<7oo00<007ooOol03Goo00<007ooOol03goo000_Ool00`00Oomoo`0d
Ool2000QOol8000EOol8000GOol00`00Oomoo`0`Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool002mo
o`8003Moo`8002MooaD001ioo`03001oogoo035oo`03001oogoo00eoo`03001oogoo00moo`00;goo
00<007ooOol0>7oo00<007ooOol0EWoo00<007ooOol0<Woo00<007ooOol03Goo00<007ooOol03goo
000_Ool00`00Oomoo`0iOol2001EOol00`00Oomoo`0cOol00`00Oomoo`0=Ool00`00Oomoo`0?Ool0
02moo`03001oogoo03]oo`80055oo`8003Ioo`03001oogoo00eoo`03001oogoo00moo`00;goo00<0
07ooOol0?Goo1000Bgoo0P00=goo00<007ooOol03Woo00<007ooOol03goo000_Ool00`00Oomoo`11
Ool40014Ool3000iOol00`00Oomoo`0>Ool00`00Oomoo`0?Ool002moo`03001oogoo04Eoo`<003io
o`<003aoo`03001oogoo00ioo`03001oogoo00moo`00;goo0P00BGoo1000=goo0`00?goo00<007oo
Ool03Woo00<007ooOol03goo000_Ool00`00Oomoo`1<Ool6000^Ool30012Ool00`00Oomoo`0>Ool0
0`00Oomoo`0?Ool002moo`03001oogoo059oo`H002=oo`D004Eoo`03001oogoo00ioo`03001oogoo
00moo`00;goo00<007ooOol0F7oo8`00BWoo00<007ooOol03Woo00<007ooOol03goo000_Ool00`00
Oomoo`35Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool001aoo`8000Aoo`8000Aoo`8000Eoo`03001o
ogoo0<Aoo`03001oogoo00moo`03001oogoo00moo`006goo00@007ooOol000=oo`8000=oo`04001o
ogoo0004Ool00`00Oomoo`34Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool001]oo`04001oogoo0008
Ool01000Oomoo`0017oo0P00aGoo00<007ooOol03Woo0P004Goo000KOol01000Oomoo`002Goo0P00
1Goo00<007ooOol0a7oo00<007ooOol03goo00<007ooOol03goo000KOol01000Oomoo`0027oo00@0
07ooOol000Aoo`03001oogoo0<Aoo`03001oogoo00moo`03001oogoo00moo`0077oo0P002Woo0P00
1Goo00<007ooOol0`goo00<007ooOol047oo00<007ooOol03goo000_Ool00`00Oomoo`33Ool00`00
Oomoo`0@Ool00`00Oomoo`0?Ool002moo`03001oogoo0<=oo`03001oogoo011oo`03001oogoo00mo
o`00;goo00<007ooOol0`Woo00<007ooOol04Goo00<007ooOol03goo000_Ool20033Ool00`00Oomo
o`0AOol00`00Oomoo`0?Ool002moo`03001oogoo0<9oo`03001oogoo015oo`03001oogoo00moo`00
;goo00<007ooOol0`Woo00<007ooOol04Goo00<007ooOol03goo000_Ool00`00Oomoo`32Ool00`00
Oomoo`0AOol00`00Oomoo`0?Ool002moo`03001oogoo0<5oo`03001oogoo019oo`03001oogoo00mo
o`00;goo00<007ooOol0`Goo00<007ooOol04Woo00<007ooOol03goo000_Ool20032Ool00`00Oomo
o`0BOol00`00Oomoo`0?Ool002moo`03001oogoo0=Ioo`03001oogoo00moo`00;goo00<007ooOol0
eWoo00<007ooOol03goo000_Ool00`00Oomoo`3FOol00`00Oomoo`0?Ool002moo`03001oogoo0=Io
o`03001oogoo00moo`00;goo00<007ooOol0eWoo00<007ooOol03goo000_Ool00`00Oomoo`3FOol0
0`00Oomoo`0?Ool002moo`800=Moo`03001oogoo00moo`00;goo00<007ooOol0eWoo00<007ooOol0
3goo000_Ool00`00Oomoo`3FOol00`00Oomoo`0?Ool002moo`03001oogoo0=Ioo`03001oogoo00mo
o`00;goo00<007ooOol0eWoo00<007ooOol03goo000WOol30005Ool00`00Oomoo`0XOol00`00Oomo
o`0YOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0?Ool002Qoo`03
001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00moo`00:7oo00<007ooOol017oofP004Goo000XOol00`00Oomoo`3_
Ool002Qoo`03001oogoo0>moo`009goo0P00lGoo001MOol4002iOol005ioo`03001oogoo0;Uoo`00
>Goo0`0017oo0P0000Aoo`00001oo`D00003Ool00000008000=oo`@000Moo`@0009oo`D0009oo`<0
00=oo`<000Uoo`<0009oo`@000Qoo`@000Qoo`D00004Ool00000Ool20002Ool500000goo00000002
00000goo000000020007Ool50002Ool500000goo000000020002Ool01000Oomoo`000Woo1@0000Ao
o`00001oo`8000Ioo`<000Aoo`D0009oo`<0009oo`04001oogoo000LOol003Yoo`03001oogoo00=o
o`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol000]oo`05001oogooOol00003Ool01@00
Oomoogoo00000goo00@007ooOol0009oo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomo
o`07Ool01@00Oomoogoo000027oo00@007ooOol0009oo`04001oogoo0002Ool01`00Oomoogoo001o
o`0000Ioo`03001oogoo00Qoo`07001oogooOol007oo00000Woo00D007ooOomoo`0000Aoo`@000Ao
o`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo00<0
07oo00000`0077oo000jOol30003Ool01000Oomoo`000Woo10000Woo10000Woo1@001goo00D007oo
Oomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`002Woo00D007ooOomoo`00009oo`03001o
ogoo00Moo`03001oo`00008000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00H007ooOomoo`00
Ool50002Ool00`00Oomoo`08Ool01P00Oomoogoo001oo`@000=oo`03001oogoo009oo`@000Aoo`05
001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01@00Oomoogoo00000goo00<007oo
00000`0077oo000jOol01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0005Ool01@00Oomo
ogoo00001goo00D007ooOomoo`0000=oo`05001oogooOol00003Ool01000Oomoo`002Woo00D007oo
Oomoo`00009oo`03001oogoo00Moo`03001oogoo00Yoo`04001oogoo0002Ool01000Oomoo`000Woo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`020009Ool01@00Oomoogoo000017oo00@007ooOomo
o`8000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007ooOol01Woo0`001Goo00D007oo
Oomoo`0000=oo`03001oo`00009oo`03001oogoo01Yoo`00>Woo00@007ooOol0009oo`@000=oo`<0
009oo`@000=oo`<000Moo`D000Aoo`03001oogoo009oo`<0009oo`@000Uoo`<0009oo`@000Moo`05
001oogooOol00007Ool2000017oo000007oo1@000goo10000Woo0`000Woo0P0000=oo`0000001goo
00D007ooOomoo`00009oo`<0009oo`800003Ool000000080009oo`80009oo`80009oo`D000Qoo`03
001oogoo00Eoo`03001oogoo009oo`<00003Ool00000009oo`8001]oo`00>Goo10000goo00<007oo
Ool08goo00<007ooOol027oo00<007ooOol03goo00<007ooOol027oo100067oo00<007ooOol047oo
1@009Goo1@0017oo00<007ooOol09goo000oOol2000SOol3000:Ool00`00Oomoo`0?Ool3000SOol2
000]Ool00`00Oomoo`0COol3000YOol00?mooa]oo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.216715, -0.176299, 
  0.00459312, 0.00743182}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -14 ]
[-0.01875 .30902 -18 14 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -113 0 ]
[.5 .63053 113 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrR2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10 translate
90 rotate
-75 -10 translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrC2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
99.000000 13.000000 moveto
(plot) show
129.000000 13.000000 moveto
(of) show
147.000000 13.000000 moveto
(G) show
159.000000 13.000000 moveto
(under) show
195.000000 13.000000 moveto
(Replicator) show
261.000000 13.000000 moveto
(Flow) show
285.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.0005 w
.9 .55623 m
.90691 .55159 L
.91327 .54657 L
.9191 .54114 L
.92445 .53528 L
.92934 .52896 L
.93381 .52218 L
.93788 .51491 L
.94158 .50713 L
.94494 .49883 L
.94798 .49 L
.95072 .48064 L
.95319 .47074 L
.9554 .4603 L
.95737 .44934 L
.95911 .43787 L
.96064 .42591 L
.96197 .41348 L
.96312 .40063 L
.96408 .38739 L
.96488 .37381 L
.96551 .35994 L
.96598 .34584 L
.96629 .33157 L
.96645 .3172 L
.96646 .30279 L
.96632 .2884 L
.96603 .27412 L
.96558 .25999 L
.96497 .24609 L
.9642 .23246 L
.96326 .21918 L
.96214 .20627 L
.96083 .19378 L
.95933 .18176 L
.95761 .17022 L
.95568 .15919 L
.9535 .14868 L
.95107 .13871 L
.94837 .12927 L
.94537 .12037 L
.94205 .112 L
.9384 .10415 L
.93438 .09681 L
.92997 .08996 L
.92514 .08358 L
.91985 .07766 L
.91409 .07217 L
.9078 .0671 L
.90097 .06241 L
Mistroke
.89355 .05809 L
.88551 .05412 L
.87681 .05047 L
.86742 .04712 L
.85731 .04406 L
.84644 .04127 L
.83478 .03872 L
.8223 .0364 L
.80899 .0343 L
.79482 .03239 L
.77979 .03068 L
.76389 .02913 L
.74712 .02774 L
.7295 .02651 L
.71105 .02541 L
.6918 .02445 L
.67179 .02361 L
.65109 .02288 L
.62975 .02227 L
.60784 .02177 L
.58546 .02137 L
.56269 .02106 L
.53963 .02085 L
.51639 .02074 L
.49308 .02072 L
.46979 .0208 L
.44665 .02097 L
.42375 .02123 L
.4012 .02159 L
.37909 .02206 L
.35751 .02262 L
.33654 .0233 L
.31624 .02409 L
.29668 .025 L
.2779 .02604 L
.25994 .02722 L
.24282 .02855 L
.22657 .03003 L
.21118 .03167 L
.19666 .0335 L
.18301 .03552 L
.17019 .03775 L
.1582 .04021 L
.14701 .0429 L
.1366 .04585 L
.12692 .04907 L
.11794 .0526 L
.10964 .05644 L
.10197 .06061 L
.0949 .06515 L
Mistroke
.0884 .07006 L
.08243 .07538 L
.07695 .08112 L
.07194 .08731 L
.06736 .09397 L
.06319 .10111 L
.05939 .10875 L
.05594 .11691 L
.05282 .12559 L
.04999 .13481 L
.04745 .14456 L
.04518 .15485 L
.04314 .16567 L
.04134 .17701 L
.03975 .18884 L
.03837 .20114 L
.03717 .21388 L
.03616 .22702 L
.03532 .24051 L
.03465 .25431 L
.03414 .26835 L
.03378 .28258 L
.03358 .29694 L
.03353 .31134 L
.03363 .32574 L
.03388 .34006 L
.03428 .35424 L
.03485 .36821 L
.03557 .38191 L
.03647 .3953 L
.03754 .40831 L
.03879 .42091 L
.04024 .43307 L
.0419 .44474 L
.04377 .45591 L
.04588 .46656 L
.04824 .47668 L
.05087 .48626 L
.05379 .4953 L
.05702 .50382 L
.06058 .51181 L
.06449 .51928 L
.0688 .52627 L
.07351 .53277 L
.07867 .53881 L
.0843 .54442 L
.09044 .5496 L
.09712 .55439 L
.10438 .55881 L
.11225 .56287 L
Mistroke
.12076 .56661 L
.12996 .57003 L
.13988 .57317 L
.15054 .57603 L
.16199 .57865 L
.17424 .58102 L
.18732 .58318 L
.20126 .58514 L
.21605 .58691 L
.23172 .5885 L
.24826 .58993 L
.26565 .59121 L
.28388 .59234 L
.30291 .59334 L
.32272 .59421 L
.34324 .59497 L
.36441 .59561 L
.38617 .59614 L
.40844 .59657 L
.43111 .5969 L
.4541 .59713 L
.4773 .59727 L
.50061 .59732 L
.52391 .59727 L
.5471 .59712 L
.57008 .59688 L
.59273 .59655 L
.61497 .59611 L
.6367 .59558 L
.65785 .59493 L
.67833 .59417 L
.6981 .59329 L
.71709 .59229 L
.73528 .59115 L
.75263 .58986 L
.76911 .58842 L
.78474 .58682 L
.79949 .58505 L
.81338 .58308 L
.82642 .58091 L
.83863 .57852 L
.85003 .57589 L
.86066 .57301 L
.87053 .56986 L
.8797 .56642 L
.88818 .56267 L
.89601 .55859 L
.90324 .55415 L
.90989 .54934 L
.916 .54413 L
Mistroke
.92161 .53851 L
.92674 .53244 L
.93144 .52591 L
.93572 .51891 L
.93962 .5114 L
.94316 .50339 L
.94637 .49485 L
.94927 .48578 L
.95188 .47617 L
.95423 .46602 L
.95633 .45534 L
.95819 .44414 L
.95984 .43245 L
.96128 .42027 L
.96252 .40764 L
.96358 .39461 L
.96447 .38121 L
.96518 .36749 L
.96574 .3535 L
.96614 .33932 L
.96638 .32499 L
.96648 .31059 L
.96642 .29619 L
.96621 .28184 L
.96584 .26762 L
.96532 .25359 L
.96464 .23981 L
.96379 .22633 L
.96277 .21321 L
.96156 .20049 L
.96017 .18821 L
.95857 .17641 L
.95676 .1651 L
.95471 .15431 L
.95242 .14404 L
.94987 .13432 L
.94703 .12513 L
.94389 .11647 L
.94042 .10834 L
.9366 .10073 L
.93241 .09361 L
.92781 .08698 L
.92277 .08082 L
.91727 .07509 L
.91127 .0698 L
.90474 .0649 L
.89764 .06039 L
.88995 .05623 L
.88161 .05241 L
.8726 .0489 L
Mistroke
.86288 .04569 L
.85242 .04275 L
.84119 .04007 L
.82916 .03763 L
.8163 .03541 L
.8026 .0334 L
.78804 .03158 L
.77261 .02995 L
.75631 .02847 L
.73915 .02716 L
.72114 .02599 L
.70232 .02495 L
.68272 .02405 L
.66239 .02326 L
.64138 .02259 L
.61977 .02203 L
.59764 .02157 L
.57507 .02121 L
.55215 .02096 L
.529 .02079 L
.50571 .02072 L
.4824 .02075 L
.45916 .02086 L
.43612 .02108 L
.41337 .02138 L
.39101 .02179 L
.36913 .0223 L
.34782 .02292 L
.32715 .02365 L
.30718 .02449 L
.28797 .02546 L
.26957 .02657 L
.25199 .02781 L
.23527 .0292 L
.21941 .03076 L
.20442 .03249 L
.1903 .0344 L
.17703 .03652 L
.1646 .03885 L
.15298 .04141 L
.14215 .04422 L
.13207 .04729 L
.12272 .05065 L
.11406 .05432 L
.10605 .05831 L
.09866 .06264 L
.09186 .06735 L
.0856 .07245 L
.07986 .07796 L
.0746 .0839 L
Mistroke
.06979 .0903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{94, 0}, {0, 11}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo002?Ool30004Ool400000goo00000002Ool200000goo00000002001d
Ool0091oo`03001oogoo00Aoo`03001oogoo009oo`04001oo`000003Ool00`00Oomoo`1dOol0091o
o`<000Aoo`03001oogoo009oo`<000Eoo`03001oogoo07=oo`00T7oo00@007ooOol000=oo`8000=o
o`04001oogoo0005Ool00`00Oomoo`1bOol0091oo`04001oogoo0002Ool200001Goo000007oo0000
0Woo00@007ooOol0009oo`03001oogoo079oo`00Sgoo100027oo100017oo0P00MGoo003oOolKOol0
0?mooa]oo`00ogoo6goo003oOolKOol005=oo`8000Aoo`8000=oo`@001aoo`8000Aoo`8000Aoo`<0
01eoo`8000Aoo`8000Aoo`8001eoo`8000Aoo`8000Aoo`8002=oo`<0015oo`00DWoo00@007ooOol0
00=oo`8000Aoo`03001oogoo01]oo`04001oogoo0003Ool20005Ool00`00Oomoo`0KOol01000Oomo
o`000goo0P000goo00@007ooOol001]oo`04001oogoo0003Ool20003Ool01000Oomoo`008goo00<0
07ooOol047oo001BOol01000Oomoo`002Woo00<007ooOol06Woo00@007ooOol000Qoo`@001aoo`04
001oogoo0008Ool01000Oomoo`006goo00@007ooOol000Qoo`04001oogoo000SOol00`00Oomoo`0@
Ool0059oo`04001oogoo000;Ool00`00Oomoo`0IOol01000Oomoo`0027oo00<007oo00007Goo00@0
07ooOol000Qoo`<001aoo`04001oogoo0009Ool2000TOol00`00Oomoo`0@Ool0059oo`04001oogoo
0008Ool01000Oomoo`006goo00@007ooOol000Qoo`03001oo`0001eoo`04001oogoo0008Ool00`00
Oomoo`0LOol01000Oomoo`0027oo00@007ooOol002=oo`03001oogoo011oo`00Dgoo0P002Woo0P00
7Goo0P002Woo0P007Woo0P002Woo0`0077oo0P002Woo0P008goo0P004Woo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol002ioom/0015oo`00;Woo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol03goo000^Ool00`00Oomoo`0Y
Ool00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0?
Ool002ioo`03001oogoo0=Moo`03001oogoo00moo`00;Woo00<007ooOol0egoo00<007ooOol03goo
000^Ool00`00Oomoo`10OomE0012Ool00`00Oomoo`0?Ool002ioo`03001oogoo031ooa80055ooa80
039oo`03001oogoo00moo`00;Woo0P00:Woo2@00LGoo30009goo0P004Goo000^Ool00`00Oomoo`0Q
Ool90023Ool7000SOol00`00Oomoo`0?Ool002ioo`03001oogoo01eoo`H0091oo`D001moo`03001o
ogoo00moo`00;Woo00<007ooOol06Woo1@00V7oo1@006goo00<007ooOol03goo000^Ool00`00Oomo
o`0GOol4002POol3000IOol00`00Oomoo`0?Ool002ioo`03001oogoo01Eoo`<00:Eoo`@001Ioo`03
001oogoo00moo`00;Woo00<007ooOol04goo0`00ZWoo0P005Goo00<007ooOol03goo000^Ool2000B
Ool3002]Ool3000BOol2000AOol002ioo`03001oogoo011oo`800;5oo`80019oo`03001oogoo00mo
o`00;Woo00<007ooOol047oo00<007ooOol0/Goo00<007ooOol047oo00<007ooOol03goo000^Ool0
0`00Oomoo`0>Ool2002eOol2000@Ool00`00Oomoo`0?Ool002ioo`03001oogoo00eoo`800;Moo`80
00moo`03001oogoo00moo`00;Woo00<007ooOol03Goo00<007ooOol0]goo00<007ooOol03Goo00<0
07ooOol03goo000^Ool2000=Ool2002iOol2000=Ool2000AOol002ioo`03001oogoo00aoo`03001o
ogoo0;Uoo`8000eoo`03001oogoo00moo`00;Woo00<007ooOol02goo00<007ooOol0^goo00<007oo
Ool02goo00<007ooOol03goo000^Ool00`00Oomoo`0;Ool00`00Oomoo`2kOol00`00Oomoo`0;Ool0
0`00Oomoo`0?Ool002ioo`03001oogoo00Yoo`03001oogoo0;aoo`8000aoo`03001oogoo00moo`00
6goo0P0017oo0P000goo100017oo00<007ooOol02Woo00<007ooOol0_Goo00<007ooOol02Woo00<0
07ooOol03goo000JOol01000Oomoo`000goo0P0017oo00<007ooOol017oo00<007ooOol02Goo00<0
07ooOol0_goo00<007ooOol02Goo00<007ooOol03goo000JOol01000Oomoo`002Woo00<007ooOol0
0goo0P002Woo00<007ooOol0_goo00<007ooOol01goo0`004Goo000JOol01000Oomoo`002goo00<0
07ooOol00Woo00<007ooOol02Goo00<007ooOol0_goo0P002Woo00<007ooOol03goo000JOol01000
Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00Uoo`03001oogoo0<1oo`03001oogoo00Qoo`03
001oogoo00moo`006goo0P002Woo0P001Goo00<007ooOol027oo00<007ooOol0`Goo00<007ooOol0
27oo00<007ooOol03goo000^Ool00`00Oomoo`08Ool00`00Oomoo`31Ool00`00Oomoo`08Ool00`00
Oomoo`0?Ool002ioo`03001oogoo00Moo`03001oogoo0<9oo`8000Uoo`03001oogoo00moo`00;Woo
00<007ooOol01goo00<007ooOol0`Woo0P002Goo00<007ooOol03goo000^Ool20008Ool00`00Oomo
o`33Ool00`00Oomoo`06Ool2000AOol002ioo`03001oogoo00Moo`03001oogoo0<=oo`03001oogoo
00Moo`03001oogoo00moo`00;Woo00<007ooOol01goo00<007ooOol0`goo00<007ooOol01goo00<0
07ooOol03goo000^Ool00`00Oomoo`07Ool00`00Oomoo`33Ool20008Ool00`00Oomoo`0?Ool002io
o`03001oogoo00Ioo`03001oogoo0<Eoo`03001oogoo00Ioo`03001oogoo00moo`00;Woo00<007oo
Ool01Woo00<007ooOol0aGoo00<007ooOol01Woo00<007ooOol03goo000^Ool00`00Oomoo`06Ool0
0`00Oomoo`35Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool002ioo`8000Moo`03001oogoo0<Eoo`03
001oogoo00Eoo`80015oo`00;Woo00<007ooOol01Woo00<007ooOol0aGoo00<007ooOol01Woo00<0
07ooOol03goo000^Ool00`00Oomoo`05Ool00`00Oomoo`36Ool00`00Oomoo`06Ool00`00Oomoo`0?
Ool002ioo`03001oogoo00Eoo`03001oogoo0<Ioo`8000Moo`03001oogoo00moo`00;Woo00<007oo
Ool01Goo00<007ooOol0aWoo0P001goo00<007ooOol03goo000^Ool00`00Oomoo`05Ool00`00Oomo
o`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool002ioo`8000Ioo`03001oogoo0<Moo`03001oogoo
00Aoo`80015oo`00;Woo00<007ooOol01Goo00<007ooOol0agoo00<007ooOol01Goo00<007ooOol0
3goo000^Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool002io
o`03001oogoo00Eoo`03001oogoo0<Moo`03001oogoo00Eoo`03001oogoo00moo`00;Woo00<007oo
Ool01Goo00<007ooOol0agoo00<007ooOol01Goo00<007ooOol03goo000KOol20004Ool20004Ool3
0004Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool001Yoo`04
001oogoo0003Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomo
o`05Ool00`00Oomoo`0?Ool001Yoo`04001oogoo0008Ool40004Ool20006Ool00`00Oomoo`37Ool0
0`00Oomoo`03Ool3000AOol001Yoo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`05Ool0
0`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool001Eoo`<0009oo`04001oogoo0008Ool0
0`00Ool00005Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool0
01Ioo`03001oogoo009oo`8000Yoo`8000Eoo`03001oogoo00Eoo`03001oogoo0<Moo`03001oogoo
00Eoo`03001oogoo00moo`005Woo0`005Goo00<007ooOol01Goo00<007ooOol0agoo00<007ooOol0
1Goo00<007ooOol03goo000FOol01000Oomoo`0057oo00<007ooOol01Goo00<007ooOol0agoo00<0
07ooOol01Goo00<007ooOol03goo000FOol01000Oomoo`0057oo00<007ooOol01Goo00<007ooOol0
agoo00<007ooOol01Goo00<007ooOol03goo000EOol4000EOol20005Ool00`00Oomoo`38Ool00`00
Oomoo`04Ool2000AOol001Ioo`@001Aoo`03001oogoo00Aoo`03001oogoo0<Qoo`03001oogoo00Eo
o`03001oogoo00moo`005goo00<007ooOol057oo00<007ooOol017oo00<007ooOol0b7oo00<007oo
Ool01Goo00<007ooOol03goo000GOol00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`38Ool2
0006Ool00`00Oomoo`0?Ool001Moo`8001Eoo`03001oogoo00Aoo`03001oogoo0<Uoo`03001oogoo
00Aoo`03001oogoo00moo`005Woo0P0000=oo`0000004goo00<007ooOol017oo00<007ooOol0bGoo
00<007ooOol017oo00<007ooOol03goo000^Ool20005Ool00`00Oomoo`39Ool00`00Oomoo`03Ool2
000AOol001Ioo`@001Aoo`03001oogoo00Aoo`03001oogoo0<Uoo`03001oogoo00Aoo`03001oogoo
00moo`005Goo00<007ooOol05Woo00<007ooOol017oo00<007ooOol0bGoo00<007ooOol017oo00<0
07ooOol03goo000EOol00`00Oomoo`0FOol00`00Oomoo`04Ool00`00Oomoo`39Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool001Eoo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo0<Qoo`8000Io
o`03001oogoo00moo`005Goo00D007ooOomoo`0001Aoo`03001oogoo00Aoo`03001oogoo0<Qoo`80
00Ioo`03001oogoo00moo`005Woo100057oo00<007ooOol017oo00<007ooOol0b7oo00<007ooOol0
1Goo00<007ooOol03goo000FOol4000DOol20005Ool00`00Oomoo`38Ool00`00Oomoo`04Ool2000A
Ool001Moo`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo0<Qoo`03001oogoo00Eoo`03001o
ogoo00moo`0067oo00<007ooOol04goo00<007ooOol01Goo00<007ooOol0agoo00<007ooOol01Goo
00<007ooOol03goo000IOol00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomo
o`05Ool00`00Oomoo`0?Ool001Ioo`04001oogoo000DOol00`00Oomoo`05Ool00`00Oomoo`37Ool0
0`00Oomoo`05Ool00`00Oomoo`0?Ool001Moo`80009oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo
00Eoo`03001oogoo0<Moo`03001oogoo00Eoo`03001oogoo00moo`006Woo00@007ooOol000=oo`80
00=oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomo
o`0?Ool001Yoo`04001oogoo0008Ool01000Oomoo`0017oo0P001Woo00<007ooOol0agoo00<007oo
Ool00goo0`004Goo000JOol01000Oomoo`0027oo0`001Goo00<007ooOol01Goo00<007ooOol0agoo
00<007ooOol01Goo00<007ooOol03goo000JOol01000Oomoo`0027oo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol0agoo00<007ooOol01Goo00<007ooOol03goo000KOol2000:Ool30004Ool0
0`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool002ioo`03001oogoo
00Eoo`03001oogoo0<Moo`03001oogoo00Eoo`03001oogoo00moo`00;Woo00<007ooOol01Goo00<0
07ooOol0agoo00<007ooOol01Goo00<007ooOol03goo000^Ool00`00Oomoo`05Ool00`00Oomoo`37
Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool002ioo`8000Ioo`03001oogoo0<Moo`03001oogoo00Ao
o`80015oo`00;Woo00<007ooOol01Goo00<007ooOol0agoo00<007ooOol01Goo00<007ooOol03goo
000^Ool00`00Oomoo`05Ool00`00Oomoo`37Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool002ioo`03
001oogoo00Ioo`03001oogoo0<Eoo`8000Moo`03001oogoo00moo`00;Woo00<007ooOol01Woo00<0
07ooOol0aGoo00<007ooOol01Woo00<007ooOol03goo000^Ool00`00Oomoo`06Ool00`00Oomoo`35
Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool002ioo`8000Moo`03001oogoo0<Eoo`03001oogoo00Eo
o`80015oo`00;Woo00<007ooOol01Woo00<007ooOol0aGoo00<007ooOol01Woo00<007ooOol03goo
000^Ool00`00Oomoo`06Ool00`00Oomoo`35Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool002ioo`03
001oogoo00Ioo`03001oogoo0<Eoo`03001oogoo00Ioo`03001oogoo00moo`00;Woo00<007ooOol0
1Woo00<007ooOol0aGoo00<007ooOol01Woo00<007ooOol03goo000^Ool00`00Oomoo`07Ool00`00
Oomoo`33Ool20008Ool00`00Oomoo`0?Ool002ioo`03001oogoo00Moo`03001oogoo0<=oo`03001o
ogoo00Moo`03001oogoo00moo`00;Woo0P0027oo00<007ooOol0`goo00<007ooOol01Woo0P004Goo
000^Ool00`00Oomoo`07Ool00`00Oomoo`33Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool002ioo`03
001oogoo00Moo`03001oogoo0<=oo`03001oogoo00Moo`03001oogoo00moo`00;Woo00<007ooOol0
27oo00<007ooOol0`Goo0P002Goo00<007ooOol03goo000^Ool00`00Oomoo`08Ool00`00Oomoo`31
Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool001]oo`8000Aoo`8000Aoo`8000Eoo`03001oogoo00Qo
o`03001oogoo0<5oo`03001oogoo00Qoo`03001oogoo00moo`006Woo00@007ooOol000=oo`8000=o
o`04001oogoo0004Ool00`00Oomoo`08Ool00`00Oomoo`31Ool00`00Oomoo`08Ool00`00Oomoo`0?
Ool001Yoo`04001oogoo0008Ool01000Oomoo`0017oo0P002Woo00<007ooOol0_goo0P0027oo0`00
4Goo000JOol01000Oomoo`002Goo0P001Goo00<007ooOol02Goo00<007ooOol0_goo00<007ooOol0
2Goo00<007ooOol03goo000JOol01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00Yoo`03
001oogoo0;eoo`8000]oo`03001oogoo00moo`006goo0P002Woo0P001Goo00<007ooOol02Woo00<0
07ooOol0_Goo00<007ooOol02Woo00<007ooOol03goo000^Ool00`00Oomoo`0:Ool00`00Oomoo`2l
Ool2000<Ool00`00Oomoo`0?Ool002ioo`03001oogoo00]oo`03001oogoo0;]oo`03001oogoo00]o
o`03001oogoo00moo`00;Woo00<007ooOol02goo00<007ooOol0^Woo0P003Goo00<007ooOol03goo
000^Ool2000=Ool00`00Oomoo`2hOol2000=Ool2000AOol002ioo`03001oogoo00eoo`03001oogoo
0;Moo`03001oogoo00eoo`03001oogoo00moo`00;Woo00<007ooOol03Goo00<007ooOol0]Woo00<0
07ooOol03Woo00<007ooOol03goo000^Ool00`00Oomoo`0>Ool00`00Oomoo`2dOol2000@Ool00`00
Oomoo`0?Ool002ioo`03001oogoo00moo`800;=oo`80015oo`03001oogoo00moo`00;Woo00<007oo
Ool04Goo00<007ooOol0[Woo0P004goo00<007ooOol03goo000^Ool2000COol2002]Ool2000COol2
000AOol002ioo`03001oogoo01Aoo`800:Uoo`8001Ioo`03001oogoo00moo`00;Woo00<007ooOol0
5Woo00<007ooOol0YGoo00<007ooOol05Woo00<007ooOol03goo000^Ool00`00Oomoo`0GOol5002N
Ool4000IOol00`00Oomoo`0?Ool002ioo`03001oogoo01aoo`8009Uoo`<001eoo`03001oogoo00mo
o`00;Woo00<007ooOol07Woo1@00T7oo100087oo00<007ooOol03goo000^Ool00`00Oomoo`0SOol6
0024Ool6000TOol00`00Oomoo`0?Ool002ioo`8002Yoo`X0071oo`X002Uoo`80015oo`00;Woo00<0
07ooOol0<goo3`00DGoo4000=7oo00<007ooOol03goo000^Ool00`00Oomoo`12OomA0014Ool00`00
Oomoo`0?Ool002ioo`03001oogoo0=Moo`03001oogoo00moo`00;Woo00<007ooOol0egoo00<007oo
Ool03goo000VOol30005Ool00`00Oomoo`0YOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomo
o`0XOol00`00Oomoo`0YOol00`00Oomoo`0?Ool002Moo`03001oogoo00Aoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00moo`00
9goo00<007ooOol017oof`004Goo000WOol00`00Oomoo`3`Ool002Moo`03001oogoo0?1oo`009Woo
0P00lWoo001@Ool4001XOol4001JOol0055oo`03001oogoo06Uoo`03001oogoo05Yoo`00;7oo0`00
17oo0P0000Aoo`00001oo`D00003Ool00000008000=oo`@000Moo`@0009oo`D0009oo`<000=oo`<0
00Uoo`<0009oo`@000Qoo`@000Qoo`D00004Ool00000Ool20002Ool500000goo0000000200000goo
000000020007Ool20002Ool20002Ool400000goo000000020002Ool500000goo000000030002Ool3
0002Ool50002Ool30003Ool30002Ool40007Ool30004Ool50002Ool30002Ool01000Oomoo`004Goo
000]Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo000;Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo0002Ool00`00Oomoo`05Ool01@00Oomo
ogoo00000Woo00<007ooOol01goo00D007ooOomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`00
0Woo00L007ooOomoo`00Ool00006Ool00`00Oomoo`08Ool01000Ool000000Woo00<007ooOol00goo
00D007ooOomoo`0000=oo`03001oogoo00=oo`05001oogooOol00003Ool00`00Ool00002Ool01@00
Oomoogoo00000Woo00<007oo00000goo00@007ooOol000Yoo`03001oogoo00Eoo`05001oogooOol0
0003Ool00`00Ool00003000AOol002eoo`<000=oo`04001oogoo0002Ool40002Ool40002Ool50007
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000=oo`04001oogoo000:Ool01@00Oomoogoo0000
0Woo00<007ooOol01goo00<007oo00000P0027oo00@007ooOol0009oo`04001oogoo0002Ool01P00
Oomoogoo001oo`D0009oo`03001oogoo00Qoo`<000=oo`D00003Ool007oo009oo`05001oogooOol0
0005Ool01@00Oomoogoo00001Goo10000goo00<007ooOol00Woo00D007ooOomoo`00009oo`03001o
ogoo00Qoo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Ool00003000AOol002eoo`04001o
ogoo0002Ool01000Oomoo`001Goo00@007ooOol000Eoo`05001oogooOol00007Ool01@00Oomoogoo
00000goo00D007ooOomoo`0000=oo`04001oogoo000:Ool01@00Oomoogoo00000Woo00<007ooOol0
1goo00<007ooOol02Woo00@007ooOol0009oo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo008000Uoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`05001oogooOol0
0005Ool01@00Oomoogoo00000goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0002Ool20009Ool30005Ool01@00Oomoogoo00000goo00<007oo00000Woo00<007ooOol03goo000]
Ool01000Oomoo`000Woo10000goo0`000Woo10000goo0`001goo1@0017oo00<007ooOol00Woo0`00
0Woo10002Goo0`000Woo10001goo00D007ooOomoo`0000Moo`800004Ool00000Ool50003Ool40002
Ool30002Ool200000goo00000007Ool01000Oomoo`000goo0`0000=oo`0000000`0017oo00<007oo
Ool00Woo0P0017oo10000Woo0`000Woo10000goo0`000Woo0P0000=oo`0000001goo00<007ooOol0
1Goo00<007ooOol00Woo0`0000=oo`0000000Woo0P0047oo000/Ool40003Ool00`00Oomoo`0SOol0
0`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool4000HOol00`00Oomoo`0@Ool4000AOol0
0`00Oomoo`0DOol00`00Oomoo`0COol50004Ool00`00Oomoo`0LOol0039oo`8002=oo`<000Yoo`03
001oogoo00moo`<002=oo`8002Eoo`<000Eoo`03001oogoo00ioo`03001oogoo01Yoo`<001ioo`00
ogoo6goo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.214094, -0.176299, 
  0.00459312, 0.00743182}}]
}, Open  ]],

Cell["\<\
We can also look at the vector fields set-up by the two dynamics in \
this game.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DarwinFlowVectorField\)\)], "Input"],

Cell[BoxData[
    \("DarwinFlowVectorField[{G_, A_}] takes a 2x2 normal form game G and an \
accuracy (# of arrows in the vector field plot) A into a vector field plot of \
the Darwin flow set-up by G."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ReplicatorFlowVectorField\)\)], "Input"],

Cell[BoxData[
    \("ReplicatorFlowVectorField[{G_, A_}] takes a 2x2  normal form game G \
and an accuracy (# of arrows  in the vector field plot) A into a vector field \
plot  of the Replicator flow set-up by G."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(DarwinFlowVectorField[{G, 15}]\), 
    \(ReplicatorFlowVectorField[{G, 15}]\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .21429 -18 -4.5 ]
[-0.0125 .21429 0 4.5 ]
[-0.0125 .40476 -18 -4.5 ]
[-0.0125 .40476 0 4.5 ]
[-0.0125 .59524 -18 -4.5 ]
[-0.0125 .59524 0 4.5 ]
[-0.0125 .78571 -18 -4.5 ]
[-0.0125 .78571 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -14 ]
[-0.01875 .5 -18 14 ]
[ 0 1 .125 0 ]
[.5 1.0125 -107 0 ]
[.5 1.0125 107 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrR2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .21429 m
.00625 .21429 L
s
[(0.2)] -0.0125 .21429 1 0 Mshowa
0 .40476 m
.00625 .40476 L
s
[(0.4)] -0.0125 .40476 1 0 Mshowa
0 .59524 m
.00625 .59524 L
s
[(0.6)] -0.0125 .59524 1 0 Mshowa
0 .78571 m
.00625 .78571 L
s
[(0.8)] -0.0125 .78571 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(1)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10 translate
90 rotate
-75 -10 translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrC2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .99375 m
.02381 1 L
s
.21429 .99375 m
.21429 1 L
s
.40476 .99375 m
.40476 1 L
s
.59524 .99375 m
.59524 1 L
s
.78571 .99375 m
.78571 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.2619 .99625 m
.2619 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.45238 .99625 m
.45238 1 L
s
.5 .99625 m
.5 1 L
s
.54762 .99625 m
.54762 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.7381 .99625 m
.7381 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
gsave
.5 1.0125 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vector) show
105.000000 13.000000 moveto
(Field) show
141.000000 13.000000 moveto
(of) show
159.000000 13.000000 moveto
(G) show
171.000000 13.000000 moveto
(under) show
207.000000 13.000000 moveto
(Darwin) show
249.000000 13.000000 moveto
(Flow) show
273.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .09184 m
.02381 .15986 L
s
% Start of user PostScript
0 0.0714286 0 0.142857 MAarrowhead1
% End of user PostScript
.02381 .15986 m
.02381 .22266 L
s
% Start of user PostScript
0 0.142857 0 0.208791 MAarrowhead1
% End of user PostScript
.02381 .22789 m
.02381 .28545 L
s
% Start of user PostScript
0 0.214286 0 0.274725 MAarrowhead1
% End of user PostScript
.02381 .29592 m
.02381 .34825 L
s
% Start of user PostScript
0 0.285714 0 0.340659 MAarrowhead1
% End of user PostScript
.02381 .36395 m
.02381 .41104 L
s
% Start of user PostScript
0 0.357143 0 0.406593 MAarrowhead1
% End of user PostScript
.02381 .43197 m
.02381 .47384 L
s
% Start of user PostScript
0 0.428571 0 0.472527 MAarrowhead1
% End of user PostScript
.02381 .5 m
.02381 .53663 L
s
% Start of user PostScript
0 0.5 0 0.538462 MAarrowhead1
% End of user PostScript
.02381 .56803 m
.02381 .59942 L
s
% Start of user PostScript
0 0.571429 0 0.604396 MAarrowhead1
% End of user PostScript
.02381 .63605 m
.02381 .66222 L
s
% Start of user PostScript
0 0.642857 0 0.67033 MAarrowhead1
% End of user PostScript
.02381 .70408 m
.02381 .72501 L
s
% Start of user PostScript
0 0.714286 0 0.736264 MAarrowhead1
% End of user PostScript
.02381 .77211 m
.02381 .78781 L
s
% Start of user PostScript
0 0.785714 0 0.802198 MAarrowhead1
% End of user PostScript
.02381 .84014 m
.02381 .8506 L
s
% Start of user PostScript
0 0.857143 0 0.868132 MAarrowhead1
% End of user PostScript
.02381 .90816 m
.02381 .9134 L
s
% Start of user PostScript
0 0.928571 0 0.934066 MAarrowhead1
% End of user PostScript
.09184 .02381 m
.0866 .02381 L
s
% Start of user PostScript
0.0714286 0 0.0659341 0 MAarrowhead1
% End of user PostScript
.09184 .09184 m
.08703 .12323 L
s
% Start of user PostScript
0.0714286 0.0714286 0.0663866 0.104396 MAarrowhead1
% End of user PostScript
.09184 .15986 m
.08753 .19952 L
s
% Start of user PostScript
0.0714286 0.142857 0.0669078 0.1845 MAarrowhead1
% End of user PostScript
.09184 .22789 m
.08811 .26934 L
s
% Start of user PostScript
0.0714286 0.214286 0.0675147 0.257802 MAarrowhead1
% End of user PostScript
.09184 .29592 m
.08879 .33643 L
s
% Start of user PostScript
0.0714286 0.285714 0.0682303 0.328252 MAarrowhead1
% End of user PostScript
.09184 .36395 m
.08961 .40213 L
s
% Start of user PostScript
0.0714286 0.357143 0.0690867 0.397238 MAarrowhead1
% End of user PostScript
.09184 .43197 m
.0906 .46702 L
s
% Start of user PostScript
0.0714286 0.428571 0.0701299 0.465372 MAarrowhead1
% End of user PostScript
.09184 .5 m
.09184 .5314 L
s
% Start of user PostScript
0.0714286 0.5 0.0714286 0.532967 MAarrowhead1
% End of user PostScript
.09184 .56803 m
.09342 .59543 L
s
% Start of user PostScript
0.0714286 0.571429 0.0730897 0.6002 MAarrowhead1
% End of user PostScript
.09184 .63605 m
.09551 .65922 L
s
% Start of user PostScript
0.0714286 0.642857 0.0752896 0.667177 MAarrowhead1
% End of user PostScript
.09184 .70408 m
.09842 .72283 L
s
% Start of user PostScript
0.0714286 0.714286 0.078341 0.733968 MAarrowhead1
% End of user PostScript
.09184 .77211 m
.10272 .7863 L
s
% Start of user PostScript
0.0714286 0.785714 0.0828571 0.800617 MAarrowhead1
% End of user PostScript
.09184 .84014 m
.10974 .84967 L
s
% Start of user PostScript
0.0714286 0.857143 0.0902256 0.867158 MAarrowhead1
% End of user PostScript
.09184 .90816 m
.12323 .91297 L
s
% Start of user PostScript
0.0714286 0.928571 0.104396 0.933613 MAarrowhead1
% End of user PostScript
.09184 .97619 m
.15986 .97619 L
s
% Start of user PostScript
0.0714286 1. 0.142857 1. MAarrowhead1
% End of user PostScript
.15986 .02381 m
.1494 .02381 L
s
% Start of user PostScript
0.142857 0 0.131868 0 MAarrowhead1
% End of user PostScript
.15986 .09184 m
.15033 .10974 L
s
% Start of user PostScript
0.142857 0.0714286 0.132842 0.0902256 MAarrowhead1
% End of user PostScript
.15986 .15986 m
.15138 .18603 L
s
% Start of user PostScript
0.142857 0.142857 0.133947 0.17033 MAarrowhead1
% End of user PostScript
.15986 .22789 m
.15258 .25766 L
s
% Start of user PostScript
0.142857 0.214286 0.135213 0.245548 MAarrowhead1
% End of user PostScript
.15986 .29592 m
.15398 .3267 L
s
% Start of user PostScript
0.142857 0.285714 0.136676 0.318035 MAarrowhead1
% End of user PostScript
.15986 .36395 m
.15561 .39414 L
s
% Start of user PostScript
0.142857 0.357143 0.138387 0.388842 MAarrowhead1
% End of user PostScript
.15986 .43197 m
.15754 .46052 L
s
% Start of user PostScript
0.142857 0.428571 0.140415 0.458541 MAarrowhead1
% End of user PostScript
.15986 .5 m
.15986 .52616 L
s
% Start of user PostScript
0.142857 0.5 0.142857 0.527473 MAarrowhead1
% End of user PostScript
.15986 .56803 m
.16272 .59128 L
s
% Start of user PostScript
0.142857 0.571429 0.145854 0.595849 MAarrowhead1
% End of user PostScript
.15986 .63605 m
.1663 .65601 L
s
% Start of user PostScript
0.142857 0.642857 0.14962 0.663811 MAarrowhead1
% End of user PostScript
.15986 .70408 m
.17095 .72043 L
s
% Start of user PostScript
0.142857 0.714286 0.154493 0.731456 MAarrowhead1
% End of user PostScript
.15986 .77211 m
.17719 .78462 L
s
% Start of user PostScript
0.142857 0.785714 0.161046 0.798853 MAarrowhead1
% End of user PostScript
.15986 .84014 m
.18603 .84862 L
s
% Start of user PostScript
0.142857 0.857143 0.17033 0.866053 MAarrowhead1
% End of user PostScript
.15986 .90816 m
.19952 .91247 L
s
% Start of user PostScript
0.142857 0.928571 0.1845 0.933092 MAarrowhead1
% End of user PostScript
.15986 .97619 m
.22266 .97619 L
s
% Start of user PostScript
0.142857 1. 0.208791 1. MAarrowhead1
% End of user PostScript
.22789 .02381 m
.21219 .02381 L
s
% Start of user PostScript
0.214286 0 0.197802 0 MAarrowhead1
% End of user PostScript
.22789 .09184 m
.2137 .10272 L
s
% Start of user PostScript
0.214286 0.0714286 0.199383 0.0828571 MAarrowhead1
% End of user PostScript
.22789 .15986 m
.21538 .17719 L
s
% Start of user PostScript
0.214286 0.142857 0.201147 0.161046 MAarrowhead1
% End of user PostScript
.22789 .22789 m
.21726 .24882 L
s
% Start of user PostScript
0.214286 0.214286 0.203128 0.236264 MAarrowhead1
% End of user PostScript
.22789 .29592 m
.2194 .31855 L
s
% Start of user PostScript
0.214286 0.285714 0.205368 0.309474 MAarrowhead1
% End of user PostScript
.22789 .36395 m
.22183 .38692 L
s
% Start of user PostScript
0.214286 0.357143 0.207924 0.381265 MAarrowhead1
% End of user PostScript
.22789 .43197 m
.22463 .4543 L
s
% Start of user PostScript
0.214286 0.428571 0.210865 0.452015 MAarrowhead1
% End of user PostScript
.22789 .5 m
.22789 .52093 L
s
% Start of user PostScript
0.214286 0.5 0.214286 0.521978 MAarrowhead1
% End of user PostScript
.22789 .56803 m
.23173 .58698 L
s
% Start of user PostScript
0.214286 0.571429 0.218315 0.591333 MAarrowhead1
% End of user PostScript
.22789 .63605 m
.23631 .65258 L
s
% Start of user PostScript
0.214286 0.642857 0.223131 0.660208 MAarrowhead1
% End of user PostScript
.22789 .70408 m
.24189 .71781 L
s
% Start of user PostScript
0.214286 0.714286 0.228987 0.728698 MAarrowhead1
% End of user PostScript
.22789 .77211 m
.24882 .78274 L
s
% Start of user PostScript
0.214286 0.785714 0.236264 0.796872 MAarrowhead1
% End of user PostScript
.22789 .84014 m
.25766 .84742 L
s
% Start of user PostScript
0.214286 0.857143 0.245548 0.864787 MAarrowhead1
% End of user PostScript
.22789 .90816 m
.26934 .91189 L
s
% Start of user PostScript
0.214286 0.928571 0.257802 0.932485 MAarrowhead1
% End of user PostScript
.22789 .97619 m
.28545 .97619 L
s
% Start of user PostScript
0.214286 1. 0.274725 1. MAarrowhead1
% End of user PostScript
.29592 .02381 m
.27499 .02381 L
s
% Start of user PostScript
0.285714 0 0.263736 0 MAarrowhead1
% End of user PostScript
.29592 .09184 m
.27717 .09842 L
s
% Start of user PostScript
0.285714 0.0714286 0.266032 0.078341 MAarrowhead1
% End of user PostScript
.29592 .15986 m
.27957 .17095 L
s
% Start of user PostScript
0.285714 0.142857 0.268544 0.154493 MAarrowhead1
% End of user PostScript
.29592 .22789 m
.28219 .24189 L
s
% Start of user PostScript
0.285714 0.214286 0.271302 0.228987 MAarrowhead1
% End of user PostScript
.29592 .29592 m
.28509 .31162 L
s
% Start of user PostScript
0.285714 0.285714 0.274346 0.302198 MAarrowhead1
% End of user PostScript
.29592 .36395 m
.28831 .38037 L
s
% Start of user PostScript
0.285714 0.357143 0.277722 0.374393 MAarrowhead1
% End of user PostScript
.29592 .43197 m
.29189 .44835 L
s
% Start of user PostScript
0.285714 0.428571 0.281488 0.445772 MAarrowhead1
% End of user PostScript
.29592 .5 m
.29592 .5157 L
s
% Start of user PostScript
0.285714 0.5 0.285714 0.516484 MAarrowhead1
% End of user PostScript
.29592 .56803 m
.30047 .58252 L
s
% Start of user PostScript
0.285714 0.571429 0.290492 0.586644 MAarrowhead1
% End of user PostScript
.29592 .63605 m
.30565 .6489 L
s
% Start of user PostScript
0.285714 0.642857 0.295937 0.656344 MAarrowhead1
% End of user PostScript
.29592 .70408 m
.31162 .71491 L
s
% Start of user PostScript
0.285714 0.714286 0.302198 0.725654 MAarrowhead1
% End of user PostScript
.29592 .77211 m
.31855 .7806 L
s
% Start of user PostScript
0.285714 0.785714 0.309474 0.794632 MAarrowhead1
% End of user PostScript
.29592 .84014 m
.3267 .84602 L
s
% Start of user PostScript
0.285714 0.857143 0.318035 0.863324 MAarrowhead1
% End of user PostScript
.29592 .90816 m
.33643 .91121 L
s
% Start of user PostScript
0.285714 0.928571 0.328252 0.93177 MAarrowhead1
% End of user PostScript
.29592 .97619 m
.34825 .97619 L
s
% Start of user PostScript
0.285714 1. 0.340659 1. MAarrowhead1
% End of user PostScript
.36395 .02381 m
.33778 .02381 L
s
% Start of user PostScript
0.357143 0 0.32967 0 MAarrowhead1
% End of user PostScript
.36395 .09184 m
.34078 .09551 L
s
% Start of user PostScript
0.357143 0.0714286 0.332823 0.0752896 MAarrowhead1
% End of user PostScript
.36395 .15986 m
.34399 .1663 L
s
% Start of user PostScript
0.357143 0.142857 0.336189 0.14962 MAarrowhead1
% End of user PostScript
.36395 .22789 m
.34742 .23631 L
s
% Start of user PostScript
0.357143 0.214286 0.339792 0.223131 MAarrowhead1
% End of user PostScript
.36395 .29592 m
.3511 .30565 L
s
% Start of user PostScript
0.357143 0.285714 0.343656 0.295937 MAarrowhead1
% End of user PostScript
.36395 .36395 m
.35506 .37441 L
s
% Start of user PostScript
0.357143 0.357143 0.347813 0.368132 MAarrowhead1
% End of user PostScript
.36395 .43197 m
.35933 .44266 L
s
% Start of user PostScript
0.357143 0.428571 0.352295 0.439794 MAarrowhead1
% End of user PostScript
.36395 .5 m
.36395 .51047 L
s
% Start of user PostScript
0.357143 0.5 0.357143 0.510989 MAarrowhead1
% End of user PostScript
.36395 .56803 m
.36896 .57788 L
s
% Start of user PostScript
0.357143 0.571429 0.362404 0.581771 MAarrowhead1
% End of user PostScript
.36395 .63605 m
.37441 .64494 L
s
% Start of user PostScript
0.357143 0.642857 0.368132 0.652187 MAarrowhead1
% End of user PostScript
.36395 .70408 m
.38037 .71169 L
s
% Start of user PostScript
0.357143 0.714286 0.374393 0.722278 MAarrowhead1
% End of user PostScript
.36395 .77211 m
.38692 .77817 L
s
% Start of user PostScript
0.357143 0.785714 0.381265 0.792076 MAarrowhead1
% End of user PostScript
.36395 .84014 m
.39414 .84439 L
s
% Start of user PostScript
0.357143 0.857143 0.388842 0.861613 MAarrowhead1
% End of user PostScript
.36395 .90816 m
.40213 .91039 L
s
% Start of user PostScript
0.357143 0.928571 0.397238 0.930913 MAarrowhead1
% End of user PostScript
.36395 .97619 m
.41104 .97619 L
s
% Start of user PostScript
0.357143 1. 0.406593 1. MAarrowhead1
% End of user PostScript
.43197 .02381 m
.40058 .02381 L
s
% Start of user PostScript
0.428571 0 0.395604 0 MAarrowhead1
% End of user PostScript
.43197 .09184 m
.40457 .09342 L
s
% Start of user PostScript
0.428571 0.0714286 0.3998 0.0730897 MAarrowhead1
% End of user PostScript
.43197 .15986 m
.40872 .16272 L
s
% Start of user PostScript
0.428571 0.142857 0.404151 0.145854 MAarrowhead1
% End of user PostScript
.43197 .22789 m
.41302 .23173 L
s
% Start of user PostScript
0.428571 0.214286 0.408667 0.218315 MAarrowhead1
% End of user PostScript
.43197 .29592 m
.41748 .30047 L
s
% Start of user PostScript
0.428571 0.285714 0.413356 0.290492 MAarrowhead1
% End of user PostScript
.43197 .36395 m
.42212 .36896 L
s
% Start of user PostScript
0.428571 0.357143 0.418229 0.362404 MAarrowhead1
% End of user PostScript
.43197 .43197 m
.42695 .43721 L
s
% Start of user PostScript
0.428571 0.428571 0.423297 0.434066 MAarrowhead1
% End of user PostScript
.43197 .5 m
.43197 .50523 L
s
% Start of user PostScript
0.428571 0.5 0.428571 0.505495 MAarrowhead1
% End of user PostScript
.43197 .56803 m
.43721 .57305 L
s
% Start of user PostScript
0.428571 0.571429 0.434066 0.576703 MAarrowhead1
% End of user PostScript
.43197 .63605 m
.44266 .64067 L
s
% Start of user PostScript
0.428571 0.642857 0.439794 0.647705 MAarrowhead1
% End of user PostScript
.43197 .70408 m
.44835 .70811 L
s
% Start of user PostScript
0.428571 0.714286 0.445772 0.718512 MAarrowhead1
% End of user PostScript
.43197 .77211 m
.4543 .77537 L
s
% Start of user PostScript
0.428571 0.785714 0.452015 0.789135 MAarrowhead1
% End of user PostScript
.43197 .84014 m
.46052 .84246 L
s
% Start of user PostScript
0.428571 0.857143 0.458541 0.859585 MAarrowhead1
% End of user PostScript
.43197 .90816 m
.46702 .9094 L
s
% Start of user PostScript
0.428571 0.928571 0.465372 0.92987 MAarrowhead1
% End of user PostScript
.43197 .97619 m
.47384 .97619 L
s
% Start of user PostScript
0.428571 1. 0.472527 1. MAarrowhead1
% End of user PostScript
.5 .02381 m
.46337 .02381 L
s
% Start of user PostScript
0.5 0 0.461538 0 MAarrowhead1
% End of user PostScript
.5 .09184 m
.4686 .09184 L
s
% Start of user PostScript
0.5 0.0714286 0.467033 0.0714286 MAarrowhead1
% End of user PostScript
.5 .15986 m
.47384 .15986 L
s
% Start of user PostScript
0.5 0.142857 0.472527 0.142857 MAarrowhead1
% End of user PostScript
.5 .22789 m
.47907 .22789 L
s
% Start of user PostScript
0.5 0.214286 0.478022 0.214286 MAarrowhead1
% End of user PostScript
.5 .29592 m
.4843 .29592 L
s
% Start of user PostScript
0.5 0.285714 0.483516 0.285714 MAarrowhead1
% End of user PostScript
.5 .36395 m
.48953 .36395 L
s
% Start of user PostScript
0.5 0.357143 0.489011 0.357143 MAarrowhead1
% End of user PostScript
.5 .43197 m
.49477 .43197 L
s
% Start of user PostScript
0.5 0.428571 0.494505 0.428571 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0.5 0.5 MAarrowzero1
% End of user PostScript
.5 .56803 m
.50523 .56803 L
s
% Start of user PostScript

0.5 0.571429 0.505495 0.571429 MAarrowhead1
% End of user PostScript
.5 .63605 m
.51047 .63605 L
s
% Start of user PostScript
0.5 0.642857 0.510989 0.642857 MAarrowhead1
% End of user PostScript
.5 .70408 m
.5157 .70408 L
s
% Start of user PostScript
0.5 0.714286 0.516484 0.714286 MAarrowhead1
% End of user PostScript
.5 .77211 m
.52093 .77211 L
s
% Start of user PostScript
0.5 0.785714 0.521978 0.785714 MAarrowhead1
% End of user PostScript
.5 .84014 m
.52616 .84014 L
s
% Start of user PostScript
0.5 0.857143 0.527473 0.857143 MAarrowhead1
% End of user PostScript
.5 .90816 m
.5314 .90816 L
s
% Start of user PostScript
0.5 0.928571 0.532967 0.928571 MAarrowhead1
% End of user PostScript
.5 .97619 m
.53663 .97619 L
s
% Start of user PostScript
0.5 1. 0.538462 1. MAarrowhead1
% End of user PostScript
.56803 .02381 m
.52616 .02381 L
s
% Start of user PostScript
0.571429 0 0.527473 0 MAarrowhead1
% End of user PostScript
.56803 .09184 m
.53298 .0906 L
s
% Start of user PostScript
0.571429 0.0714286 0.534628 0.0701299 MAarrowhead1
% End of user PostScript
.56803 .15986 m
.53948 .15754 L
s
% Start of user PostScript
0.571429 0.142857 0.541459 0.140415 MAarrowhead1
% End of user PostScript
.56803 .22789 m
.5457 .22463 L
s
% Start of user PostScript
0.571429 0.214286 0.547985 0.210865 MAarrowhead1
% End of user PostScript
.56803 .29592 m
.55165 .29189 L
s
% Start of user PostScript
0.571429 0.285714 0.554228 0.281488 MAarrowhead1
% End of user PostScript
.56803 .36395 m
.55734 .35933 L
s
% Start of user PostScript
0.571429 0.357143 0.560206 0.352295 MAarrowhead1
% End of user PostScript
.56803 .43197 m
.56279 .42695 L
s
% Start of user PostScript
0.571429 0.428571 0.565934 0.423297 MAarrowhead1
% End of user PostScript
.56803 .5 m
.56803 .49477 L
s
% Start of user PostScript
0.571429 0.5 0.571429 0.494505 MAarrowhead1
% End of user PostScript
.56803 .56803 m
.57305 .56279 L
s
% Start of user PostScript
0.571429 0.571429 0.576703 0.565934 MAarrowhead1
% End of user PostScript
.56803 .63605 m
.57788 .63104 L
s
% Start of user PostScript
0.571429 0.642857 0.581771 0.637596 MAarrowhead1
% End of user PostScript
.56803 .70408 m
.58252 .69953 L
s
% Start of user PostScript
0.571429 0.714286 0.586644 0.709508 MAarrowhead1
% End of user PostScript
.56803 .77211 m
.58698 .76827 L
s
% Start of user PostScript
0.571429 0.785714 0.591333 0.781685 MAarrowhead1
% End of user PostScript
.56803 .84014 m
.59128 .83728 L
s
% Start of user PostScript
0.571429 0.857143 0.595849 0.854146 MAarrowhead1
% End of user PostScript
.56803 .90816 m
.59543 .90658 L
s
% Start of user PostScript
0.571429 0.928571 0.6002 0.92691 MAarrowhead1
% End of user PostScript
.56803 .97619 m
.59942 .97619 L
s
% Start of user PostScript
0.571429 1. 0.604396 1. MAarrowhead1
% End of user PostScript
.63605 .02381 m
.58896 .02381 L
s
% Start of user PostScript
0.642857 0 0.593407 0 MAarrowhead1
% End of user PostScript
.63605 .09184 m
.59787 .08961 L
s
% Start of user PostScript
0.642857 0.0714286 0.602762 0.0690867 MAarrowhead1
% End of user PostScript
.63605 .15986 m
.60586 .15561 L
s
% Start of user PostScript
0.642857 0.142857 0.611158 0.138387 MAarrowhead1
% End of user PostScript
.63605 .22789 m
.61308 .22183 L
s
% Start of user PostScript
0.642857 0.214286 0.618735 0.207924 MAarrowhead1
% End of user PostScript
.63605 .29592 m
.61963 .28831 L
s
% Start of user PostScript
0.642857 0.285714 0.625607 0.277722 MAarrowhead1
% End of user PostScript
.63605 .36395 m
.62559 .35506 L
s
% Start of user PostScript
0.642857 0.357143 0.631868 0.347813 MAarrowhead1
% End of user PostScript
.63605 .43197 m
.63104 .42212 L
s
% Start of user PostScript
0.642857 0.428571 0.637596 0.418229 MAarrowhead1
% End of user PostScript
.63605 .5 m
.63605 .48953 L
s
% Start of user PostScript
0.642857 0.5 0.642857 0.489011 MAarrowhead1
% End of user PostScript
.63605 .56803 m
.64067 .55734 L
s
% Start of user PostScript
0.642857 0.571429 0.647705 0.560206 MAarrowhead1
% End of user PostScript
.63605 .63605 m
.64494 .62559 L
s
% Start of user PostScript
0.642857 0.642857 0.652187 0.631868 MAarrowhead1
% End of user PostScript
.63605 .70408 m
.6489 .69435 L
s
% Start of user PostScript
0.642857 0.714286 0.656344 0.704063 MAarrowhead1
% End of user PostScript
.63605 .77211 m
.65258 .76369 L
s
% Start of user PostScript
0.642857 0.785714 0.660208 0.776869 MAarrowhead1
% End of user PostScript
.63605 .84014 m
.65601 .8337 L
s
% Start of user PostScript
0.642857 0.857143 0.663811 0.85038 MAarrowhead1
% End of user PostScript
.63605 .90816 m
.65922 .90449 L
s
% Start of user PostScript
0.642857 0.928571 0.667177 0.92471 MAarrowhead1
% End of user PostScript
.63605 .97619 m
.66222 .97619 L
s
% Start of user PostScript
0.642857 1. 0.67033 1. MAarrowhead1
% End of user PostScript
.70408 .02381 m
.65175 .02381 L
s
% Start of user PostScript
0.714286 0 0.659341 0 MAarrowhead1
% End of user PostScript
.70408 .09184 m
.66357 .08879 L
s
% Start of user PostScript
0.714286 0.0714286 0.671748 0.0682303 MAarrowhead1
% End of user PostScript
.70408 .15986 m
.6733 .15398 L
s
% Start of user PostScript
0.714286 0.142857 0.681965 0.136676 MAarrowhead1
% End of user PostScript
.70408 .22789 m
.68145 .2194 L
s
% Start of user PostScript
0.714286 0.214286 0.690526 0.205368 MAarrowhead1
% End of user PostScript
.70408 .29592 m
.68838 .28509 L
s
% Start of user PostScript
0.714286 0.285714 0.697802 0.274346 MAarrowhead1
% End of user PostScript
.70408 .36395 m
.69435 .3511 L
s
% Start of user PostScript
0.714286 0.357143 0.704063 0.343656 MAarrowhead1
% End of user PostScript
.70408 .43197 m
.69953 .41748 L
s
% Start of user PostScript
0.714286 0.428571 0.709508 0.413356 MAarrowhead1
% End of user PostScript
.70408 .5 m
.70408 .4843 L
s
% Start of user PostScript
0.714286 0.5 0.714286 0.483516 MAarrowhead1
% End of user PostScript
.70408 .56803 m
.70811 .55165 L
s
% Start of user PostScript
0.714286 0.571429 0.718512 0.554228 MAarrowhead1
% End of user PostScript
.70408 .63605 m
.71169 .61963 L
s
% Start of user PostScript
0.714286 0.642857 0.722278 0.625607 MAarrowhead1
% End of user PostScript
.70408 .70408 m
.71491 .68838 L
s
% Start of user PostScript
0.714286 0.714286 0.725654 0.697802 MAarrowhead1
% End of user PostScript
.70408 .77211 m
.71781 .75811 L
s
% Start of user PostScript
0.714286 0.785714 0.728698 0.771013 MAarrowhead1
% End of user PostScript
.70408 .84014 m
.72043 .82905 L
s
% Start of user PostScript
0.714286 0.857143 0.731456 0.845507 MAarrowhead1
% End of user PostScript
.70408 .90816 m
.72283 .90158 L
s
% Start of user PostScript
0.714286 0.928571 0.733968 0.921659 MAarrowhead1
% End of user PostScript
.70408 .97619 m
.72501 .97619 L
s
% Start of user PostScript
0.714286 1. 0.736264 1. MAarrowhead1
% End of user PostScript
.77211 .02381 m
.71455 .02381 L
s
% Start of user PostScript
0.785714 0 0.725275 0 MAarrowhead1
% End of user PostScript
.77211 .09184 m
.73066 .08811 L
s
% Start of user PostScript
0.785714 0.0714286 0.742198 0.0675147 MAarrowhead1
% End of user PostScript
.77211 .15986 m
.74234 .15258 L
s
% Start of user PostScript
0.785714 0.142857 0.754452 0.135213 MAarrowhead1
% End of user PostScript
.77211 .22789 m
.75118 .21726 L
s
% Start of user PostScript
0.785714 0.214286 0.763736 0.203128 MAarrowhead1
% End of user PostScript
.77211 .29592 m
.75811 .28219 L
s
% Start of user PostScript
0.785714 0.285714 0.771013 0.271302 MAarrowhead1
% End of user PostScript
.77211 .36395 m
.76369 .34742 L
s
% Start of user PostScript
0.785714 0.357143 0.776869 0.339792 MAarrowhead1
% End of user PostScript
.77211 .43197 m
.76827 .41302 L
s
% Start of user PostScript
0.785714 0.428571 0.781685 0.408667 MAarrowhead1
% End of user PostScript
.77211 .5 m
.77211 .47907 L
s
% Start of user PostScript
0.785714 0.5 0.785714 0.478022 MAarrowhead1
% End of user PostScript
.77211 .56803 m
.77537 .5457 L
s
% Start of user PostScript
0.785714 0.571429 0.789135 0.547985 MAarrowhead1
% End of user PostScript
.77211 .63605 m
.77817 .61308 L
s
% Start of user PostScript
0.785714 0.642857 0.792076 0.618735 MAarrowhead1
% End of user PostScript
.77211 .70408 m
.7806 .68145 L
s
% Start of user PostScript
0.785714 0.714286 0.794632 0.690526 MAarrowhead1
% End of user PostScript
.77211 .77211 m
.78274 .75118 L
s
% Start of user PostScript
0.785714 0.785714 0.796872 0.763736 MAarrowhead1
% End of user PostScript
.77211 .84014 m
.78462 .82281 L
s
% Start of user PostScript
0.785714 0.857143 0.798853 0.838954 MAarrowhead1
% End of user PostScript
.77211 .90816 m
.7863 .89728 L
s
% Start of user PostScript
0.785714 0.928571 0.800617 0.917143 MAarrowhead1
% End of user PostScript
.77211 .97619 m
.78781 .97619 L
s
% Start of user PostScript
0.785714 1. 0.802198 1. MAarrowhead1
% End of user PostScript
.84014 .02381 m
.77734 .02381 L
s
% Start of user PostScript
0.857143 0 0.791209 0 MAarrowhead1
% End of user PostScript
.84014 .09184 m
.80048 .08753 L
s
% Start of user PostScript
0.857143 0.0714286 0.8155 0.0669078 MAarrowhead1
% End of user PostScript
.84014 .15986 m
.81397 .15138 L
s
% Start of user PostScript
0.857143 0.142857 0.82967 0.133947 MAarrowhead1
% End of user PostScript
.84014 .22789 m
.82281 .21538 L
s
% Start of user PostScript
0.857143 0.214286 0.838954 0.201147 MAarrowhead1
% End of user PostScript
.84014 .29592 m
.82905 .27957 L
s
% Start of user PostScript
0.857143 0.285714 0.845507 0.268544 MAarrowhead1
% End of user PostScript
.84014 .36395 m
.8337 .34399 L
s
% Start of user PostScript
0.857143 0.357143 0.85038 0.336189 MAarrowhead1
% End of user PostScript
.84014 .43197 m
.83728 .40872 L
s
% Start of user PostScript
0.857143 0.428571 0.854146 0.404151 MAarrowhead1
% End of user PostScript
.84014 .5 m
.84014 .47384 L
s
% Start of user PostScript
0.857143 0.5 0.857143 0.472527 MAarrowhead1
% End of user PostScript
.84014 .56803 m
.84246 .53948 L
s
% Start of user PostScript
0.857143 0.571429 0.859585 0.541459 MAarrowhead1
% End of user PostScript
.84014 .63605 m
.84439 .60586 L
s
% Start of user PostScript
0.857143 0.642857 0.861613 0.611158 MAarrowhead1
% End of user PostScript
.84014 .70408 m
.84602 .6733 L
s
% Start of user PostScript
0.857143 0.714286 0.863324 0.681965 MAarrowhead1
% End of user PostScript
.84014 .77211 m
.84742 .74234 L
s
% Start of user PostScript
0.857143 0.785714 0.864787 0.754452 MAarrowhead1
% End of user PostScript
.84014 .84014 m
.84862 .81397 L
s
% Start of user PostScript
0.857143 0.857143 0.866053 0.82967 MAarrowhead1
% End of user PostScript
.84014 .90816 m
.84967 .89026 L
s
% Start of user PostScript
0.857143 0.928571 0.867158 0.909774 MAarrowhead1
% End of user PostScript
.84014 .97619 m
.8506 .97619 L
s
% Start of user PostScript
0.857143 1. 0.868132 1. MAarrowhead1
% End of user PostScript
.90816 .02381 m
.84014 .02381 L
s
% Start of user PostScript
0.928571 0 0.857143 0 MAarrowhead1
% End of user PostScript
.90816 .09184 m
.87677 .08703 L
s
% Start of user PostScript
0.928571 0.0714286 0.895604 0.0663866 MAarrowhead1
% End of user PostScript
.90816 .15986 m
.89026 .15033 L
s
% Start of user PostScript
0.928571 0.142857 0.909774 0.132842 MAarrowhead1
% End of user PostScript
.90816 .22789 m
.89728 .2137 L
s
% Start of user PostScript
0.928571 0.214286 0.917143 0.199383 MAarrowhead1
% End of user PostScript
.90816 .29592 m
.90158 .27717 L
s
% Start of user PostScript
0.928571 0.285714 0.921659 0.266032 MAarrowhead1
% End of user PostScript
.90816 .36395 m
.90449 .34078 L
s
% Start of user PostScript
0.928571 0.357143 0.92471 0.332823 MAarrowhead1
% End of user PostScript
.90816 .43197 m
.90658 .40457 L
s
% Start of user PostScript
0.928571 0.428571 0.92691 0.3998 MAarrowhead1
% End of user PostScript
.90816 .5 m
.90816 .4686 L
s
% Start of user PostScript
0.928571 0.5 0.928571 0.467033 MAarrowhead1
% End of user PostScript
.90816 .56803 m
.9094 .53298 L
s
% Start of user PostScript
0.928571 0.571429 0.92987 0.534628 MAarrowhead1
% End of user PostScript
.90816 .63605 m
.91039 .59787 L
s
% Start of user PostScript
0.928571 0.642857 0.930913 0.602762 MAarrowhead1
% End of user PostScript
.90816 .70408 m
.91121 .66357 L
s
% Start of user PostScript
0.928571 0.714286 0.93177 0.671748 MAarrowhead1
% End of user PostScript
.90816 .77211 m
.91189 .73066 L
s
% Start of user PostScript
0.928571 0.785714 0.932485 0.742198 MAarrowhead1
% End of user PostScript
.90816 .84014 m
.91247 .80048 L
s
% Start of user PostScript
0.928571 0.857143 0.933092 0.8155 MAarrowhead1
% End of user PostScript
.90816 .90816 m
.91297 .87677 L
s
% Start of user PostScript
0.928571 0.928571 0.933613 0.895604 MAarrowhead1
% End of user PostScript
.90816 .97619 m
.9134 .97619 L
s
% Start of user PostScript
0.928571 1. 0.934066 1. MAarrowhead1
% End of user PostScript
.97619 .09184 m
.97619 .0866 L
s
% Start of user PostScript
1. 0.0714286 1. 0.0659341 MAarrowhead1
% End of user PostScript
.97619 .15986 m
.97619 .1494 L
s
% Start of user PostScript
1. 0.142857 1. 0.131868 MAarrowhead1
% End of user PostScript
.97619 .22789 m
.97619 .21219 L
s
% Start of user PostScript
1. 0.214286 1. 0.197802 MAarrowhead1
% End of user PostScript
.97619 .29592 m
.97619 .27499 L
s
% Start of user PostScript
1. 0.285714 1. 0.263736 MAarrowhead1
% End of user PostScript
.97619 .36395 m
.97619 .33778 L
s
% Start of user PostScript
1. 0.357143 1. 0.32967 MAarrowhead1
% End of user PostScript
.97619 .43197 m
.97619 .40058 L
s
% Start of user PostScript
1. 0.428571 1. 0.395604 MAarrowhead1
% End of user PostScript
.97619 .5 m
.97619 .46337 L
s
% Start of user PostScript
1. 0.5 1. 0.461538 MAarrowhead1
% End of user PostScript
.97619 .56803 m
.97619 .52616 L
s
% Start of user PostScript
1. 0.571429 1. 0.527473 MAarrowhead1
% End of user PostScript
.97619 .63605 m
.97619 .58896 L
s
% Start of user PostScript
1. 0.642857 1. 0.593407 MAarrowhead1
% End of user PostScript
.97619 .70408 m
.97619 .65175 L
s
% Start of user PostScript
1. 0.714286 1. 0.659341 MAarrowhead1
% End of user PostScript
.97619 .77211 m
.97619 .71455 L
s
% Start of user PostScript
1. 0.785714 1. 0.725275 MAarrowhead1
% End of user PostScript
.97619 .84014 m
.97619 .77734 L
s
% Start of user PostScript
1. 0.857143 1. 0.791209 MAarrowhead1
% End of user PostScript
.97619 .90816 m
.97619 .84014 L
s
% Start of user PostScript
1. 0.928571 1. 0.857143 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002DOol30004Ool400000goo00000002Ool200000goo00000002001e
Ool009Eoo`03001oogoo00Aoo`03001oogoo009oo`04001oo`000003Ool00`00Oomoo`1eOol009Eo
o`<000Aoo`03001oogoo009oo`<000Eoo`03001oogoo07Aoo`00UGoo00@007ooOol000=oo`8000=o
o`04001oogoo0005Ool00`00Oomoo`1cOol009Eoo`04001oogoo0002Ool200001Goo000007oo0000
0Woo00@007ooOol0009oo`03001oogoo07=oo`00U7oo100027oo100017oo0P00MWoo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol002Uoo`8002Moo`8000Aoo`8000=oo`@0025oo`8000Aoo`80
00Aoo`<0021oo`8000Aoo`8000Aoo`80025oo`8000Aoo`8000Aoo`8002Ioo`<000Uoo`00:7oo00@0
07ooOol002Eoo`04001oogoo0003Ool20004Ool00`00Oomoo`0POol01000Oomoo`000goo0P001Goo
00<007ooOol07Woo00@007ooOol000=oo`8000=oo`04001oogoo000OOol01000Oomoo`000goo0P00
0goo00@007ooOol002Ioo`03001oogoo00Qoo`00:7oo00@007ooOol002Eoo`04001oogoo000:Ool0
0`00Oomoo`0OOol01000Oomoo`0027oo10007goo00@007ooOol000Qoo`04001oogoo000OOol01000
Oomoo`0027oo00@007ooOol002Ioo`03001oogoo00Qoo`00:7oo00@007ooOol002Eoo`04001oogoo
000;Ool00`00Oomoo`0NOol01000Oomoo`0027oo00<007oo000087oo00@007ooOol000Qoo`<0021o
o`04001oogoo0009Ool2000WOol00`00Oomoo`08Ool002Qoo`04001oogoo000UOol01000Oomoo`00
27oo00@007ooOol0021oo`04001oogoo0008Ool00`00Ool0000POol01000Oomoo`0027oo00<007oo
Ool087oo00@007ooOol000Qoo`04001oogoo000VOol00`00Oomoo`08Ool002Uoo`8002Moo`8000Yo
o`80029oo`8000Yoo`80025oo`8000Yoo`<0021oo`8000Yoo`8002Ioo`8000Yoo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol002AoooT000=oo`0097oo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool001eoo`8000Eo
o`03001oogoo0?Eoo`03001oogoo005oo`0077oo00@007ooOol000Aoo`03001oogoo01Ioo`<000ao
o`<000eoo`<000aoo`<000eoo`<000eoo`<000aoo`<000eoo`<000aoo`<000eoo`<000aoo`<000eo
o`<000aoo`<0029oo`03001oogoo005oo`0077oo00@007ooOol000Aoo`<001=oo`H000Uoo`H000Yo
o`H000Yoo`H000Uoo`P000Qoo`P000Moo`X000Ioo`/000Aoo`d000=oo`h00003Ool0000002l001Eo
o`8000=oo`0077oo00@007ooOol000Aoo`03001oogoo01Eoo`@000]oo`@000aoo`@000aoo`<000ao
o`@000aoo`@000]oo`@000aoo`@000]oo`@000aoo`@000]oo`@000aoo`@000aoo`<0029oo`03001o
ogoo005oo`0077oo00@007ooOol000Aoo`03001oogoo01Qoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo021oo`03001oogoo005oo`007Goo0P001Goo00<007ooOol0mGoo00<007ooOol00Goo
000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`00
97oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Ao
o`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol0
0`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo0P00
mGoo0P000goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001o
ogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`0eOol00`00Oomo
o`0=Ool2000>Ool2000>Ool2000=Ool3000=Ool3000>Ool3000=Ool3000:Ool7000;Ool6000=Ool6
000BOol00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03
001oogoo00eoo`8000moo`8000eoo`@000]oo`H000Yoo`H000Qoo`T000Moo`X000Moo`X000Ioo`/0
00Moo`@00003Ool0000000<000Qoo`T000Yoo`H0011oo`03001oogoo00=oo`03001oogoo005oo`00
97oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Goo0`003Goo10002goo1@002Woo1P00
2Woo1P002goo10003Woo0P003Woo0P003goo0P003goo00<007ooOol03Woo00<007ooOol047oo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>
Ool00`00Oomoo`0=Ool3000<Ool3000<Ool6000>Ool2000>Ool2000>Ool00`00Oomoo`1eOol30004
Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00aoo`@000eoo`<000aoo`03001o
ogoo0;Uoo`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol037oo10003Goo
0P00bGoo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0<Ool3000>Ool0
0`00Oomoo`3?Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00eoo`800>1oo`03
001oogoo005oo`0097oo0P0017oo00<007ooOol03Goo0P00ggoo0P000goo000TOol00`00Oomoo`03
Ool00`00Oomoo`0=Ool00`00Oomoo`3OOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001o
ogoo0>moo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol0kgoo00<007ooOol00Goo
000TOol00`00Oomoo`03Ool00`00Oomoo`3_Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<0
0?1oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`00l7oo00<007ooOol00Goo000TOol00`00
Oomoo`02Ool3003`Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo0:moo`H000ao
o`H000eoo`@0015oo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007oo
Ool0@7oo00<007ooOol03Goo0P003Woo0P003Woo0`003Goo0`002Woo1`002Woo1P003Goo1@003Goo
10003goo10003goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool2000?Ool2000=Ool4000;Ool5000:Ool70009Ool8
000:Ool7000:Ool7000<Ool200000goo0000000<Ool200000goo0000000>Ool3000?Ool00`00Oomo
o`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03
001oogoo00eoo`<000eoo`<000aoo`D000Yoo`H000ioo`8000ioo`8000moo`03001oogoo00ioo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo011oo`03001oogoo00eoo`<000Aoo`03001oogoo
005oo`0097oo0P0017oo00<007ooOol03Woo00<007ooOol037oo10003Goo0`003Goo0P003Goo0`00
4Goo0P00QGoo0`000goo0P000goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0<
Ool4000=Ool2000=Ool00`00Oomoo`2XOol30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=o
o`03001oogoo00ioo`03001oogoo00aoo`<000ioo`03001oogoo0;ioo`03001oogoo005oo`0097oo
00<007ooOol00goo00<007ooOol037oo10003Goo0P003Woo00<007ooOol0_goo00<007ooOol00Goo
000TOol00`00Oomoo`03Ool00`00Oomoo`0<Ool4000=Ool2003@Ool00`00Oomoo`01Ool002Aoo`03
001oogoo00=oo`03001oogoo00aoo`<000ioo`03001oogoo0<moo`03001oogoo005oo`0097oo00<0
07ooOol00goo00<007ooOol03Goo0P00h7oo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00
Oomoo`0=Ool2003POol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00eoo`03001o
ogoo0=moo`03001oogoo005oo`0097oo00<007ooOol00Woo0`00l7oo00<007ooOol00Goo000AOol2
0004Ool20003Ool40004Ool00`00Oomoo`02Ool3003`Ool00`00Oomoo`01Ool0011oo`04001oogoo
0003Ool20004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool3003ZOol00`00Oomoo`03Ool00`00Oomo
o`01Ool0011oo`04001oogoo000:Ool00`00Oomoo`03Ool30003Ool00`00Oomoo`2bOol2000?Ool2
000AOol2000AOol00`00Oomoo`02Ool20003Ool0011oo`04001oogoo000;Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2POol4000>Ool4000>Ool4000>Ool3000@Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool0011oo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol00goo00<007oo
Ool0@7oo00<007ooOol03Goo0P003goo0P003Woo0`002goo1P002Woo1P003Goo10003Goo10003Woo
10003Woo0`003Woo0`0017oo00<007ooOol00Goo000AOol2000:Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool3000?Ool2000=Ool4000<Ool4000;Ool6
000=Ool4000<Ool5000=Ool4000=Ool4000>Ool3000>Ool4000=Ool30004Ool00`00Oomoo`01Ool0
02Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00aoo`@000eoo`@0
00]oo`D000]oo`H000ioo`8000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03
001oogoo00moo`03001oogoo00ioo`03001oogoo00eoo`<000Aoo`03001oogoo005oo`0097oo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol037oo0`003Woo0`003Goo0`0037oo0`00Wgoo00<0
07ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool4000<Ool3000>
Ool00`00Oomoo`2^Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00aoo`@000aoo`8000ioo`03001oogoo0:moo`03001oogoo005oo`0097oo00<007ooOol00goo
00<007ooOol037oo0`003Woo0`003Goo00<007ooOol0_goo00<007ooOol00Goo000TOol00`00Oomo
o`03Ool00`00Oomoo`0<Ool4000=Ool2003@Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03
001oogoo00aoo`@000eoo`03001oogoo0<moo`03001oogoo005oo`0097oo0P0017oo00<007ooOol0
3Goo0P00ggoo0P000goo000TOol00`00Oomoo`02Ool3000>Ool2003POol00`00Oomoo`01Ool002Ao
o`03001oogoo009oo`<000ioo`03001oogoo0=moo`03001oogoo005oo`0097oo00<007ooOol00Woo
0`00l7oo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`3GOol00`00Oomoo`0?Ool0
0`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo0<Eoo`80011oo`03
001oogoo00moo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol0
XWoo0P003goo0P0047oo0`003goo0P0047oo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`1GOol00`00Oomoo`0>Ool2000]Ool4000=Ool5000<Ool5000>Ool3000>Ool3000>Ool30004
Ool00`00Oomoo`01Ool002Aoo`03001oogoo04Ioo`8000moo`8000ioo`<000ioo`<000]oo`H000eo
o`@000aoo`D000aoo`D000eoo`@000eoo`<000ioo`<000Aoo`03001oogoo005oo`0097oo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol037oo0`003goo0`003Goo100037oo
1@002Woo1P003Goo10003Woo0`003Goo0`003Woo0`003Woo0`003Woo10003Goo0`0017oo00<007oo
Ool00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool4
000=Ool3000=Ool3000=Ool6000>Ool2000@Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomo
o`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00aoo`<000ioo`@000eoo`8000eoo`03001oogoo09ioo`03001oogoo
005oo`0097oo0P0017oo00<007ooOol03Woo00<007ooOol037oo10003Goo0`003Woo00<007ooOol0
[7oo0P000goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool4000=Ool2000>
Ool00`00Oomoo`2^Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00aoo`@000eo
o`<000ioo`800;moo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol037oo10003Woo
0P003Woo00<007ooOol0_Woo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0<Ool3
000?Ool2003?Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000ioo`8000moo`03001oogoo
0<ioo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003Woo0P00h7oo00<007ooOol00Goo000T
Ool00`00Oomoo`02Ool3000>Ool00`00Oomoo`3IOol00`00Oomoo`03Ool00`00Oomoo`01Ool002Ao
o`03001oogoo00=oo`03001oogoo0=Moo`03001oogoo00moo`03001oogoo00=oo`03001oogoo005o
o`0097oo00<007ooOol00goo00<007ooOol0aWoo00<007ooOol03Woo00<007ooOol03goo00<007oo
Ool00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`2eOol00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool2000?Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo0:Uoo`80011oo`03
001oogoo00ioo`8000moo`8000moo`<000Aoo`03001oogoo005oo`0097oo0P00FGoo00<007ooOol0
3Woo0P00;Goo0P003goo0`003goo0P003goo0`003Woo0P003goo0`000goo0P000goo000TOol00`00
Oomoo`16Ool2000@Ool2000>Ool3000?Ool3000:Ool6000;Ool5000=Ool3000?Ool2000>Ool4000=
Ool3000?Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00aoo`<000moo`<000ioo`8000ioo`D000]oo`H000aoo`@000ao
o`D000aoo`@000ioo`<000eoo`<000moo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005o
o`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol037oo10003Woo
0`003Goo00<007ooOol03Goo0`004Woo0P003Woo0P003Goo0`003Woo00<007ooOol03Woo00<007oo
Ool0=Woo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool3
000>Ool4000=Ool3000=Ool00`00Oomoo`0dOol00`00Oomoo`0<Ool00`00Oomoo`1GOol00`00Oomo
o`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00aoo`@000eoo`<000ioo`80
0:ioo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Goo0`003Goo10003Goo0P00
3goo00<007ooOol0[Goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0=Ool3000>
Ool2000>Ool00`00Oomoo`2nOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00eo
o`<000ioo`800<moo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003goo00<007ooOol03Goo
00<007ooOol0cWoo00<007ooOol00Goo000AOol20004Ool20004Ool30004Ool00`00Oomoo`02Ool3
000?Ool00`00Oomoo`3NOol00`00Oomoo`01Ool0011oo`04001oogoo0003Ool20005Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool3000?Ool00`00Oomoo`3HOol00`00Oomoo`03Ool00`00Oomoo`01Ool0
011oo`04001oogoo0008Ool40004Ool30003Ool00`00Oomoo`3HOol00`00Oomoo`0>Ool00`00Oomo
o`02Ool20003Ool0011oo`04001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomo
o`37Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool0011oo`04
001oogoo0008Ool00`00Ool00005Ool00`00Oomoo`2lOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool2
000>Ool30004Ool00`00Oomoo`01Ool0015oo`8000Yoo`8000Eoo`03001oogoo0:]oo`03001oogoo
00ioo`03001oogoo00ioo`8000ioo`<000ioo`<000Aoo`03001oogoo005oo`0097oo00<007ooOol0
Egoo0P004Goo0P00;Woo00<007ooOol03Woo00<007ooOol03Woo0P003Woo0`003Woo0`003Woo0`00
17oo00<007ooOol00Goo000TOol00`00Oomoo`1GOol3000@Ool3000?Ool2000;Ool2000?Ool00`00
Oomoo`0>Ool2000?Ool2000>Ool3000>Ool4000>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Ao
o`03001oogoo04Ioo`<000ioo`<000moo`8000ioo`D000]oo`<000ioo`8000moo`8000moo`8000io
o`@000ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo0`003Woo0`003Goo0`003goo00<007oo
Ool03Goo1P0037oo0`003Woo0P003Woo0`003Woo0`003goo00<007ooOol03Goo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomo
o`0>Ool00`00Oomoo`0=Ool3000>Ool2000>Ool2000?Ool00`00Oomoo`0BOol2000<Ool4000=Ool3
000=Ool00`00Oomoo`17Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03
001oogoo00eoo`<000ioo`8000moo`8000ioo`03001oogoo035oo`<000ioo`03001oogoo05Moo`03
001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Goo0`003Woo0`003Woo0P003goo0P00
@goo00<007ooOol0Igoo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0=Ool3000>
Ool2000?Ool2000?Ool00`00Oomoo`2/Ool00`00Oomoo`01Ool000]oo`<001Ioo`8000=oo`<000io
o`<000ioo`8000moo`03001oogoo0;aoo`8000=oo`0037oo00<007ooOol05Goo00<007ooOol00Woo
0`003goo00<007ooOol03Goo0P00cgoo00<007ooOol00Goo000<Ool3000EOol00`00Oomoo`02Ool3
000?Ool00`00Oomoo`0=Ool00`00Oomoo`38Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000aoo`04
001oogoo000DOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`3HOol00`00Oomoo`03Ool0
0`00Oomoo`01Ool000aoo`04001oogoo000DOol00`00Oomoo`03Ool00`00Oomoo`3HOol00`00Oomo
o`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000]oo`@001Eoo`03001oogoo00=oo`03001oogoo
0<Qoo`03001oogoo00eoo`03001oogoo00eoo`<000Aoo`03001oogoo005oo`0037oo100057oo00<0
07ooOol0_Goo00<007ooOol03Woo00<007ooOol03Goo0P003Woo0`0017oo00<007ooOol00Goo000=
Ool00`00Oomoo`0DOol00`00Oomoo`2mOol00`00Oomoo`0=Ool2000>Ool3000>Ool30004Ool00`00
Oomoo`01Ool000eoo`03001oogoo01Aoo`03001oogoo06Moo`@0045oo`03001oogoo00eoo`8000mo
o`<000eoo`<000moo`03001oogoo00=oo`03001oogoo005oo`003Goo0P005Goo00<007ooOol0EWoo
10003Goo1000<7oo00<007ooOol03Woo00<007ooOol03Goo0`003Woo0`003Goo10003Woo00<007oo
Ool00goo00<007ooOol00Goo000<Ool200000goo0000000COol00`00Oomoo`15Ool4000=Ool4000=
Ool3000POol00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool3000=Ool4000>Ool00`00
Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`8000Aoo`03001oogoo00ioo`03001o
ogoo00ioo`03001oogoo00ioo`03001oogoo00aoo`@000ioo`<000ioo`8000moo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00eoo`<000eoo`@000moo`03001oogoo00eoo`03001oogoo00io
o`03001oogoo009oo`8000=oo`0037oo100057oo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03Goo0`003Woo0`003Woo0P003goo0P0087oo00<007ooOol03Goo0`003Woo
0`00Agoo00<007ooOol00Goo000;Ool00`00Oomoo`0FOol00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool3000>Ool3000>Ool2000?Ool2000?Ool00`00Oomoo`0NOol3000>Ool3000>Ool3
0017Ool00`00Oomoo`01Ool000]oo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo00eoo`<0
00ioo`<000ioo`<000ioo`80011oo`03001oogoo02ioo`<000ioo`<005Qoo`03001oogoo005oo`00
2goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol03Goo0`003Woo0`003goo00<007ooOol0
3Woo00<007ooOol0?goo0`00JGoo00<007ooOol00Goo000;Ool01@00Oomoogoo000057oo00<007oo
Ool00Woo0`003Woo0`003goo00<007ooOol03Woo00<007ooOol0_7oo00<007ooOol00Goo000<Ool4
000DOol00`00Oomoo`02Ool3000?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`2lOol0
0`00Oomoo`01Ool000aoo`@001Aoo`03001oogoo009oo`<000moo`03001oogoo00ioo`03001oogoo
0<Moo`03001oogoo00=oo`03001oogoo005oo`003Goo00<007ooOol057oo00<007ooOol00goo00<0
07ooOol03Woo00<007ooOol0f7oo00<007ooOol00goo00<007ooOol00Goo000>Ool00`00Oomoo`0C
Ool00`00Oomoo`03Ool00`00Oomoo`3IOol00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`01
Ool000moo`03001oogoo019oo`03001oogoo00=oo`03001oogoo0<Qoo`03001oogoo00ioo`03001o
ogoo00aoo`<000Aoo`03001oogoo005oo`0037oo00@007ooOol001Aoo`03001oogoo0<ioo`03001o
ogoo00eoo`8000ioo`<000Aoo`03001oogoo005oo`003Goo0P005Goo0P00_Woo00<007ooOol03Goo
0P003goo0`003Goo0`000goo0P000goo000TOol00`00Oomoo`2]Ool00`00Oomoo`0=Ool00`00Oomo
o`0=Ool3000>Ool3000>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo06Moo`03
001oogoo04=oo`03001oogoo00eoo`03001oogoo00eoo`<000eoo`@000ioo`03001oogoo00=oo`03
001oogoo005oo`0097oo00<007ooOol0Egoo0P003Goo0P00=7oo00<007ooOol03Goo0P003Woo0`00
3Goo10003Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`17
Ool2000<Ool4000<Ool4000=Ool4000@Ool2000@Ool00`00Oomoo`0<Ool3000>Ool3000?Ool00`00
Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=o
o`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`<000eoo`@000eoo`<000ioo`<000ao
o`H000eoo`<000moo`8000ioo`<000ioo`<000moo`03001oogoo00eoo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Goo
0`003Woo0`003Goo10003Woo0`003goo00<007ooOol02Woo10003Woo0`003goo0P003Woo1000Agoo
00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0=Ool3000>Ool3000?Ool2000>Ool3
000?Ool2000@Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool4000>Ool3001IOol00`00Oomoo`01Ool0
02Aoo`03001oogoo009oo`<000ioo`<000moo`8000moo`8000moo`80011oo`03001oogoo02aoo`<0
011oo`03001oogoo05Moo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003goo0P003goo0P00
3goo0P0047oo00<007ooOol0?Woo00<007ooOol0JGoo00<007ooOol00Goo000AOol20004Ool20004
Ool20005Ool00`00Oomoo`02Ool3000?Ool2000?Ool2000@Ool00`00Oomoo`2kOol00`00Oomoo`01
Ool0011oo`04001oogoo0003Ool20003Ool01000Oomoo`0017oo00<007ooOol00goo00<007ooOol0
3Woo0P0047oo00<007ooOol0aWoo00<007ooOol00goo00<007ooOol00Goo000@Ool01000Oomoo`00
27oo00@007ooOol000Aoo`<000=oo`03001oogoo00moo`03001oogoo0=Moo`03001oogoo009oo`80
00=oo`0047oo00@007ooOol000Qoo`<000Eoo`03001oogoo00=oo`03001oogoo0=Uoo`03001oogoo
00eoo`03001oogoo00=oo`03001oogoo005oo`0047oo00@007ooOol000Qoo`03001oogoo00Eoo`03
001oogoo0=moo`03001oogoo00aoo`<000Aoo`03001oogoo005oo`004Goo0P002Woo0`0017oo00<0
07ooOol0cgoo00<007ooOol037oo0P003Woo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`3?
Ool00`00Oomoo`0<Ool3000=Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo0;ioo`03001o
ogoo00eoo`8000ioo`<000ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0[Woo
00<007ooOol03Goo00<007ooOol03Goo0P003Goo10003Woo00<007ooOol00goo00<007ooOol00Goo
000TOol00`00Oomoo`2]Ool2000>Ool2000>Ool3000>Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo05Moo`03001oogoo00eoo`8003=oo`8000ioo`<000ioo`80
00moo`8000ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0
=Woo0P003Woo0P003goo00<007ooOol03Goo0`003Goo100047oo0`003Goo0`003Goo0`003Woo0`00
3goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool2000>Ool3000=Ool3000>Ool3000=Ool5000<
Ool6000;Ool4000>Ool3000=Ool4000?Ool2000?Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00eoo`<000ioo`<000io
o`<000moo`8000moo`8000aoo`H000]oo`<000ioo`<000ioo`@0011oo`03001oogoo04Eoo`03001o
ogoo005oo`0097oo0P000goo0`003Woo0`003Woo0`003goo0`003goo00<007ooOol03goo00<007oo
Ool0;7oo00<007ooOol03goo00<007ooOol0EWoo0P000goo000TOol00`00Oomoo`02Ool3000?Ool2
000?Ool3000?Ool2000@Ool00`00Oomoo`2YOol00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<0
00moo`80011oo`80011oo`03001oogoo0;Aoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<0
07ooOol00goo00<007ooOol03Woo0P004Goo00<007ooOol0aGoo00<007ooOol00goo00<007ooOol0
0Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`3GOol00`00Oomoo`03Ool00`00
Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo0=Uoo`03001oogoo00aoo`<000Aoo`03001o
ogoo005oo`0097oo00<007ooOol0ggoo00<007ooOol037oo0`0017oo00<007ooOol00Goo000TOol0
0`00Oomoo`3?Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool30004Ool00`00Oomoo`01Ool002Aoo`03
001oogoo0<moo`03001oogoo00aoo`<000ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<0
07ooOol0_goo00<007ooOol037oo0P003Woo0`003Woo00<007ooOol00goo00<007ooOol00Goo000T
Ool00`00Oomoo`2oOol00`00Oomoo`0<Ool2000>Ool3000>Ool00`00Oomoo`03Ool00`00Oomoo`01
Ool002Aoo`03001oogoo0:moo`03001oogoo00aoo`8000ioo`8000ioo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo005oo`0097oo0P00[goo0P003Goo0`003Goo0`003Woo00<007ooOol03Woo
00<007ooOol00Woo0P000goo000TOol00`00Oomoo`2MOol2000>Ool2000>Ool2000?Ool2000>Ool0
0`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo02Ioo`03001oogoo
00ioo`03001oogoo00eoo`03001oogoo00ioo`8000ioo`8000ioo`@000eoo`H000]oo`D000eoo`<0
00eoo`<000moo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`00
97oo00<007ooOol00Woo0`003goo0P003goo0P003goo0P003goo0P003goo0`003Goo100037oo1P00
2goo100037oo1@003Goo10003Woo0P003goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol0
0goo00<007ooOol00Goo000TOol00`00Oomoo`02Ool3000>Ool3000>Ool4000=Ool4000=Ool4000=
Ool5000;Ool6000;Ool3000>Ool2000?Ool3000@Ool00`00Oomoo`15Ool00`00Oomoo`01Ool002Ao
o`03001oogoo009oo`<000ioo`<0011oo`8000moo`8000moo`<0011oo`8002aoo`03001oogoo00mo
o`03001oogoo05Moo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo0`0047oo
00<007ooOol03goo00<007ooOol03goo00<007ooOol0XGoo00<007ooOol00goo00<007ooOol00Goo
000TOol00`00Oomoo`03Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`34Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo011oo`03001oogoo0=Ioo`03001oogoo
00=oo`03001oogoo005oo`0097oo00<007ooOol0kWoo0`0017oo00<007ooOol00Goo000TOol00`00
Oomoo`3OOol00`00Oomoo`0<Ool30004Ool00`00Oomoo`01Ool002Aoo`800>1oo`03001oogoo00ao
o`<000=oo`8000=oo`0097oo00<007ooOol0ggoo00<007ooOol03Goo00<007ooOol00goo00<007oo
Ool00Goo000TOol00`00Oomoo`3?Ool00`00Oomoo`0<Ool3000>Ool00`00Oomoo`03Ool00`00Oomo
o`01Ool002Aoo`03001oogoo0<moo`03001oogoo00aoo`<000ioo`03001oogoo00=oo`03001oogoo
005oo`0097oo00<007ooOol0_goo00<007ooOol037oo0P003Woo0`003Woo00<007ooOol00goo00<0
07ooOol00Goo000TOol00`00Oomoo`2^Ool2000?Ool00`00Oomoo`0<Ool2000>Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo0:eoo`<000ioo`8000eoo`<000io
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0WGoo0`0037oo
0`003Woo0P003goo0P003Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol0
0`00Oomoo`02Ool3000?Ool2000@Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool2000?Ool2000>Ool2
000>Ool4000=Ool6000:Ool4000=Ool4000=Ool3000?Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000ioo`<000moo`8000moo`<0
00ioo`@000eoo`D000]oo`H000]oo`H000]oo`@000aoo`<000moo`<000ioo`8000moo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`004Goo0P0017oo0P0017oo0P00
1Goo00<007ooOol00Woo0`0047oo0P003Woo0`003Woo10003Goo1@0037oo1P002goo1P002Woo0`00
3Woo00<007ooOol03Woo00<007ooOol03goo00<007ooOol0?goo00<007ooOol00goo00<007ooOol0
0Goo000@Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo
011oo`03001oogoo00ioo`8000moo`<0011oo`800:9oo`03001oogoo00=oo`03001oogoo005oo`00
47oo00@007ooOol000Qoo`04001oogoo0004Ool30003Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool0
0`00Oomoo`0?Ool00`00Oomoo`2aOol00`00Oomoo`02Ool20003Ool0011oo`04001oogoo0009Ool2
0005Ool00`00Oomoo`03Ool00`00Oomoo`3XOol30004Ool00`00Oomoo`01Ool0011oo`04001oogoo
0008Ool01000Oomoo`0017oo00<007ooOol0kWoo0`0017oo00<007ooOol00Goo000AOol2000:Ool2
0005Ool00`00Oomoo`3^Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo0=moo`03001oogoo
00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0ggoo00<007ooOol03Goo00<0
07ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`3OOol00`00Oomoo`0=Ool00`00Oomoo`03
Ool00`00Oomoo`01Ool002Aoo`03001oogoo0=1oo`03001oogoo00]oo`<000ioo`03001oogoo00=o
o`03001oogoo005oo`0097oo00<007ooOol0d7oo00<007ooOol02goo0`003Woo00<007ooOol00goo
00<007ooOol00Goo000TOol00`00Oomoo`30Ool00`00Oomoo`0<Ool2000=Ool3000>Ool00`00Oomo
o`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo0;moo`8000eoo`8000ioo`03001oogoo00ioo`03
001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`00ZWoo0P003Goo0P003Woo0P00
3Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol20003Ool30026Ool4000?
Ool3000;Ool4000=Ool3000=Ool3000>Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool20003Ool002Ao
o`03001oogoo009oo`<0011oo`80011oo`80011oo`8000moo`8000ioo`8000moo`<000eoo`@000ao
o`H000Yoo`@000aoo`@000eoo`@000ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=o
o`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo10003Goo1@0037oo1P002goo
1`002Woo1`002Goo20002Goo20002Goo1@0037oo0`003Goo0`003goo0P003goo00<007ooOol03Goo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomo
o`0>Ool5000=Ool5000=Ool5000<Ool6000;Ool6000:Ool3000>Ool3000=Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool00`00Oomoo`10Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo
00=oo`03001oogoo019oo`8000aoo`H000aoo`H000]oo`<00:=oo`03001oogoo00=oo`03001oogoo
005oo`0097oo00<007ooOol0kWoo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`3^Ool30004
Ool00`00Oomoo`01Ool002Aoo`03001oogoo0>ioo`<000Aoo`03001oogoo005oo`0097oo00<007oo
Ool0kgoo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`3_Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo0>moo`03001oogoo00=oo`03001oogoo005oo`0097oo00<0
07ooOol0h7oo00<007ooOol037oo00<007ooOol00goo00<007ooOol00Goo000TOol2003QOol00`00
Oomoo`0<Ool00`00Oomoo`02Ool20003Ool002Aoo`03001oogoo0=moo`8000ioo`03001oogoo00=o
o`03001oogoo005oo`0097oo00<007ooOol0d7oo00<007ooOol037oo0P003Woo00<007ooOol00goo
00<007ooOol00Goo000TOol00`00Oomoo`02Ool3003:Ool2000>Ool2000>Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo009oo`<00;Yoo`8000eoo`<000eoo`<000ioo`03001oogoo
00=oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`00Mgoo0P003Woo100037oo10003Woo0`00
37oo100037oo0`003goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`03Ool00`00Oomoo`0AOol2000AOol2000?Ool2000?Ool4000<Ool4000<Ool4000<Ool5000;
Ool6000:Ool60009Ool4000=Ool4000<Ool4000>Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00
Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`P000Uoo`X000Moo`X000Moo`/000Io
o`X000Ioo`X000Moo`T000Qoo`H000]oo`D000]oo`<000ioo`<000moo`8000ioo`03001oogoo00io
o`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol04Goo1P003Goo
1P002goo1P002goo0`003Goo0`003Goo0`003Goo0`003Goo00<007ooOol03Goo00<007ooOol03Goo
00<007ooOol03Woo00<007ooOol0=Goo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomo
o`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol0
0Goo000TOol2003eOol20003Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007oo
Ool0mGoo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo
0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`3e
Ool00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo
00<007ooOol00Goo000LOol30005Ool00`00Oomoo`3eOol00`00Oomoo`01Ool001eoo`03001oogoo
00Aoo`03001oogoo021oo`@000aoo`@000]oo`@000aoo`@000]oo`@000aoo`@000]oo`@000aoo`@0
00]oo`@000aoo`@000aoo`@000]oo`@000aoo`@001Ioo`03001oogoo005oo`007Goo00<007ooOol0
17oo0`0057oo<@000Woo3P000goo300017oo30001Goo2P001goo2@0027oo1`002Woo1P002Woo1P00
2Goo1P002Woo1P004goo0P000goo000MOol00`00Oomoo`04Ool00`00Oomoo`0POol4000<Ool4000;
Ool4000<Ool4000;Ool4000<Ool4000;Ool4000<Ool4000;Ool4000<Ool4000<Ool4000;Ool4000<
Ool4000FOol00`00Oomoo`01Ool001eoo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo00eo
o`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00ao
o`03001oogoo00eoo`03001oogoo01Moo`03001oogoo005oo`0077oo0P001Woo00<007ooOol0mGoo
00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00=oo`03001oogoo005oo`0097oon@000goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo000iOol00`00Oomoo`03Ool40002Ool30003Ool30003Ool30002
Ool40007Ool30004Ool50002Ool400000goo000000030002Ool50007Ool30002Ool40008Ool40008
Ool5000017oo000007oo0P000Woo1@0000=oo`0000000P0000=oo`0000000P001goo1@000Woo1@00
00=oo`0000000P000Woo00@007ooOol0009oo`D00004Ool00000Ool20006Ool30004Ool50002Ool3
0002Ool01000Oomoo`0067oo000iOol00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00H007ooOol007oo0003Ool01000Oomoo`002Woo00<007ooOol01Goo00D007ooOomoo`0000Mo
o`05001oogooOol00003Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01goo00D0
07ooOomoo`0000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00006Ool0
0`00Oomoo`08Ool01`00Oomoogoo001oo`00009oo`05001oogooOol00004Ool40004Ool01@00Oomo
ogoo00000Woo00<007ooOol01Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`03001oo`0000<0
01Qoo`00>7oo00<007oo00000goo1@0000=oo`00Ool01Goo00<007ooOol00Woo00D007ooOomoo`00
009oo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogooOol50003Ool01@00Oomoogoo00000goo
00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo00Moo`03001oo`00008000Qoo`04001o
ogoo0002Ool01000Oomoo`000Woo00H007ooOomoo`00Ool50002Ool00`00Oomoo`08Ool01P00Oomo
ogoo001oo`@000=oo`03001oogoo009oo`@000Aoo`05001oogooOol00002Ool00`00Oomoo`06Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000goo00<007oo00000`0067oo000hOol00`00Ool00003Ool0
1`00Oomoogoo001oo`0000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo0P002Goo0`001Goo
00D007ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001goo00D007ooOomoo`00
009oo`03001oogoo00Moo`03001oogoo00Yoo`04001oogoo0002Ool01000Oomoo`000Woo00L007oo
Oomoo`00Ool00003Ool00`00Oomoo`020009Ool01@00Oomoogoo000017oo00@007ooOomoo`8000=o
o`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007ooOol01Woo0`001Goo00D007ooOomoo`00
00=oo`03001oo`00009oo`03001oogoo01Ioo`00>7oo00<007oo000017oo0`000goo100000=oo`00
00000P000goo0`000Woo0P0000=oo`0000001goo00<007ooOol017oo0P0017oo0`0017oo00<007oo
Ool00Woo100027oo0`000Woo10001goo00D007ooOomoo`0000Moo`800004Ool00000Ool50003Ool4
0002Ool30002Ool200000goo00000007Ool01@00Oomoogoo00000Woo0`000Woo0P0000=oo`000000
0P000Woo0P000Woo0P000Woo1@0027oo00<007ooOol01Goo00<007ooOol00Woo0`0000=oo`000000
0Woo0P005goo000gOol200000goo0000000?Ool00`00Oomoo`0COol5000@Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`08Ool4000HOol00`00Oomoo`0@Ool5000UOol50004Ool00`00Oomo
o`0SOol004]oo`03001oogoo01aoo`03001oogoo00Moo`<000Ioo`8000ioo`<002=oo`8002eoo`03
001oogoo01=oo`<002Eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.181183, -0.127113, 
  0.00423725, 0.00423725}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -14 -21 ]
[.5 -0.0125 14 -9 ]
[-0.0125 .02381 -6 -4.5 ]
[-0.0125 .02381 0 4.5 ]
[-0.0125 .21429 -18 -4.5 ]
[-0.0125 .21429 0 4.5 ]
[-0.0125 .40476 -18 -4.5 ]
[-0.0125 .40476 0 4.5 ]
[-0.0125 .59524 -18 -4.5 ]
[-0.0125 .59524 0 4.5 ]
[-0.0125 .78571 -18 -4.5 ]
[-0.0125 .78571 0 4.5 ]
[-0.0125 .97619 -6 -4.5 ]
[-0.0125 .97619 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -30 -14 ]
[-0.01875 .5 -18 14 ]
[ 0 1 .125 0 ]
[.5 1.0125 -119 0 ]
[.5 1.0125 119 12 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -75 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrR2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
0 .02381 m
.00625 .02381 L
s
[(0)] -0.0125 .02381 1 0 Mshowa
0 .21429 m
.00625 .21429 L
s
[(0.2)] -0.0125 .21429 1 0 Mshowa
0 .40476 m
.00625 .40476 L
s
[(0.4)] -0.0125 .40476 1 0 Mshowa
0 .59524 m
.00625 .59524 L
s
[(0.6)] -0.0125 .59524 1 0 Mshowa
0 .78571 m
.00625 .78571 L
s
[(0.8)] -0.0125 .78571 1 0 Mshowa
0 .97619 m
.00625 .97619 L
s
[(1)] -0.0125 .97619 1 0 Mshowa
.125 Mabswid
0 .07143 m
.00375 .07143 L
s
0 .11905 m
.00375 .11905 L
s
0 .16667 m
.00375 .16667 L
s
0 .2619 m
.00375 .2619 L
s
0 .30952 m
.00375 .30952 L
s
0 .35714 m
.00375 .35714 L
s
0 .45238 m
.00375 .45238 L
s
0 .5 m
.00375 .5 L
s
0 .54762 m
.00375 .54762 L
s
0 .64286 m
.00375 .64286 L
s
0 .69048 m
.00375 .69048 L
s
0 .7381 m
.00375 .7381 L
s
0 .83333 m
.00375 .83333 L
s
0 .88095 m
.00375 .88095 L
s
0 .92857 m
.00375 .92857 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -99 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
75 10 translate
90 rotate
-75 -10 translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(PrC2) show
87.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.02381 .99375 m
.02381 1 L
s
.21429 .99375 m
.21429 1 L
s
.40476 .99375 m
.40476 1 L
s
.59524 .99375 m
.59524 1 L
s
.78571 .99375 m
.78571 1 L
s
.97619 .99375 m
.97619 1 L
s
.125 Mabswid
.07143 .99625 m
.07143 1 L
s
.11905 .99625 m
.11905 1 L
s
.16667 .99625 m
.16667 1 L
s
.2619 .99625 m
.2619 1 L
s
.30952 .99625 m
.30952 1 L
s
.35714 .99625 m
.35714 1 L
s
.45238 .99625 m
.45238 1 L
s
.5 .99625 m
.5 1 L
s
.54762 .99625 m
.54762 1 L
s
.64286 .99625 m
.64286 1 L
s
.69048 .99625 m
.69048 1 L
s
.7381 .99625 m
.7381 1 L
s
.83333 .99625 m
.83333 1 L
s
.88095 .99625 m
.88095 1 L
s
.92857 .99625 m
.92857 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
gsave
.5 1.0125 -180 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.000000 moveto
 558.000000 16.000000 lineto
 558.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.000000 lineto
closepath
clip newpath
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Vector) show
105.000000 13.000000 moveto
(Field) show
141.000000 13.000000 moveto
(of) show
159.000000 13.000000 moveto
(G) show
171.000000 13.000000 moveto
(under) show
207.000000 13.000000 moveto
(Replicator) show
273.000000 13.000000 moveto
(Flow) show
297.000000 13.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier
grestore
.99375 .02381 m
1 .02381 L
s
.99375 .21429 m
1 .21429 L
s
.99375 .40476 m
1 .40476 L
s
.99375 .59524 m
1 .59524 L
s
.99375 .78571 m
1 .78571 L
s
.99375 .97619 m
1 .97619 L
s
.125 Mabswid
.99625 .07143 m
1 .07143 L
s
.99625 .11905 m
1 .11905 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .2619 m
1 .2619 L
s
.99625 .30952 m
1 .30952 L
s
.99625 .35714 m
1 .35714 L
s
.99625 .45238 m
1 .45238 L
s
.99625 .5 m
1 .5 L
s
.99625 .54762 m
1 .54762 L
s
.99625 .64286 m
1 .64286 L
s
.99625 .69048 m
1 .69048 L
s
.99625 .7381 m
1 .7381 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .88095 m
1 .88095 L
s
.99625 .92857 m
1 .92857 L
s
.25 Mabswid
1 0 m
1 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.02381 .02381 m
.02381 .02381 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.02381 .09184 m
.02381 .10988 L
s
% Start of user PostScript
0 0.0714286 0 0.090379 MAarrowhead1
% End of user PostScript
.02381 .15986 m
.02381 .19318 L
s
% Start of user PostScript
0 0.142857 0 0.177843 MAarrowhead1
% End of user PostScript
.02381 .22789 m
.02381 .27371 L
s
% Start of user PostScript
0 0.214286 0 0.262391 MAarrowhead1
% End of user PostScript
.02381 .29592 m
.02381 .35145 L
s
% Start of user PostScript
0 0.285714 0 0.344023 MAarrowhead1
% End of user PostScript
.02381 .36395 m
.02381 .42642 L
s
% Start of user PostScript
0 0.357143 0 0.422741 MAarrowhead1
% End of user PostScript
.02381 .43197 m
.02381 .49861 L
s
% Start of user PostScript
0 0.428571 0 0.498542 MAarrowhead1
% End of user PostScript
.02381 .5 m
.02381 .56803 L
s
% Start of user PostScript
0 0.5 0 0.571429 MAarrowhead1
% End of user PostScript
.02381 .56803 m
.02381 .63467 L
s
% Start of user PostScript
0 0.571429 0 0.641399 MAarrowhead1
% End of user PostScript
.02381 .63605 m
.02381 .69853 L
s
% Start of user PostScript
0 0.642857 0 0.708455 MAarrowhead1
% End of user PostScript
.02381 .70408 m
.02381 .75961 L
s
% Start of user PostScript
0 0.714286 0 0.772595 MAarrowhead1
% End of user PostScript
.02381 .77211 m
.02381 .81792 L
s
% Start of user PostScript
0 0.785714 0 0.833819 MAarrowhead1
% End of user PostScript
.02381 .84014 m
.02381 .87346 L
s
% Start of user PostScript
0 0.857143 0 0.892128 MAarrowhead1
% End of user PostScript
.02381 .90816 m
.02381 .92621 L
s
% Start of user PostScript
0 0.928571 0 0.947522 MAarrowhead1
% End of user PostScript
.02381 .97619 m
.02381 .97619 L
s
% Start of user PostScript
0 1. MAarrowzero1
% End of user PostScript
.09184 .02381 m
.07379 .02381 L
s
% Start of user PostScript
0.0714286 0 0.0524781 0 MAarrowhead1
% End of user PostScript
.09184 .09184 m
.07637 .10731 L
s
% Start of user PostScript
0.0714286 0.0714286 0.0551853 0.0876718 MAarrowhead1
% End of user PostScript
.09184 .15986 m
.07895 .18842 L
s
% Start of user PostScript
0.0714286 0.142857 0.0578925 0.172845 MAarrowhead1
% End of user PostScript
.09184 .22789 m
.08152 .26716 L
s
% Start of user PostScript
0.0714286 0.214286 0.0605998 0.255519 MAarrowhead1
% End of user PostScript
.09184 .29592 m
.0841 .34352 L
s
% Start of user PostScript
0.0714286 0.285714 0.063307 0.335693 MAarrowhead1
% End of user PostScript
.09184 .36395 m
.08668 .41749 L
s
% Start of user PostScript
0.0714286 0.357143 0.0660142 0.413369 MAarrowhead1
% End of user PostScript
.09184 .43197 m
.08926 .48909 L
s
% Start of user PostScript
0.0714286 0.428571 0.0687214 0.488546 MAarrowhead1
% End of user PostScript
.09184 .5 m
.09184 .55831 L
s
% Start of user PostScript
0.0714286 0.5 0.0714286 0.561224 MAarrowhead1
% End of user PostScript
.09184 .56803 m
.09442 .62515 L
s
% Start of user PostScript
0.0714286 0.571429 0.0741358 0.631404 MAarrowhead1
% End of user PostScript
.09184 .63605 m
.09699 .6896 L
s
% Start of user PostScript
0.0714286 0.642857 0.076843 0.699084 MAarrowhead1
% End of user PostScript
.09184 .70408 m
.09957 .75168 L
s
% Start of user PostScript
0.0714286 0.714286 0.0795502 0.764265 MAarrowhead1
% End of user PostScript
.09184 .77211 m
.10215 .81138 L
s
% Start of user PostScript
0.0714286 0.785714 0.0822574 0.826947 MAarrowhead1
% End of user PostScript
.09184 .84014 m
.10473 .8687 L
s
% Start of user PostScript
0.0714286 0.857143 0.0849646 0.88713 MAarrowhead1
% End of user PostScript
.09184 .90816 m
.10731 .92363 L
s
% Start of user PostScript
0.0714286 0.928571 0.0876718 0.944815 MAarrowhead1
% End of user PostScript
.09184 .97619 m
.10988 .97619 L
s
% Start of user PostScript
0.0714286 1. 0.090379 1. MAarrowhead1
% End of user PostScript
.15986 .02381 m
.12654 .02381 L
s
% Start of user PostScript
0.142857 0 0.107872 0 MAarrowhead1
% End of user PostScript
.15986 .09184 m
.1313 .10473 L
s
% Start of user PostScript
0.142857 0.0714286 0.11287 0.0849646 MAarrowhead1
% End of user PostScript
.15986 .15986 m
.13606 .18366 L
s
% Start of user PostScript
0.142857 0.142857 0.117868 0.167847 MAarrowhead1
% End of user PostScript
.15986 .22789 m
.14082 .26062 L
s
% Start of user PostScript
0.142857 0.214286 0.122865 0.248646 MAarrowhead1
% End of user PostScript
.15986 .29592 m
.14558 .33558 L
s
% Start of user PostScript
0.142857 0.285714 0.127863 0.327364 MAarrowhead1
% End of user PostScript
.15986 .36395 m
.15034 .40857 L
s
% Start of user PostScript
0.142857 0.357143 0.132861 0.403998 MAarrowhead1
% End of user PostScript
.15986 .43197 m
.1551 .47957 L
s
% Start of user PostScript
0.142857 0.428571 0.137859 0.478551 MAarrowhead1
% End of user PostScript
.15986 .5 m
.15986 .54859 L
s
% Start of user PostScript
0.142857 0.5 0.142857 0.55102 MAarrowhead1
% End of user PostScript
.15986 .56803 m
.16462 .61563 L
s
% Start of user PostScript
0.142857 0.571429 0.147855 0.621408 MAarrowhead1
% End of user PostScript
.15986 .63605 m
.16938 .68068 L
s
% Start of user PostScript
0.142857 0.642857 0.152853 0.689713 MAarrowhead1
% End of user PostScript
.15986 .70408 m
.17414 .74375 L
s
% Start of user PostScript
0.142857 0.714286 0.157851 0.755935 MAarrowhead1
% End of user PostScript
.15986 .77211 m
.1789 .80483 L
s
% Start of user PostScript
0.142857 0.785714 0.162849 0.820075 MAarrowhead1
% End of user PostScript
.15986 .84014 m
.18366 .86394 L
s
% Start of user PostScript
0.142857 0.857143 0.167847 0.882132 MAarrowhead1
% End of user PostScript
.15986 .90816 m
.18842 .92105 L
s
% Start of user PostScript
0.142857 0.928571 0.172845 0.942107 MAarrowhead1
% End of user PostScript
.15986 .97619 m
.19318 .97619 L
s
% Start of user PostScript
0.142857 1. 0.177843 1. MAarrowhead1
% End of user PostScript
.22789 .02381 m
.18208 .02381 L
s
% Start of user PostScript
0.214286 0 0.166181 0 MAarrowhead1
% End of user PostScript
.22789 .09184 m
.18862 .10215 L
s
% Start of user PostScript
0.214286 0.0714286 0.173053 0.0822574 MAarrowhead1
% End of user PostScript
.22789 .15986 m
.19517 .1789 L
s
% Start of user PostScript
0.214286 0.142857 0.179925 0.162849 MAarrowhead1
% End of user PostScript
.22789 .22789 m
.20171 .25407 L
s
% Start of user PostScript
0.214286 0.214286 0.186797 0.241774 MAarrowhead1
% End of user PostScript
.22789 .29592 m
.20826 .32765 L
s
% Start of user PostScript
0.214286 0.285714 0.193669 0.319034 MAarrowhead1
% End of user PostScript
.22789 .36395 m
.2148 .39964 L
s
% Start of user PostScript
0.214286 0.357143 0.200541 0.394627 MAarrowhead1
% End of user PostScript
.22789 .43197 m
.22135 .47005 L
s
% Start of user PostScript
0.214286 0.428571 0.207414 0.468555 MAarrowhead1
% End of user PostScript
.22789 .5 m
.22789 .53887 L
s
% Start of user PostScript
0.214286 0.5 0.214286 0.540816 MAarrowhead1
% End of user PostScript
.22789 .56803 m
.23444 .60611 L
s
% Start of user PostScript
0.214286 0.571429 0.221158 0.611412 MAarrowhead1
% End of user PostScript
.22789 .63605 m
.24098 .67175 L
s
% Start of user PostScript
0.214286 0.642857 0.22803 0.680342 MAarrowhead1
% End of user PostScript
.22789 .70408 m
.24753 .73581 L
s
% Start of user PostScript
0.214286 0.714286 0.234902 0.747605 MAarrowhead1
% End of user PostScript
.22789 .77211 m
.25407 .79829 L
s
% Start of user PostScript
0.214286 0.785714 0.241774 0.813203 MAarrowhead1
% End of user PostScript
.22789 .84014 m
.26062 .85918 L
s
% Start of user PostScript
0.214286 0.857143 0.248646 0.877135 MAarrowhead1
% End of user PostScript
.22789 .90816 m
.26716 .91848 L
s
% Start of user PostScript
0.214286 0.928571 0.255519 0.9394 MAarrowhead1
% End of user PostScript
.22789 .97619 m
.27371 .97619 L
s
% Start of user PostScript
0.214286 1. 0.262391 1. MAarrowhead1
% End of user PostScript
.29592 .02381 m
.24039 .02381 L
s
% Start of user PostScript
0.285714 0 0.227405 0 MAarrowhead1
% End of user PostScript
.29592 .09184 m
.24832 .09957 L
s
% Start of user PostScript
0.285714 0.0714286 0.235735 0.0795502 MAarrowhead1
% End of user PostScript
.29592 .15986 m
.25625 .17414 L
s
% Start of user PostScript
0.285714 0.142857 0.244065 0.157851 MAarrowhead1
% End of user PostScript
.29592 .22789 m
.26419 .24753 L
s
% Start of user PostScript
0.285714 0.214286 0.252395 0.234902 MAarrowhead1
% End of user PostScript
.29592 .29592 m
.27212 .31972 L
s
% Start of user PostScript
0.285714 0.285714 0.260725 0.310704 MAarrowhead1
% End of user PostScript
.29592 .36395 m
.28005 .39072 L
s
% Start of user PostScript
0.285714 0.357143 0.269055 0.385256 MAarrowhead1
% End of user PostScript
.29592 .43197 m
.28799 .46053 L
s
% Start of user PostScript
0.285714 0.428571 0.277384 0.458559 MAarrowhead1
% End of user PostScript
.29592 .5 m
.29592 .52915 L
s
% Start of user PostScript
0.285714 0.5 0.285714 0.530612 MAarrowhead1
% End of user PostScript
.29592 .56803 m
.30385 .59659 L
s
% Start of user PostScript
0.285714 0.571429 0.294044 0.601416 MAarrowhead1
% End of user PostScript
.29592 .63605 m
.31178 .66283 L
s
% Start of user PostScript
0.285714 0.642857 0.302374 0.67097 MAarrowhead1
% End of user PostScript
.29592 .70408 m
.31972 .72788 L
s
% Start of user PostScript
0.285714 0.714286 0.310704 0.739275 MAarrowhead1
% End of user PostScript
.29592 .77211 m
.32765 .79174 L
s
% Start of user PostScript
0.285714 0.785714 0.319034 0.806331 MAarrowhead1
% End of user PostScript
.29592 .84014 m
.33558 .85442 L
s
% Start of user PostScript
0.285714 0.857143 0.327364 0.872137 MAarrowhead1
% End of user PostScript
.29592 .90816 m
.34352 .9159 L
s
% Start of user PostScript
0.285714 0.928571 0.335693 0.936693 MAarrowhead1
% End of user PostScript
.29592 .97619 m
.35145 .97619 L
s
% Start of user PostScript
0.285714 1. 0.344023 1. MAarrowhead1
% End of user PostScript
.36395 .02381 m
.30147 .02381 L
s
% Start of user PostScript
0.357143 0 0.291545 0 MAarrowhead1
% End of user PostScript
.36395 .09184 m
.3104 .09699 L
s
% Start of user PostScript
0.357143 0.0714286 0.300916 0.076843 MAarrowhead1
% End of user PostScript
.36395 .15986 m
.31932 .16938 L
s
% Start of user PostScript
0.357143 0.142857 0.310287 0.152853 MAarrowhead1
% End of user PostScript
.36395 .22789 m
.32825 .24098 L
s
% Start of user PostScript
0.357143 0.214286 0.319658 0.22803 MAarrowhead1
% End of user PostScript
.36395 .29592 m
.33717 .31178 L
s
% Start of user PostScript
0.357143 0.285714 0.32903 0.302374 MAarrowhead1
% End of user PostScript
.36395 .36395 m
.3461 .3818 L
s
% Start of user PostScript
0.357143 0.357143 0.338401 0.375885 MAarrowhead1
% End of user PostScript
.36395 .43197 m
.35502 .45101 L
s
% Start of user PostScript
0.357143 0.428571 0.347772 0.448563 MAarrowhead1
% End of user PostScript
.36395 .5 m
.36395 .51944 L
s
% Start of user PostScript
0.357143 0.5 0.357143 0.520408 MAarrowhead1
% End of user PostScript
.36395 .56803 m
.37287 .58707 L
s
% Start of user PostScript
0.357143 0.571429 0.366514 0.59142 MAarrowhead1
% End of user PostScript
.36395 .63605 m
.3818 .6539 L
s
% Start of user PostScript
0.357143 0.642857 0.375885 0.661599 MAarrowhead1
% End of user PostScript
.36395 .70408 m
.39072 .71995 L
s
% Start of user PostScript
0.357143 0.714286 0.385256 0.730945 MAarrowhead1
% End of user PostScript
.36395 .77211 m
.39964 .7852 L
s
% Start of user PostScript
0.357143 0.785714 0.394627 0.799459 MAarrowhead1
% End of user PostScript
.36395 .84014 m
.40857 .84966 L
s
% Start of user PostScript
0.357143 0.857143 0.403998 0.867139 MAarrowhead1
% End of user PostScript
.36395 .90816 m
.41749 .91332 L
s
% Start of user PostScript
0.357143 0.928571 0.413369 0.933986 MAarrowhead1
% End of user PostScript
.36395 .97619 m
.42642 .97619 L
s
% Start of user PostScript
0.357143 1. 0.422741 1. MAarrowhead1
% End of user PostScript
.43197 .02381 m
.36533 .02381 L
s
% Start of user PostScript
0.428571 0 0.358601 0 MAarrowhead1
% End of user PostScript
.43197 .09184 m
.37485 .09442 L
s
% Start of user PostScript
0.428571 0.0714286 0.368596 0.0741358 MAarrowhead1
% End of user PostScript
.43197 .15986 m
.38437 .16462 L
s
% Start of user PostScript
0.428571 0.142857 0.378592 0.147855 MAarrowhead1
% End of user PostScript
.43197 .22789 m
.39389 .23444 L
s
% Start of user PostScript
0.428571 0.214286 0.388588 0.221158 MAarrowhead1
% End of user PostScript
.43197 .29592 m
.40341 .30385 L
s
% Start of user PostScript
0.428571 0.285714 0.398584 0.294044 MAarrowhead1
% End of user PostScript
.43197 .36395 m
.41293 .37287 L
s
% Start of user PostScript
0.428571 0.357143 0.40858 0.366514 MAarrowhead1
% End of user PostScript
.43197 .43197 m
.42245 .44149 L
s
% Start of user PostScript
0.428571 0.428571 0.418576 0.438567 MAarrowhead1
% End of user PostScript
.43197 .5 m
.43197 .50972 L
s
% Start of user PostScript
0.428571 0.5 0.428571 0.510204 MAarrowhead1
% End of user PostScript
.43197 .56803 m
.44149 .57755 L
s
% Start of user PostScript
0.428571 0.571429 0.438567 0.581424 MAarrowhead1
% End of user PostScript
.43197 .63605 m
.45101 .64498 L
s
% Start of user PostScript
0.428571 0.642857 0.448563 0.652228 MAarrowhead1
% End of user PostScript
.43197 .70408 m
.46053 .71201 L
s
% Start of user PostScript
0.428571 0.714286 0.458559 0.722616 MAarrowhead1
% End of user PostScript
.43197 .77211 m
.47005 .77865 L
s
% Start of user PostScript
0.428571 0.785714 0.468555 0.792586 MAarrowhead1
% End of user PostScript
.43197 .84014 m
.47957 .8449 L
s
% Start of user PostScript
0.428571 0.857143 0.478551 0.862141 MAarrowhead1
% End of user PostScript
.43197 .90816 m
.48909 .91074 L
s
% Start of user PostScript
0.428571 0.928571 0.488546 0.931279 MAarrowhead1
% End of user PostScript
.43197 .97619 m
.49861 .97619 L
s
% Start of user PostScript
0.428571 1. 0.498542 1. MAarrowhead1
% End of user PostScript
.5 .02381 m
.43197 .02381 L
s
% Start of user PostScript
0.5 0 0.428571 0 MAarrowhead1
% End of user PostScript
.5 .09184 m
.44169 .09184 L
s
% Start of user PostScript
0.5 0.0714286 0.438776 0.0714286 MAarrowhead1
% End of user PostScript
.5 .15986 m
.45141 .15986 L
s
% Start of user PostScript
0.5 0.142857 0.44898 0.142857 MAarrowhead1
% End of user PostScript
.5 .22789 m
.46113 .22789 L
s
% Start of user PostScript
0.5 0.214286 0.459184 0.214286 MAarrowhead1
% End of user PostScript
.5 .29592 m
.47085 .29592 L
s
% Start of user PostScript
0.5 0.285714 0.469388 0.285714 MAarrowhead1
% End of user PostScript
.5 .36395 m
.48056 .36395 L
s
% Start of user PostScript
0.5 0.357143 0.479592 0.357143 MAarrowhead1
% End of user PostScript
.5 .43197 m
.49028 .43197 L
s
% Start of user PostScript
0.5 0.428571 0.489796 0.428571 MAarrowhead1
% End of user PostScript
.5 .5 m
.5 .5 L
s
% Start of user PostScript
0.5 0.5 MAarrowzero1
% End of user PostScript
.5 .56803 m
.50972 .56803 L
s
% Start of user PostScript
0.5 0.571429 0.510204 0.571429 MAarrowhead1
% End of user PostScript
.5 .63605 m
.51944 .63605 L
s
% Start of user PostScript
0.5 0.642857 0.520408 0.642857 MAarrowhead1
% End of user PostScript
.5 .70408 m
.52915 .70408 L
s
% Start of user PostScript
0.5 0.714286 0.530612 0.714286 MAarrowhead1
% End of user PostScript
.5 .77211 m
.53887 .77211 L
s
% Start of user PostScript
0.5 0.785714 0.540816 0.785714 MAarrowhead1
% End of user PostScript
.5 .84014 m
.54859 .84014 L
s
% Start of user PostScript
0.5 0.857143 0.55102 0.857143 MAarrowhead1
% End of user PostScript
.5 .90816 m
.55831 .90816 L
s
% Start of user PostScript
0.5 0.928571 0.561224 0.928571 MAarrowhead1
% End of user PostScript
.5 .97619 m
.56803 .97619 L
s
% Start of user PostScript
0.5 1. 0.571429 1. MAarrowhead1
% End of user PostScript
.56803 .02381 m
.50139 .02381 L
s
% Start of user PostScript
0.571429 0 0.501458 0 MAarrowhead1
% End of user PostScript
.56803 .09184 m
.51091 .08926 L
s
% Start of user PostScript
0.571429 0.0714286 0.511454 0.0687214 MAarrowhead1
% End of user PostScript
.56803 .15986 m
.52043 .1551 L
s
% Start of user PostScript
0.571429 0.142857 0.521449 0.137859 MAarrowhead1
% End of user PostScript
.56803 .22789 m
.52995 .22135 L
s
% Start of user PostScript
0.571429 0.214286 0.531445 0.207414 MAarrowhead1
% End of user PostScript
.56803 .29592 m
.53947 .28799 L
s
% Start of user PostScript
0.571429 0.285714 0.541441 0.277384 MAarrowhead1
% End of user PostScript
.56803 .36395 m
.54899 .35502 L
s
% Start of user PostScript
0.571429 0.357143 0.551437 0.347772 MAarrowhead1
% End of user PostScript
.56803 .43197 m
.55851 .42245 L
s
% Start of user PostScript
0.571429 0.428571 0.561433 0.418576 MAarrowhead1
% End of user PostScript
.56803 .5 m
.56803 .49028 L
s
% Start of user PostScript
0.571429 0.5 0.571429 0.489796 MAarrowhead1
% End of user PostScript
.56803 .56803 m
.57755 .55851 L
s
% Start of user PostScript
0.571429 0.571429 0.581424 0.561433 MAarrowhead1
% End of user PostScript
.56803 .63605 m
.58707 .62713 L
s
% Start of user PostScript
0.571429 0.642857 0.59142 0.633486 MAarrowhead1
% End of user PostScript
.56803 .70408 m
.59659 .69615 L
s
% Start of user PostScript
0.571429 0.714286 0.601416 0.705956 MAarrowhead1
% End of user PostScript
.56803 .77211 m
.60611 .76556 L
s
% Start of user PostScript
0.571429 0.785714 0.611412 0.778842 MAarrowhead1
% End of user PostScript
.56803 .84014 m
.61563 .83538 L
s
% Start of user PostScript
0.571429 0.857143 0.621408 0.852145 MAarrowhead1
% End of user PostScript
.56803 .90816 m
.62515 .90558 L
s
% Start of user PostScript
0.571429 0.928571 0.631404 0.925864 MAarrowhead1
% End of user PostScript
.56803 .97619 m
.63467 .97619 L
s
% Start of user PostScript
0.571429 1. 0.641399 1. MAarrowhead1
% End of user PostScript
.63605 .02381 m
.57358 .02381 L
s
% Start of user PostScript
0.642857 0 0.577259 0 MAarrowhead1
% End of user PostScript
.63605 .09184 m
.58251 .08668 L
s
% Start of user PostScript
0.642857 0.0714286 0.586631 0.0660142 MAarrowhead1
% End of user PostScript
.63605 .15986 m
.59143 .15034 L
s
% Start of user PostScript
0.642857 0.142857 0.596002 0.132861 MAarrowhead1
% End of user PostScript
.63605 .22789 m
.60036 .2148 L
s
% Start of user PostScript
0.642857 0.214286 0.605373 0.200541 MAarrowhead1
% End of user PostScript
.63605 .29592 m
.60928 .28005 L
s
% Start of user PostScript
0.642857 0.285714 0.614744 0.269055 MAarrowhead1
% End of user PostScript
.63605 .36395 m
.6182 .3461 L
s
% Start of user PostScript
0.642857 0.357143 0.624115 0.338401 MAarrowhead1
% End of user PostScript
.63605 .43197 m
.62713 .41293 L
s
% Start of user PostScript
0.642857 0.428571 0.633486 0.40858 MAarrowhead1
% End of user PostScript
.63605 .5 m
.63605 .48056 L
s
% Start of user PostScript
0.642857 0.5 0.642857 0.479592 MAarrowhead1
% End of user PostScript
.63605 .56803 m
.64498 .54899 L
s
% Start of user PostScript
0.642857 0.571429 0.652228 0.551437 MAarrowhead1
% End of user PostScript
.63605 .63605 m
.6539 .6182 L
s
% Start of user PostScript
0.642857 0.642857 0.661599 0.624115 MAarrowhead1
% End of user PostScript
.63605 .70408 m
.66283 .68822 L
s
% Start of user PostScript
0.642857 0.714286 0.67097 0.697626 MAarrowhead1
% End of user PostScript
.63605 .77211 m
.67175 .75902 L
s
% Start of user PostScript
0.642857 0.785714 0.680342 0.77197 MAarrowhead1
% End of user PostScript
.63605 .84014 m
.68068 .83062 L
s
% Start of user PostScript
0.642857 0.857143 0.689713 0.847147 MAarrowhead1
% End of user PostScript
.63605 .90816 m
.6896 .90301 L
s
% Start of user PostScript
0.642857 0.928571 0.699084 0.923157 MAarrowhead1
% End of user PostScript
.63605 .97619 m
.69853 .97619 L
s
% Start of user PostScript
0.642857 1. 0.708455 1. MAarrowhead1
% End of user PostScript
.70408 .02381 m
.64855 .02381 L
s
% Start of user PostScript
0.714286 0 0.655977 0 MAarrowhead1
% End of user PostScript
.70408 .09184 m
.65648 .0841 L
s
% Start of user PostScript
0.714286 0.0714286 0.664307 0.063307 MAarrowhead1
% End of user PostScript
.70408 .15986 m
.66442 .14558 L
s
% Start of user PostScript
0.714286 0.142857 0.672636 0.127863 MAarrowhead1
% End of user PostScript
.70408 .22789 m
.67235 .20826 L
s
% Start of user PostScript
0.714286 0.214286 0.680966 0.193669 MAarrowhead1
% End of user PostScript
.70408 .29592 m
.68028 .27212 L
s
% Start of user PostScript
0.714286 0.285714 0.689296 0.260725 MAarrowhead1
% End of user PostScript
.70408 .36395 m
.68822 .33717 L
s
% Start of user PostScript
0.714286 0.357143 0.697626 0.32903 MAarrowhead1
% End of user PostScript
.70408 .43197 m
.69615 .40341 L
s
% Start of user PostScript
0.714286 0.428571 0.705956 0.398584 MAarrowhead1
% End of user PostScript
.70408 .5 m
.70408 .47085 L
s
% Start of user PostScript
0.714286 0.5 0.714286 0.469388 MAarrowhead1
% End of user PostScript
.70408 .56803 m
.71201 .53947 L
s
% Start of user PostScript
0.714286 0.571429 0.722616 0.541441 MAarrowhead1
% End of user PostScript
.70408 .63605 m
.71995 .60928 L
s
% Start of user PostScript
0.714286 0.642857 0.730945 0.614744 MAarrowhead1
% End of user PostScript
.70408 .70408 m
.72788 .68028 L
s
% Start of user PostScript
0.714286 0.714286 0.739275 0.689296 MAarrowhead1
% End of user PostScript
.70408 .77211 m
.73581 .75247 L
s
% Start of user PostScript
0.714286 0.785714 0.747605 0.765098 MAarrowhead1
% End of user PostScript
.70408 .84014 m
.74375 .82586 L
s
% Start of user PostScript
0.714286 0.857143 0.755935 0.842149 MAarrowhead1
% End of user PostScript
.70408 .90816 m
.75168 .90043 L
s
% Start of user PostScript
0.714286 0.928571 0.764265 0.92045 MAarrowhead1
% End of user PostScript
.70408 .97619 m
.75961 .97619 L
s
% Start of user PostScript
0.714286 1. 0.772595 1. MAarrowhead1
% End of user PostScript
.77211 .02381 m
.72629 .02381 L
s
% Start of user PostScript
0.785714 0 0.737609 0 MAarrowhead1
% End of user PostScript
.77211 .09184 m
.73284 .08152 L
s
% Start of user PostScript
0.785714 0.0714286 0.744481 0.0605998 MAarrowhead1
% End of user PostScript
.77211 .15986 m
.73938 .14082 L
s
% Start of user PostScript
0.785714 0.142857 0.751354 0.122865 MAarrowhead1
% End of user PostScript
.77211 .22789 m
.74593 .20171 L
s
% Start of user PostScript
0.785714 0.214286 0.758226 0.186797 MAarrowhead1
% End of user PostScript
.77211 .29592 m
.75247 .26419 L
s
% Start of user PostScript
0.785714 0.285714 0.765098 0.252395 MAarrowhead1
% End of user PostScript
.77211 .36395 m
.75902 .32825 L
s
% Start of user PostScript
0.785714 0.357143 0.77197 0.319658 MAarrowhead1
% End of user PostScript
.77211 .43197 m
.76556 .39389 L
s
% Start of user PostScript
0.785714 0.428571 0.778842 0.388588 MAarrowhead1
% End of user PostScript
.77211 .5 m
.77211 .46113 L
s
% Start of user PostScript
0.785714 0.5 0.785714 0.459184 MAarrowhead1
% End of user PostScript
.77211 .56803 m
.77865 .52995 L
s
% Start of user PostScript
0.785714 0.571429 0.792586 0.531445 MAarrowhead1
% End of user PostScript
.77211 .63605 m
.7852 .60036 L
s
% Start of user PostScript
0.785714 0.642857 0.799459 0.605373 MAarrowhead1
% End of user PostScript
.77211 .70408 m
.79174 .67235 L
s
% Start of user PostScript
0.785714 0.714286 0.806331 0.680966 MAarrowhead1
% End of user PostScript
.77211 .77211 m
.79829 .74593 L
s
% Start of user PostScript
0.785714 0.785714 0.813203 0.758226 MAarrowhead1
% End of user PostScript
.77211 .84014 m
.80483 .8211 L
s
% Start of user PostScript
0.785714 0.857143 0.820075 0.837151 MAarrowhead1
% End of user PostScript
.77211 .90816 m
.81138 .89785 L
s
% Start of user PostScript
0.785714 0.928571 0.826947 0.917743 MAarrowhead1
% End of user PostScript
.77211 .97619 m
.81792 .97619 L
s
% Start of user PostScript
0.785714 1. 0.833819 1. MAarrowhead1
% End of user PostScript
.84014 .02381 m
.80682 .02381 L
s
% Start of user PostScript
0.857143 0 0.822157 0 MAarrowhead1
% End of user PostScript
.84014 .09184 m
.81158 .07895 L
s
% Start of user PostScript
0.857143 0.0714286 0.827155 0.0578925 MAarrowhead1
% End of user PostScript
.84014 .15986 m
.81634 .13606 L
s
% Start of user PostScript
0.857143 0.142857 0.832153 0.117868 MAarrowhead1
% End of user PostScript
.84014 .22789 m
.8211 .19517 L
s
% Start of user PostScript
0.857143 0.214286 0.837151 0.179925 MAarrowhead1
% End of user PostScript
.84014 .29592 m
.82586 .25625 L
s
% Start of user PostScript
0.857143 0.285714 0.842149 0.244065 MAarrowhead1
% End of user PostScript
.84014 .36395 m
.83062 .31932 L
s
% Start of user PostScript
0.857143 0.357143 0.847147 0.310287 MAarrowhead1
% End of user PostScript
.84014 .43197 m
.83538 .38437 L
s
% Start of user PostScript
0.857143 0.428571 0.852145 0.378592 MAarrowhead1
% End of user PostScript
.84014 .5 m
.84014 .45141 L
s
% Start of user PostScript
0.857143 0.5 0.857143 0.44898 MAarrowhead1
% End of user PostScript
.84014 .56803 m
.8449 .52043 L
s
% Start of user PostScript
0.857143 0.571429 0.862141 0.521449 MAarrowhead1
% End of user PostScript
.84014 .63605 m
.84966 .59143 L
s
% Start of user PostScript
0.857143 0.642857 0.867139 0.596002 MAarrowhead1
% End of user PostScript
.84014 .70408 m
.85442 .66442 L
s
% Start of user PostScript
0.857143 0.714286 0.872137 0.672636 MAarrowhead1
% End of user PostScript
.84014 .77211 m
.85918 .73938 L
s
% Start of user PostScript
0.857143 0.785714 0.877135 0.751354 MAarrowhead1
% End of user PostScript
.84014 .84014 m
.86394 .81634 L
s
% Start of user PostScript
0.857143 0.857143 0.882132 0.832153 MAarrowhead1
% End of user PostScript
.84014 .90816 m
.8687 .89527 L
s
% Start of user PostScript
0.857143 0.928571 0.88713 0.915035 MAarrowhead1
% End of user PostScript
.84014 .97619 m
.87346 .97619 L
s
% Start of user PostScript
0.857143 1. 0.892128 1. MAarrowhead1
% End of user PostScript
.90816 .02381 m
.89012 .02381 L
s
% Start of user PostScript
0.928571 0 0.909621 0 MAarrowhead1
% End of user PostScript
.90816 .09184 m
.89269 .07637 L
s
% Start of user PostScript
0.928571 0.0714286 0.912328 0.0551853 MAarrowhead1
% End of user PostScript
.90816 .15986 m
.89527 .1313 L
s
% Start of user PostScript
0.928571 0.142857 0.915035 0.11287 MAarrowhead1
% End of user PostScript
.90816 .22789 m
.89785 .18862 L
s
% Start of user PostScript
0.928571 0.214286 0.917743 0.173053 MAarrowhead1
% End of user PostScript
.90816 .29592 m
.90043 .24832 L
s
% Start of user PostScript
0.928571 0.285714 0.92045 0.235735 MAarrowhead1
% End of user PostScript
.90816 .36395 m
.90301 .3104 L
s
% Start of user PostScript
0.928571 0.357143 0.923157 0.300916 MAarrowhead1
% End of user PostScript
.90816 .43197 m
.90558 .37485 L
s
% Start of user PostScript
0.928571 0.428571 0.925864 0.368596 MAarrowhead1
% End of user PostScript
.90816 .5 m
.90816 .44169 L
s
% Start of user PostScript
0.928571 0.5 0.928571 0.438776 MAarrowhead1
% End of user PostScript
.90816 .56803 m
.91074 .51091 L
s
% Start of user PostScript
0.928571 0.571429 0.931279 0.511454 MAarrowhead1
% End of user PostScript
.90816 .63605 m
.91332 .58251 L
s
% Start of user PostScript
0.928571 0.642857 0.933986 0.586631 MAarrowhead1
% End of user PostScript
.90816 .70408 m
.9159 .65648 L
s
% Start of user PostScript
0.928571 0.714286 0.936693 0.664307 MAarrowhead1
% End of user PostScript
.90816 .77211 m
.91848 .73284 L
s
% Start of user PostScript
0.928571 0.785714 0.9394 0.744481 MAarrowhead1
% End of user PostScript
.90816 .84014 m
.92105 .81158 L
s
% Start of user PostScript
0.928571 0.857143 0.942107 0.827155 MAarrowhead1
% End of user PostScript
.90816 .90816 m
.92363 .89269 L
s
% Start of user PostScript
0.928571 0.928571 0.944815 0.912328 MAarrowhead1
% End of user PostScript
.90816 .97619 m
.92621 .97619 L
s
% Start of user PostScript
0.928571 1. 0.947522 1. MAarrowhead1
% End of user PostScript
.97619 .02381 m
.97619 .02381 L
s
% Start of user PostScript
1. 0 MAarrowzero1
% End of user PostScript
.97619 .09184 m
.97619 .07379 L
s
% Start of user PostScript
1. 0.0714286 1. 0.0524781 MAarrowhead1
% End of user PostScript
.97619 .15986 m
.97619 .12654 L
s
% Start of user PostScript
1. 0.142857 1. 0.107872 MAarrowhead1
% End of user PostScript
.97619 .22789 m
.97619 .18208 L
s
% Start of user PostScript
1. 0.214286 1. 0.166181 MAarrowhead1
% End of user PostScript
.97619 .29592 m
.97619 .24039 L
s
% Start of user PostScript
1. 0.285714 1. 0.227405 MAarrowhead1
% End of user PostScript
.97619 .36395 m
.97619 .30147 L
s
% Start of user PostScript
1. 0.357143 1. 0.291545 MAarrowhead1
% End of user PostScript
.97619 .43197 m
.97619 .36533 L
s
% Start of user PostScript
1. 0.428571 1. 0.358601 MAarrowhead1
% End of user PostScript
.97619 .5 m
.97619 .43197 L
s
% Start of user PostScript
1. 0.5 1. 0.428571 MAarrowhead1
% End of user PostScript
.97619 .56803 m
.97619 .50139 L
s
% Start of user PostScript
1. 0.571429 1. 0.501458 MAarrowhead1
% End of user PostScript
.97619 .63605 m
.97619 .57358 L
s
% Start of user PostScript
1. 0.642857 1. 0.577259 MAarrowhead1
% End of user PostScript
.97619 .70408 m
.97619 .64855 L
s
% Start of user PostScript
1. 0.714286 1. 0.655977 MAarrowhead1
% End of user PostScript
.97619 .77211 m
.97619 .72629 L
s
% Start of user PostScript
1. 0.785714 1. 0.737609 MAarrowhead1
% End of user PostScript
.97619 .84014 m
.97619 .80682 L
s
% Start of user PostScript
1. 0.857143 1. 0.822157 MAarrowhead1
% End of user PostScript
.97619 .90816 m
.97619 .89012 L
s
% Start of user PostScript
1. 0.928571 1. 0.909621 MAarrowhead1
% End of user PostScript
.97619 .97619 m
.97619 .97619 L
s
% Start of user PostScript
1. 1. MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo002DOol30004Ool400000goo00000002Ool200000goo00000002001e
Ool009Eoo`03001oogoo00Aoo`03001oogoo009oo`04001oo`000003Ool00`00Oomoo`1eOol009Eo
o`<000Aoo`03001oogoo009oo`<000Eoo`03001oogoo07Aoo`00UGoo00@007ooOol000=oo`8000=o
o`04001oogoo0005Ool00`00Oomoo`1cOol009Eoo`04001oogoo0002Ool200001Goo000007oo0000
0Woo00@007ooOol0009oo`03001oogoo07=oo`00U7oo100027oo100017oo0P00MWoo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol002Uoo`8002Moo`8000Aoo`8000=oo`@0025oo`8000Aoo`80
00Aoo`<0021oo`8000Aoo`8000Aoo`80025oo`8000Aoo`8000Aoo`8002Ioo`<000Uoo`00:7oo00@0
07ooOol002Eoo`04001oogoo0003Ool20004Ool00`00Oomoo`0POol01000Oomoo`000goo0P001Goo
00<007ooOol07Woo00@007ooOol000=oo`8000=oo`04001oogoo000OOol01000Oomoo`000goo0P00
0goo00@007ooOol002Ioo`03001oogoo00Qoo`00:7oo00@007ooOol002Eoo`04001oogoo000:Ool0
0`00Oomoo`0OOol01000Oomoo`0027oo10007goo00@007ooOol000Qoo`04001oogoo000OOol01000
Oomoo`0027oo00@007ooOol002Ioo`03001oogoo00Qoo`00:7oo00@007ooOol002Eoo`04001oogoo
000;Ool00`00Oomoo`0NOol01000Oomoo`0027oo00<007oo000087oo00@007ooOol000Qoo`<0021o
o`04001oogoo0009Ool2000WOol00`00Oomoo`08Ool002Qoo`04001oogoo000UOol01000Oomoo`00
27oo00@007ooOol0021oo`04001oogoo0008Ool00`00Ool0000POol01000Oomoo`0027oo00<007oo
Ool087oo00@007ooOol000Qoo`04001oogoo000VOol00`00Oomoo`08Ool002Uoo`8002Moo`8000Yo
o`80029oo`8000Yoo`80025oo`8000Yoo`<0021oo`8000Yoo`8002Ioo`8000Yoo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol002AoooT000=oo`0097oo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<0
07ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool001eoo`8000Eo
o`03001oogoo0?Eoo`03001oogoo005oo`0077oo00@007ooOol000Aoo`03001oogoo01=oo`<000Yo
o`<000Yoo`<000aoo`<000aoo`<000eoo`<000eoo`<000moo`<000ioo`<0011oo`<0011oo`<0015o
o`<0019oo`<001Eoo`03001oogoo005oo`0077oo00@007ooOol000Aoo`<000=oo`03001oogoo00Yo
o`H000Moo`T000Aoo`d0009oof<0009oo`l000Aoo`d000Moo`X000]oo`H000moo`03001oogoo009o
o`8000=oo`0077oo00@007ooOol000Aoo`03001oogoo019oo`@000Uoo`@000Uoo`@000]oo`@000]o
o`@000aoo`@000aoo`@000ioo`@000eoo`@000moo`@000moo`@0011oo`@0015oo`@001Eoo`03001o
ogoo005oo`0077oo00@007ooOol000Aoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo00eoo`03001oogoo00mo
o`03001oogoo00ioo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo01=oo`03001oogoo005oo`007Goo0P001Goo00<007ooOol0mGoo00<007ooOol00Goo
000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`00
97oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Ao
o`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol0
0`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo0P00
mGoo0P000goo000TOol00`00Oomoo`3_Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001o
ogoo0<Ioo`@0015oo`80019oo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0TGoo
0`0037oo1P003Goo1P003goo10003goo100047oo00<007ooOol00goo00<007ooOol00Goo000TOol0
0`00Oomoo`1^Ool3000>Ool3000<Ool8000<Ool8000;Ool7000=Ool5000>Ool4000>Ool30004Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000ioo`8000eoo`04001oo`00000:Ool20002Ool3
0008Ool20003Ool40006Ool20005Ool40004Ool300000goo000000060002Ool?0002Ool?0005Ool4
0002Ool60009Ool00`00Oomoo`02Ool3000:Ool00`00Oomoo`02Ool2000<Ool01@00Oomoogoo0000
3Goo0`003goo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`02Ool3000>Ool2000<Ool3000:
Ool60008Ool80007Ool:0005Ool7000<Ool4000?Ool2000AOol00`00Oomoo`17Ool00`00Oomoo`0>
Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000eoo`@000Yoo`@000Uoo`D000Uo
o`H000Uoo`H000ioo`80011oo`03001oogoo089oo`03001oogoo005oo`0097oo00<007ooOol00goo
00<007ooOol02goo0`002goo1@0027oo1P003Goo0P00]7oo00<007ooOol00Goo000TOol00`00Oomo
o`03Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool3003DOol00`00Oomoo`01Ool002Aoo`03001oogoo
00=oo`03001oogoo0>moo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000T
Ool2003eOol20003Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0kgoo
00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`3KOol00`00Oomoo`0AOol00`00Oomo
o`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo0<Qoo`80015oo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo005oo`0097oo00<007ooOol0]Goo0P004Goo0`0047oo0P004Goo0`0017oo00<0
07ooOol00Goo000TOol00`00Oomoo`2eOol4000@Ool3000@Ool2000@Ool30004Ool00`00Oomoo`01
Ool002Aoo`03001oogoo0:9oo`H000ioo`@000moo`@000moo`<000moo`<000Aoo`03001oogoo005o
o`0097oo00<007ooOol0PGoo0`0037oo1P003Woo10003goo1@003Goo10003goo0P004Goo00<007oo
Ool00goo00<007ooOol00Goo000TOol00`00Oomoo`1`Ool3000;Ool7000=Ool7000<Ool2000017oo
000000003Goo00D007ooOomoo`0000eoo`04001oogoo000?Ool00`00Oomoo`0?Ool00`00Oomoo`03
Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001o
ogoo00eoo`8000moo`8000Qoo`8000Aoo`<000Ioo`<00003Ool0000000@000Aoo`d000Ioo`@00003
Ool0000000@000Uoo`03001oogoo009oo`<000Yoo`03001oogoo009oo`80011oo`03001oogoo00io
o`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol02Woo00@007ooOol000]oo`800004
Ool000000008Ool80007Ool6000>Ool2000@Ool00`00Oomoo`1_Ool00`00Oomoo`01Ool002Aoo`80
00Aoo`03001oogoo00aoo`8000ioo`8000eoo`<000]oo`@000Yoo`H000ioo`80095oo`8000=oo`00
97oo00<007ooOol00goo00<007ooOol037oo0`003Goo0P0037oo0`002goo1@002Goo1`00XWoo00<0
07ooOol00Goo000TOol00`00Oomoo`02Ool3000=Ool3000<Ool00`00Oomoo`0;Ool50009Ool3002e
Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000aoo`<000aoo`03001oogoo00]oo`<00<Ao
o`03001oogoo005oo`0097oo00<007ooOol00Woo0`0037oo0P0037oo00<007ooOol0cGoo00<007oo
Ool00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`38Ool0
0`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo
0=Ioo`03001oogoo011oo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0bGoo00<0
07ooOol047oo0P0047oo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`39Ool00`00Oomoo`0@
Ool2000@Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo0;Ioo`80015oo`80015oo`80011o
o`<000Aoo`03001oogoo005oo`004Goo0P0017oo0P000goo100017oo00<007ooOol0Y7oo0P0047oo
1@003goo0P0047oo0`0047oo00<007ooOol00goo00<007ooOol00Goo000@Ool01000Oomoo`000goo
0P0017oo00<007ooOol017oo00<007ooOol0YGoo10003Woo1@003Woo0`0047oo00<007ooOol03goo
00<007ooOol00goo00<007ooOol00Goo000@Ool01000Oomoo`002Woo00<007ooOol00goo0`00TWoo
1P003Woo10003Woo0`003goo00<007oo000047oo00<007ooOol03goo00<007ooOol00Woo0P000goo
000@Ool01000Oomoo`002goo00<007ooOol00Woo00<007ooOol0PGoo1P003Goo10003goo10003Woo
00<007oo000047oo00<007ooOol03goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo
000@Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo07=oo`<000eoo`H000aoo`800004
Ool00000000=Ool01000Oomoo`0047oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol00Goo000AOol2000:Ool20005Ool00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool2000:Ool20003Ool2000:Ool2
000017oo000000001goo2P002Woo0P000goo0P002goo00<007ooOol00Woo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=
Ool00`00Oomoo`0:Ool01000Oomoo`002goo1P002Goo1P003Woo0P003goo00<007ooOol0KGoo00<0
07ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0;
Ool00`00Ool0000=Ool3000;Ool5000:Ool6002@Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=o
o`03001oogoo00eoo`03001oogoo00aoo`8000ioo`8000eoo`@000Yoo`H009Yoo`03001oogoo00=o
o`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Goo00<007ooOol037oo0P003Goo
10002goo0`00[7oo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomo
o`0<Ool3000<Ool4000;Ool3000<Ool00`00Oomoo`2JOol00`00Oomoo`0@Ool00`00Oomoo`03Ool0
0`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000eoo`<000aoo`8000eoo`03001oogoo0:Uoo`03
001oogoo00moo`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003Goo0P003Goo00<0
07ooOol02goo00<007ooOol0V7oo00<007ooOol03goo0P0047oo0`0017oo00<007ooOol00Goo000T
Ool20003Ool3000=Ool2000<Ool00`00Oomoo`2WOol00`00Oomoo`0?Ool2000@Ool30003Ool20003
Ool002Aoo`03001oogoo00=oo`03001oogoo00aoo`800:Aoo`03001oogoo00moo`80011oo`80015o
o`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol037oo00<007oo
Ool0Xgoo00<007ooOol03goo0`003goo0`0047oo00<007ooOol00goo00<007ooOol00Goo000TOol0
0`00Oomoo`03Ool00`00Oomoo`2POol2000@Ool2000@Ool4000?Ool00`00Oomoo`0?Ool00`00Oomo
o`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo0:Ioo`<0011oo`8000moo`<0011oo`03001oogoo
00moo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0U7oo10003goo0`003goo0`00
47oo00<007ooOol03Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`2EOol5000>Ool3000>Ool00`00Ool0000AOol00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo08=oo`H000eoo`@000moo`80011oo`03001o
ogoo00moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo
00<007ooOol0IGoo0P003Woo0`003Goo10003Woo100047oo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`0;Ool01000Ool000002Woo1P002Goo200037oo0P0000=oo`0000003Goo00@007ooOol0011oo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol0
3Woo00<007ooOol02Woo00@007ooOol000eoo`<000]oo`D000moo`8000moo`03001oogoo06Eoo`03
001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol03Woo00<007ooOol02goo0`003Goo10002Woo1P00R7oo00<007ooOol00goo00<0
07ooOol00Goo000TOol20004Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool3000=
Ool4000<Ool3002JOol00`00Oomoo`02Ool20003Ool002Aoo`03001oogoo00=oo`03001oogoo00eo
o`03001oogoo00ioo`03001oogoo00]oo`@000aoo`8000eoo`03001oogoo08Uoo`03001oogoo00io
o`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Goo00<007ooOol037oo
0P003Woo0`003Goo00<007ooOol0V7oo00<007ooOol03Woo0`0017oo00<007ooOol00Goo000TOol0
0`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool3000<Ool3000=Ool00`00Oomoo`27Ool0
0`00Oomoo`0?Ool2000?Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo
00aoo`<000eoo`<000aoo`8009Qoo`03001oogoo00ioo`<0011oo`03001oogoo00=oo`03001oogoo
005oo`0097oo00<007ooOol00goo00<007ooOol037oo0`0037oo0`003Goo00<007ooOol0QGoo00<0
07ooOol03goo0P003goo10003goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`02
Ool3000=Ool2000=Ool2002FOol00`00Oomoo`0?Ool2000?Ool2000AOol00`00Oomoo`03Ool00`00
Oomoo`01Ool002Aoo`03001oogoo009oo`<000eoo`8000eoo`03001oogoo08Aoo`03001oogoo00io
o`80011oo`<000moo`03001oogoo00moo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007oo
Ool00Woo0`003Goo0P00U7oo00<007ooOol03goo0P003goo0P004Goo00<007ooOol03Woo00<007oo
Ool00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`22Ool2
000?Ool2000@Ool3000@Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`01Ool002Aoo`03001oogoo00=oo`03001oogoo095oo`<000moo`8000moo`80015oo`03001oogoo
00ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<0
07ooOol0TWoo0`003Woo0`003goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol00Goo000TOol20026Ool4000?Ool4000=Ool00`00Ool0000@Ool00`00
Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool20003Ool002Aoo`03001o
ogoo06Moo`8000ioo`<000eoo`@000eoo`<0011oo`03001oogoo00ioo`03001oogoo00moo`03001o
ogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol037oo
0`003Goo0`002goo1P003Woo0`003Woo00<007oo000047oo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool5000>Ool2000?Ool00`00Oomoo`1SOol00`00Oomoo`03Ool00`00Oomo
o`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03
001oogoo00aoo`<000ioo`<000aoo`<007Moo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo
005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<0
07ooOol037oo0`003Goo0P00R7oo00<007ooOol03Goo0`0017oo00<007ooOol00Goo000TOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool3000>Ool2000=Ool00`00
Oomoo`28Ool00`00Oomoo`0=Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001o
ogoo00ioo`03001oogoo00eoo`03001oogoo00aoo`<000eoo`8008Moo`03001oogoo00moo`8000io
o`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol02goo
10003Goo0P003Woo00<007ooOol0QWoo00<007ooOol03Woo0`003goo00<007ooOol00goo00<007oo
Ool00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool4000=Ool20026Ool0
0`00Oomoo`0>Ool2000?Ool3000?Ool00`00Oomoo`03Ool00`00Oomoo`01Ool0015oo`8000Aoo`80
00Aoo`<000Aoo`03001oogoo00=oo`03001oogoo00aoo`@000aoo`<000ioo`8008Ioo`03001oogoo
00ioo`8000moo`80011oo`03001oogoo00=oo`03001oogoo005oo`0047oo00@007ooOol000=oo`80
00Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00aoo`@000eoo`8000ioo`03001oogoo
08Eoo`8000moo`80011oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0047oo00@0
07ooOol000Qoo`@000Aoo`<0009oo`<000eoo`<000ioo`8008Eoo`03001oogoo00ioo`8000moo`<0
00moo`03001oogoo00ioo`03001oogoo009oo`8000=oo`0047oo00@007ooOol000Qoo`03001oo`00
00Eoo`03001oogoo009oo`<000ioo`8000ioo`03001oogoo08Aoo`03001oogoo00ioo`80011oo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0047oo00@007ooOol0
00Qoo`03001oo`0000Eoo`03001oogoo009oo`<000ioo`8008Aoo`03001oogoo00ioo`8000moo`<0
00moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`004Goo0P00
2Woo0P001Goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0Pgoo00<007ooOol03Woo0P00
47oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0
0Goo000TOol00`00Oomoo`03Ool00`00Oomoo`22Ool2000?Ool2000?Ool3000?Ool00`00Oomoo`0>
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001o
ogoo00=oo`03001oogoo06=oo`03001oogoo00moo`8000]oo`<000moo`8000ioo`80015oo`03001o
ogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo
00<007ooOol0EWoo0`0047oo0P003Goo1@0037oo0`003Woo0`003goo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0<Ool4000>Ool00`00Oomoo`0<Ool6000<Ool4000=Ool2000@Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool0
02Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
00ioo`03001oogoo00aoo`<000ioo`03001oogoo015oo`8000aoo`<006=oo`03001oogoo00=oo`03
001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol0
3Woo00<007ooOol037oo0`003Goo0`003Woo00<007ooOol08Goo00<007ooOol0DGoo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool3000=Ool20027Ool00`00Oomoo`0=Ool30004
Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001o
ogoo00aoo`<000ioo`8000ioo`03001oogoo07Ioo`03001oogoo00eoo`8000ioo`<000Aoo`03001o
ogoo005oo`002goo0`005Woo0P0017oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol037oo
0`003Woo0P00Qgoo00<007ooOol037oo0`003Woo0`000goo0P000goo000<Ool00`00Oomoo`0EOol0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool2000?Ool2000?Ool20026Ool2000>Ool3
000?Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000aoo`<001Eoo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo00aoo`<000ioo`8000moo`03001oogoo07Eoo`03001oogoo00eoo`<000eoo`@0
00ioo`03001oogoo00=oo`03001oogoo005oo`0037oo00@007ooOol001Aoo`03001oogoo00=oo`03
001oogoo00eoo`03001oogoo00eoo`<000ioo`8008Moo`03001oogoo00eoo`<000ioo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo005oo`0037oo00@007ooOol001Aoo`03001oogoo00=oo`03
001oogoo00aoo`@000ioo`8000ioo`03001oogoo07Eoo`03001oogoo00eoo`8000ioo`@000ioo`03
001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`002goo10005Goo00<007ooOol00goo00<0
07ooOol037oo10003Woo00<007ooOol0QGoo00<007ooOol03Goo0`003goo00<007ooOol03Goo00<0
07ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000<Ool4000DOol00`00Oomoo`02Ool3000=
Ool3000?Ool00`00Oomoo`25Ool00`00Oomoo`0=Ool3000?Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000eoo`03001oogoo01Aoo`03001oogoo009oo`<000io
o`8008Ioo`03001oogoo00eoo`<000eoo`@000moo`03001oogoo00eoo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo005oo`003Goo00<007ooOol057oo00<007ooOol00Woo0`003Woo0P00QWoo
00<007ooOol03Goo0`003goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007oo
Ool00goo00<007ooOol00Goo000=Ool2000EOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomo
o`1AOol4000OOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool3000?Ool00`00Oomoo`0>Ool00`00Oomo
o`0=Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000aoo`800003Ool0000001=o
o`03001oogoo00=oo`03001oogoo065oo`@001moo`03001oogoo00eoo`<000moo`03001oogoo00io
o`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005o
o`0097oo0P0017oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol037oo10003Goo0`003goo00<007ooOol03Woo00<007ooOol03Goo0`003goo00<007oo
Ool03Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00Woo0P000goo
000<Ool4000DOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0<Ool4000>Ool2000OOol3000>Ool3001BOol00`00Oomoo`03Ool0
0`00Oomoo`01Ool000]oo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`<000ioo`8001moo`<006=oo`03
001oogoo00=oo`03001oogoo005oo`002goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol037oo10003Woo0P003goo00<007ooOol0
7Woo0`00Dgoo00<007ooOol03Goo00<007ooOol00goo00<007ooOol00Goo000;Ool00`00Oomoo`0F
Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0<
Ool4000>Ool20026Ool00`00Oomoo`0<Ool30004Ool00`00Oomoo`01Ool000]oo`05001oogooOol0
000DOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool3000>Ool3
000?Ool00`00Oomoo`24Ool00`00Oomoo`0<Ool30004Ool00`00Oomoo`01Ool000aoo`@001Aoo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`<000ioo`8008Moo`03
001oogoo00aoo`<000eoo`<000Aoo`03001oogoo005oo`0037oo100057oo00<007ooOol00goo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo0`003Woo0P00Qgoo00<007ooOol037oo0`00
3Woo00<007ooOol00goo00<007ooOol00Goo000=Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00
Oomoo`0>Ool00`00Oomoo`0=Ool3000?Ool00`00Oomoo`0>Ool00`00Oomoo`1dOol00`00Oomoo`0=
Ool2000>Ool3000>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool000ioo`03001oogoo01=oo`03001o
ogoo00=oo`03001oogoo00ioo`03001oogoo00eoo`<000moo`03001oogoo08Eoo`03001oogoo00eo
o`8000moo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo005oo`003goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol03Goo0`003Woo0`003goo00<007ooOol0MGoo00<007ooOol037oo
0P003Woo0`003goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol00Goo000<Ool01000Oomo
o`0057oo00<007ooOol00goo00<007ooOol03Goo0`003goo00<007ooOol0QWoo00<007ooOol037oo
0`003goo00<007ooOol037oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000=Ool2
000EOol20003Ool3000>Ool3000?Ool00`00Oomoo`25Ool2000>Ool3000>Ool00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool20003Ool002Aoo`03001oogoo009oo`<000moo`03001oogoo
00ioo`03001oogoo07Eoo`03001oogoo00aoo`<000eoo`@000ioo`03001oogoo00eoo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003goo00<007ooOol0
QWoo00<007ooOol037oo0`003Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`1A
Ool00`00Oomoo`0POol2000?Ool2000=Ool4000>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo065o
o`8000ioo`@000moo`<000ioo`8000moo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eo
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007oo
Ool03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo0P0037oo
10003Goo1P0037oo0`003Woo0`003goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomo
o`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool3000>Ool3
000<Ool4000=Ool4000@Ool00`00Oomoo`1FOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`<000eoo`<0011oo`03
001oogoo00Yoo`03001oogoo011oo`03001oogoo069oo`03001oogoo00=oo`03001oogoo005oo`00
97oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol0
3Goo10003Woo0`0047oo00<007ooOol0PGoo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool4000?
Ool20025Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`01Ool0015oo`8000Aoo`8000Ao
o`8000Eoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`@000io
o`<0011oo`03001oogoo08=oo`03001oogoo00]oo`<000Aoo`03001oogoo005oo`0047oo00@007oo
Ool000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`0=Ool4000?Ool20026Ool00`00Oomoo`0<Ool2000=Ool30004Ool00`00Oomoo`01
Ool0011oo`04001oogoo0008Ool01000Oomoo`0017oo0`000goo00<007ooOol03Woo00<007ooOol0
3Goo10003Woo0`0047oo00<007ooOol0Q7oo00<007ooOol037oo0P003Goo0`000goo0P000goo000@
Ool01000Oomoo`0027oo0`001Goo00<007ooOol00goo00<007ooOol03goo00<007ooOol037oo1000
3Woo0P00R7oo00<007ooOol037oo0P003Woo0P003Woo00<007ooOol00goo00<007ooOol00Goo000@
Ool01000Oomoo`0027oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol03goo00<007ooOol0
3Goo0`003Woo0P00R7oo00<007ooOol037oo0P003Goo0`003Woo00<007ooOol00goo00<007ooOol0
0Goo000AOol2000:Ool30004Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool4000>Ool2000@Ool00`00
Oomoo`25Ool2000>Ool2000>Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Ao
o`03001oogoo00=oo`03001oogoo00eoo`@000ioo`8008Qoo`8000eoo`8000ioo`<000ioo`03001o
ogoo00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003goo0`003goo
00<007ooOol0QGoo0`003Goo0P003goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol00Goo000TOol00`00Oomoo`02Ool3000?Ool20028Ool2000=Ool3000=Ool3000?Ool0
0`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo
009oo`<000moo`8008Ioo`@000aoo`@000ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo
00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03goo00<0
07ooOol0MGoo0`002goo10003Woo0`003Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`1SOol2000>
Ool4000=Ool4000>Ool3000>Ool2000>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`8000ioo`@000eoo`H000]o
o`<000ioo`03001oo`0000ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo0P003Woo1@0037oo
0`003goo00<007ooOol0Igoo00<007ooOol00Goo000TOol20004Ool00`00Oomoo`0>Ool00`00Oomo
o`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool2000>Ool3000AOol20026Ool20003Ool002Aoo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00eoo`<0
011oo`8009=oo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol03goo00<007ooOol03Woo0`003Woo0`0047oo00<007ooOol0TGoo00<007ooOol0
0goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00
Oomoo`0=Ool4000?Ool2000AOol00`00Oomoo`21Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00moo`8000ioo`@0011o
o`03001oogoo09=oo`03001oogoo00]oo`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00goo
00<007ooOol03goo00<007ooOol03Goo0`003goo0`004Goo00<007ooOol0Pgoo00<007ooOol02goo
0P003Goo0`0017oo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0?Ool2000>Ool3
000@Ool2002GOol00`00Oomoo`0;Ool3000<Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo
00=oo`03001oogoo00ioo`<000moo`80015oo`03001oogoo08Ioo`03001oogoo00]oo`8000eoo`<0
00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol03Woo0`00
3goo0P00VGoo0P0037oo0`0037oo10003Goo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`02Ool3000?Ool2000AOol00`00Oomoo`27Ool2000=Ool2000<Ool4000=Ool00`00Oomoo`0=
Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<0011oo`03001oogoo09Mo
o`@000aoo`<000ioo`8000eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo
00<007ooOol00Woo0`0047oo00<007ooOol0RGoo0P002goo100037oo10003Goo00<007ooOol03Goo
00<007ooOol03Goo00<007ooOol00goo00<007ooOol00Goo000TOol20004Ool00`00Oomoo`2HOol4
000;Ool4000>Ool2000>Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool20003Ool0
02Aoo`03001oogoo00=oo`03001oogoo08Ioo`H000]oo`@000eoo`<000ioo`03001oogoo00eoo`03
001oogoo00aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007ooOol0
0goo00<007ooOol0MGoo10003Goo100037oo10003Goo00<007oo00003Woo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool3000=Ool5000<Ool80009Ool200000goo0000000<Ool01000Oomoo`003Goo00<007ooOol03Woo
00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Goo
000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`0?Ool00`00Oomoo`0?Ool2000?Ool4000<Ool3000?Ool00`00Oomoo`1UOol00`00Oomoo`01Ool0
02Aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00ioo`03001oogoo
00moo`8000ioo`@000eoo`H008Eoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol03goo00<007ooOol03goo0P003Woo0`003Woo1@00Ugoo00<007ooOol00Goo000T
Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool3000@Ool2000A
Ool2002FOol00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00mo
o`8000moo`<0015oo`03001oogoo0:Ioo`03001oogoo005oo`0097oo00<007ooOol00goo00<007oo
Ool03goo00<007ooOol03Woo0`0047oo0P004Woo00<007ooOol0Wgoo00<007ooOol00goo00<007oo
Ool00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool3000?Ool3000AOol00`00Oomoo`2TOol0
0`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`8000Aoo`03001oogoo00ioo`<0
011oo`<0015oo`03001oogoo0:=oo`03001oogoo00]oo`03001oogoo009oo`8000=oo`0097oo00<0
07ooOol00Woo0`0047oo0P004Goo0P00Z7oo00<007ooOol02goo0P0037oo0`0017oo00<007ooOol0
0Goo000TOol00`00Oomoo`02Ool3000@Ool2000BOol00`00Oomoo`2FOol2000>Ool00`00Oomoo`0:
Ool3000<Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<0011oo`800:Yoo`<000eo
o`8000aoo`<000aoo`<000Aoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol047oo
00<007ooOol0VWoo0P002goo0`003Goo0P0037oo10003Goo00<007ooOol00goo00<007ooOol00Goo
000TOol00`00Oomoo`03Ool00`00Oomoo`2ZOol4000;Ool3000=Ool3000=Ool00`00Oomoo`0=Ool0
0`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo09Uoo`H000Yoo`@0
00aoo`<000ioo`8000eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<0
07ooOol0SWoo1`002Woo10002goo10003Goo0P003Woo00<007ooOol03Goo00<007ooOol03Goo00<0
07ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`1]Ool2000?Ool4000;Ool6000:Ool5000;
Ool01000Oomoo`003Goo00<007ooOol03Woo00<007ooOol037oo00<007ooOol03Woo00<007ooOol0
0goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00
Oomoo`0>Ool00`00Oomoo`0>Ool2000?Ool20002Ool2000:Ool400000goo000000020008Ool;0006
Ool30002Ool00`00Oomoo`09Ool20003Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`0>
Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`01Ool0015oo`8000Ao
o`8000Aoo`8000Eoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00mo
o`03001oogoo00moo`03001oo`0000ioo`D000eoo`H000aoo`<007Aoo`03001oogoo005oo`0047oo
00@007ooOol000=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`0?Ool00`00Oomoo`0?Ool00`00Ool0000?Ool3000>Ool5000=Ool60022Ool00`00Oomoo`01
Ool0011oo`04001oogoo0008Ool01000Oomoo`0017oo0`000goo00<007ooOol03goo00<007ooOol0
3goo0P0047oo0P003goo10003Goo1P00Tgoo0P000goo000@Ool01000Oomoo`002Goo0P001Goo00<0
07ooOol00goo00<007ooOol03goo00<007ooOol03Woo0`003goo100047oo0`00YWoo00<007ooOol0
0Goo000@Ool01000Oomoo`0027oo00@007ooOol000Aoo`03001oogoo00=oo`03001oogoo00ioo`@0
00moo`<0011oo`8001=oo`03001oogoo0:=oo`03001oogoo005oo`004Goo0P002Woo0P001Goo00<0
07ooOol00Woo0`003goo100047oo0P004Woo00<007ooOol0]Woo00<007ooOol00Goo000TOol00`00
Oomoo`02Ool3000@Ool3000AOol00`00Oomoo`39Ool00`00Oomoo`01Ool002Aoo`03001oogoo009o
o`<0015oo`80019oo`03001oogoo0<Qoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007oo
Ool047oo0P00egoo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomo
o`0AOol00`00Oomoo`38Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03
001oogoo00=oo`03001oogoo0<aoo`8000eoo`8000aoo`03001oogoo00=oo`03001oogoo005oo`00
97oo00<007ooOol0a7oo0P002goo0`0037oo0`002goo0`0017oo00<007ooOol00Goo000TOol00`00
Oomoo`2dOol3000:Ool4000;Ool3000<Ool3000<Ool30004Ool00`00Oomoo`01Ool002Aoo`03001o
ogoo0:5oo`H000Yoo`@000]oo`@000]oo`@000]oo`@000aoo`<000Aoo`03001oogoo005oo`0097oo
0P00TWoo10002goo1@002goo0`0037oo10003Goo0P003Goo00<007oo00003Goo00<007ooOol00Woo
0P000goo000TOol00`00Oomoo`1_Ool2000?Ool4000<Ool70006Ool300000goo0000000:Ool30000
0goo001oo`0;Ool01000Oomoo`003Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomo
o`0>Ool2000?Ool3000>Ool40002Ool20008Ool<0005Ool=0004Ool6000017oo000000001goo0P00
17oo00<007ooOol027oo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`0?Ool00`00Ool0000?Ool00`00Ool0000?Ool4000>Ool7000<Ool6000;Ool3001bOol00`00
Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo00moo`80011oo`80011oo`<0011oo`D000ao
o`L000]oo`<008=oo`03001oogoo005oo`0097oo00<007ooOol00Woo0`003goo0`003goo10003goo
10003Woo1`00Xgoo00<007ooOol00Goo000TOol00`00Oomoo`02Ool3000?Ool3000AOol3000@Ool3
002gOol00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<0011oo`<0019oo`03001oogoo015oo`03
001oogoo0;Aoo`03001oogoo005oo`0097oo00<007ooOol00goo00<007ooOol047oo0P004goo00<0
07ooOol0agoo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`3K
Ool00`00Oomoo`01Ool002Aoo`03001oogoo00=oo`03001oogoo0>moo`03001oogoo005oo`0097oo
00<007ooOol0mGoo00<007ooOol00Goo000TOol2003eOol20003Ool002Aoo`03001oogoo0?Eoo`03
001oogoo005oo`0097oo00<007ooOol0kgoo00<007ooOol00goo00<007ooOol00Goo000TOol00`00
Oomoo`3COol3000;Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`01Ool002Aoo`03001oogoo0;=o
o`@000Yoo`H000Uoo`D000Yoo`@000aoo`03001oogoo00=oo`03001oogoo005oo`0097oo00<007oo
Ool0Pgoo0P003Woo100037oo1P002Woo1P0027oo10002goo10002Woo100037oo0`0017oo00<007oo
Ool00Goo000TOol00`00Oomoo`02Ool3000@Ool00`00Oomoo`18Ool2000@Ool4000=Ool50009Ool8
0005Ool90008Ool80008Ool5000;Ool4000<Ool3000<Ool30004Ool00`00Oomoo`01Ool002Aoo`03
001oogoo009oo`<000moo`8000moo`800003Ool0000000aoo`@00003Ool0000000Yoo`@000=oo`80
00Qoo`d000=ooa000003Ool0000000h00003Ool0000000D0009oo`@000Aoo`<000Eoo`03001oogoo
00Ioo`<000Aoo`03001oogoo00Moo`8000=oo`03001oogoo00Uoo`04001oogoo000<Ool00`00Ool0
000=Ool30004Ool00`00Oomoo`01Ool002Aoo`03001oogoo009oo`<000moo`<0011oo`@000moo`H0
00]oo`L000ioo`H000]oo`<000moo`<000eoo`03001oogoo05moo`03001oogoo005oo`0097oo00<0
07ooOol00goo00<007ooOol047oo0P003goo1@003Woo1`0037oo1P003Goo0`00TWoo00<007ooOol0
0Goo000TOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`0@Ool20038Ool00`00Oomoo`01
Ool002Aoo`03001oogoo00=oo`03001oogoo0>moo`03001oogoo005oo`0097oo0P00mGoo0P000goo
000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`00
97oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`3eOol00`00Oomoo`01Ool002Ao
o`03001oogoo0?Eoo`03001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol0
0`00Oomoo`3eOol00`00Oomoo`01Ool002Aoo`03001oogoo0?Eoo`03001oogoo005oo`0077oo0`00
1Goo00<007ooOol0mGoo00<007ooOol00Goo000MOol00`00Oomoo`04Ool00`00Oomoo`0DOol4000@
Ool4000@Ool4000?Ool4000?Ool4000>Ool4000=Ool4000=Ool4000;Ool4000<Ool4000:Ool4000:
Ool40009Ool4000COol00`00Oomoo`01Ool001eoo`03001oogoo00Aoo`<000=oo`03001oogoo00io
o`H000]oo`T000Qoo``000Eoo`h000=ooe<00003Ool0000000d0009oo``000Eoo`T000Moo`H000]o
o`03001oogoo009oo`8000=oo`007Goo00<007ooOol017oo00<007ooOol057oo100047oo100047oo
10003goo10003goo10003Woo10003Goo10003Goo10002goo100037oo10002Woo10002Woo10002Goo
10004goo00<007ooOol00Goo000MOol00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`0AOol0
0`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool0
0`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0DOol00`00Oomoo`01Ool001aoo`8000Ioo`03001oogoo0?Eoo`03
001oogoo005oo`0097oo00<007ooOol0mGoo00<007ooOol00Goo000TOol00`00Oomoo`03Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`03Ool00`00Oomoo`01Ool002AoooT000=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo0037Ool4001EOol00<Qoo`03001oogoo05Eoo`00;Goo00<007ooOol00goo10000Woo0`000goo
0`000goo0`000Woo10001goo0`0017oo1@000Woo100000=oo`0000000`000Woo1@001goo0`000Woo
100027oo100027oo1@0000Aoo`00001oo`80009oo`D00003Ool0000000800003Ool00000008000Mo
o`80009oo`80009oo`@00003Ool000000080009oo`D00003Ool0000000<0009oo`<0009oo`D0009o
o`<000=oo`<0009oo`@000Moo`<000Aoo`D0009oo`<0009oo`04001oogoo000<Ool002eoo`03001o
ogoo009oo`03001oogoo00=oo`05001oogooOol00002Ool01P00Oomoo`00Ool000=oo`04001oogoo
000:Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00D007ooOomoo`0000=oo`03001oogoo00Eo
o`05001oogooOol00002Ool00`00Oomoo`07Ool01@00Oomoogoo000027oo00@007ooOol0009oo`04
001oogoo0002Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo00Qoo`04001oo`000002Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00<007ooOol00goo00D007ooOomoo`0000=oo`03001oo`00
009oo`05001oogooOol00002Ool00`00Ool00003Ool01000Oomoo`002Woo00<007ooOol01Goo00D0
07ooOomoo`0000=oo`03001oo`0000<000aoo`00;7oo00<007oo00000goo1@0000=oo`00Ool01Goo
00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo00Qoo`03001oogoo00Eoo`04001oogoo
Ool50003Ool01@00Oomoogoo00000goo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo
00Moo`03001oo`00008000Qoo`04001oogoo0002Ool01000Oomoo`000Woo00H007ooOomoo`00Ool5
0002Ool00`00Oomoo`08Ool30003Ool500000goo001oo`02Ool01@00Oomoogoo00001Goo00D007oo
Oomoo`0000Eoo`@000=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`08Ool00`00
Oomoo`05Ool01@00Oomoogoo00000goo00<007oo00000`0037oo000/Ool00`00Ool00003Ool01`00
Oomoogoo001oo`0000=oo`04001oogoo0004Ool01@00Oomoogoo00000Woo0P002Goo0`001Goo00D0
07ooOomoo`0000=oo`05001oogooOol00003Ool01@00Oomoogoo00001goo00D007ooOomoo`00009o
o`03001oogoo00Moo`03001oogoo00Yoo`04001oogoo0002Ool01000Oomoo`000Woo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`020009Ool01000Oomoo`000Woo00L007ooOomoo`00Ool00003Ool0
1@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`05001oogooOol00004Ool0
1@00Oomoogoo00000Woo0P002Goo0`001Goo00D007ooOomoo`0000=oo`03001oo`00009oo`03001o
ogoo00Yoo`00;7oo00<007oo000017oo0`000goo100000=oo`0000000P000goo0`000Woo0P0000=o
o`0000001goo00<007ooOol017oo0P0017oo0`0017oo00<007ooOol00Woo100027oo0`000Woo1000
1goo00D007ooOomoo`0000Moo`800004Ool00000Ool50003Ool40002Ool30002Ool200000goo0000
0007Ool01000Oomoo`000goo0`0000=oo`0000000`0017oo00<007ooOol00Woo0P0017oo10000Woo
0`000Woo10000goo0`000Woo0P0000=oo`0000001goo00<007ooOol01Goo00<007ooOol00Woo0`00
00=oo`0000000Woo0P002goo000[Ool200000goo0000000?Ool00`00Oomoo`0COol5000@Ool00`00
Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool4000HOol00`00Oomoo`0@Ool4000AOol00`00
Oomoo`0DOol00`00Oomoo`0COol50004Ool00`00Oomoo`0GOol003moo`03001oogoo01aoo`03001o
ogoo00Moo`<000Ioo`8000ioo`<002=oo`8002Eoo`<000Eoo`03001oogoo00ioo`03001oogoo01Yo
o`<001Uoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.181183, -0.127113, 
  0.00423725, 0.00423725}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
There are also functions for theoretically analysing the stability \
properties of equilibria in the games under the two kinds of dynamics.\
\>", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ReplicatorFlowStability\)\)], "Input"],

Cell[BoxData[
    \("ReplicatorFlowStability[G_], (1) finds the Nash  equilibria of a game \
G, and (2) performs  a linear stability analysis for the continuous time  \
Replicator flow at each of the Nash equilibria.   Specifically, this function \
outputs the real parts of  the eigenvalues of the Jacobian Matrix of the \
Replicator flow evaluated at each Nash equilibrium of G."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?DarwinFlowStability\)\)], "Input"],

Cell[BoxData[
    \("DarwinFlowStability[G_], (1) finds the Nash  equilibria of a game G, \
and (2) performs  a linear stability analysis for the continuous time  Darwin \
flow at each of the Nash equilibria.   Specifically, this function outputs \
the real parts of  the eigenvalues of the Jacobian Matrix of the Darwin flow \
evaluated at each Nash equilibrium of G."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ReplicatorFlowStability[G]\), 
    \(DarwinFlowStability[G]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("The Nash equilibria of G are: "\[InvisibleSpace]{{0.5`, 0.5`}}\),
      SequenceForm[ "The Nash equilibria of G are: ", {{0.5, 0.5}}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "\<\"The Jacobian of the Replicator Flow \"\>", "\[InvisibleSpace]", 
        "\<\"at the point \"\>", "\[InvisibleSpace]", \({0.5`, 0.5`}\), 
        "\[InvisibleSpace]", "\<\" is \"\>", "\[InvisibleSpace]", 
        TagBox[GridBox[{
              {"0.`", "0.5`"},
              {\(-0.5`\), "0.`"}
              },
            RowSpacings->1,
            ColumnSpacings->3,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          (TableForm[ #]&)]}],
      SequenceForm[ 
      "The Jacobian of the Replicator Flow ", "at the point ", {0.5, 0.5}, 
        " is ", 
        TableForm[ {{0.0, 0.5}, {-0.5, 0.0}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("The Real Parts of the Eigenvalues of the "\[InvisibleSpace]"Jacobian \
of the Replicator Flow at the point "\[InvisibleSpace]{0.5`, 0.5`}
          \[InvisibleSpace]" are: "\[InvisibleSpace]{0.`, 0.`}\),
      SequenceForm[ 
      "The Real Parts of the Eigenvalues of the ", 
        "Jacobian of the Replicator Flow at the point ", {0.5, 0.5}, 
        " are: ", {0.0, 0.0}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("The Nash equilibria of G are: "\[InvisibleSpace]{{0.5`, 0.5`}}\),
      SequenceForm[ "The Nash equilibria of G are: ", {{0.5, 0.5}}],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{
      "\<\"The Jacobian of the Darwin Flow \"\>", "\[InvisibleSpace]", 
        "\<\"at the point \"\>", "\[InvisibleSpace]", \({0.5`, 0.5`}\), 
        "\[InvisibleSpace]", "\<\" is \"\>", "\[InvisibleSpace]", 
        TagBox[GridBox[{
              {"0.`", "1.`"},
              {\(-1.`\), "0.`"}
              },
            RowSpacings->1,
            ColumnSpacings->3,
            RowAlignments->Baseline,
            ColumnAlignments->{Left}],
          (TableForm[ #]&)]}],
      SequenceForm[ 
      "The Jacobian of the Darwin Flow ", "at the point ", {0.5, 0.5}, 
        " is ", 
        TableForm[ {{0.0, 1.0}, {-1.0, 0.0}}]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("The Real Parts of the Eigenvalues of the "\[InvisibleSpace]"Jacobian \
of the Darwin Flow at the point "\[InvisibleSpace]{0.5`, 0.5`}
          \[InvisibleSpace]" are: "\[InvisibleSpace]{0.`, 0.`}\),
      SequenceForm[ 
      "The Real Parts of the Eigenvalues of the ", 
        "Jacobian of the Darwin Flow at the point ", {0.5, 0.5}, " are: ", {
        0.0, 0.0}],
      Editable->False]], "Print"]
}, Open  ]],

Cell[TextData[{
  "In this case, the standard analytical approach will not tell us whether \
the equilibrium point is a global attractor or not (but we do know it is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " ",
  StyleBox["un",
    FontSlant->"Italic"],
  "stable).  [As it turns out, it is a global attractor in the darwin flow \
case, but not in the replicator case.]"
}], "Text"],

Cell["\<\
There are a couple of other useful functions in this package as \
well:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(G1\  = 
      \ {{{R11, \ C11}, \ {R12, \ C12}}, \n
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {{R21, \ C21}, \ {R22, \ C22}}}\)], 
  "Input"],

Cell[BoxData[
    \({{{1, 0}, {0, 1}}, {{0, 1}, {1, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?IsNash\)\)], "Input"],

Cell[BoxData[
    \("IsNash[game_,strategies_] returns True if strategies is  a Nash \
Equilibrium of game and False otherwise. Example input: \
IsNash[game,{{2/3,1/3},{1/3,2/3}}]."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(IsNash[G1, {{1/2, 1/2}, {1/2, 1/2}}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Nash\)\)], "Input"],

Cell[BoxData[
    \("Nash[game_] finds the Nash Equilibria of game, a game in  normal form. \
Example input: Nash[{{{2,1},{0,0}},{{0,0},{1,2}}}]. Nash  returns the \
probability weights on the different pure strategies."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nash[G1]\)], "Input"],

Cell[BoxData[
    \({{{1\/2, 1\/2}, {1\/2, 1\/2}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nash[{{{2, 1}, {0, 0}}, {{0, 0}, {1, 2}}}]\)], "Input"],

Cell[BoxData[
    \({{{0, 1}, {0, 1}}, {{2\/3, 1\/3}, {1\/3, 2\/3}}, {{1, 0}, {1, 0}}}\)], 
  "Output"]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 800}, {0, 580}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{785, 547},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 598, 21, 94, "Input"],
Cell[2310, 72, 5777, 201, 138, "Text",
  Evaluatable->False],
Cell[8090, 275, 1160, 42, 49, "Text"],
Cell[9253, 319, 138, 3, 43, "Input"],
Cell[9394, 324, 165, 5, 31, "Text"],

Cell[CellGroupData[{
Cell[9584, 333, 53, 1, 27, "Input"],
Cell[9640, 336, 494, 7, 82, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10171, 348, 57, 1, 27, "Input"],
Cell[10231, 351, 501, 7, 82, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10769, 363, 254, 6, 43, "Input"],
Cell[11026, 371, 531, 14, 35, "Print"]
}, Open  ]],
Cell[11572, 388, 238, 8, 32, "Text"],

Cell[CellGroupData[{
Cell[11835, 400, 711, 15, 139, "Input"],
Cell[12549, 417, 30761, 1035, 193, 12516, 804, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[43313, 1454, 27091, 990, 193, 12523, 804, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False]
}, Open  ]],
Cell[70419, 2447, 104, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[70548, 2454, 59, 1, 27, "Input"],
Cell[70610, 2457, 215, 3, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[70862, 2465, 63, 1, 27, "Input"],
Cell[70928, 2468, 226, 3, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71191, 2476, 136, 3, 43, "Input"],
Cell[71330, 2481, 67696, 2264, 296, 37682, 1889, "GraphicsData", 
"PostScript", "Graphics"],
Cell[139029, 4747, 130, 3, 26, "Output"],
Cell[139162, 4752, 74120, 2362, 296, 38124, 1913, "GraphicsData", 
"PostScript", "Graphics"],
Cell[213285, 7116, 130, 3, 26, "Output"]
}, Open  ]],
Cell[213430, 7122, 166, 4, 31, "Text"],

Cell[CellGroupData[{
Cell[213621, 7130, 61, 1, 27, "Input"],
Cell[213685, 7133, 394, 5, 67, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214116, 7143, 57, 1, 27, "Input"],
Cell[214176, 7146, 382, 5, 67, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214595, 7156, 120, 3, 43, "Input"],
Cell[214718, 7161, 214, 4, 22, "Print"],
Cell[214935, 7167, 735, 19, 35, "Print"],
Cell[215673, 7188, 457, 9, 37, "Print"],
Cell[216133, 7199, 214, 4, 22, "Print"],
Cell[216350, 7205, 725, 19, 35, "Print"],
Cell[217078, 7226, 449, 9, 37, "Print"]
}, Open  ]],
Cell[217542, 7238, 391, 10, 49, "Text"],
Cell[217936, 7250, 95, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[218056, 7257, 157, 4, 43, "Input"],
Cell[218216, 7263, 70, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218323, 7269, 44, 1, 27, "Input"],
Cell[218370, 7272, 194, 3, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218601, 7280, 69, 1, 27, "Input"],
Cell[218673, 7283, 38, 1, 26, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[218748, 7289, 42, 1, 27, "Input"],
Cell[218793, 7292, 233, 3, 37, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219063, 7300, 41, 1, 27, "Input"],
Cell[219107, 7303, 64, 1, 40, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219208, 7309, 75, 1, 27, "Input"],
Cell[219286, 7312, 103, 2, 40, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

